@@ -17,16 +17,18 @@
 
 #include "config.h"
 
+#include <errno.h>
+
 #include <QtCore/QFile>
 #include <QtCore/QString>
 #include <QtCore/QMetaType>
+#include <QtCore/QMutableListIterator>
 
 #include <kcmdlineargs.h>
 #include <kconfig.h>
 #include <kconfiggroup.h>
 #include <ktoolinvocation.h>
 
-#include "libkwave/ApplicationContext.h"
 #include "libkwave/ClipBoard.h"
 #include "libkwave/LabelList.h"
 #include "libkwave/Logger.h"
@@ -37,16 +39,22 @@
 #include "libkwave/SignalManager.h"
 #include "libkwave/String.h"
 #include "libkwave/PluginManager.h"
+#include "libkwave/Utils.h"
 
-#include "TopWidget.h"
 #include "App.h"
+#include "FileContext.h"
 #include "Splash.h"
+#include "TopWidget.h"
+
+/** maximum number of recent files */
+#define MAX_RECENT_FILES 20
 
 //***************************************************************************
 Kwave::App::App()
    :KUniqueApplication(),
     m_recent_files(),
-    m_top_widgets()
+    m_top_widgets(),
+    m_gui_type(Kwave::App::GUI_TAB)
 {
     qRegisterMetaType<Kwave::SampleArray>("Kwave::SampleArray");
     qRegisterMetaType<Kwave::LabelList>("Kwave::LabelList");
@@ -58,6 +66,48 @@ Kwave::App::App()
             SIGNAL(changed(QClipboard::Mode)),
             &(Kwave::ClipBoard::instance()),
             SLOT(slotChanged(QClipboard::Mode)));
+
+    // read the configured user interface type
+    QString result;
+    KConfigGroup cfg = KGlobal::config()->group("Global");
+    result = cfg.readEntry("UI Type");
+    if (result == _("SDI")) {
+	m_gui_type = Kwave::App::GUI_SDI;
+    } else if (result == _("MDI")) {
+	m_gui_type = Kwave::App::GUI_MDI;
+    } else if (result == _("TAB")) {
+	m_gui_type = Kwave::App::GUI_TAB;
+    }
+    // else: use default
+
+    // if user interface type is given as cmdline parameter: use that one
+    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+    if (args && args->isSet("gui")) {
+	QString arg = args->getOption("gui").toUpper();
+	bool valid = false;
+	if (arg == _("SDI")) {
+	    m_gui_type = Kwave::App::GUI_SDI;
+	    valid = true;
+	} else if (arg == _("MDI")) {
+	    m_gui_type = Kwave::App::GUI_MDI;
+	    valid = true;
+	} else if (arg == _("TAB")) {
+	    m_gui_type = Kwave::App::GUI_TAB;
+	    valid = true;
+	}
+	// else: use previous setting
+
+	// save this setting
+	if (valid && (arg != result))
+	    cfg.writeEntry(_("UI Type"), arg);
+    }
+}
+
+//***************************************************************************
+Kwave::App::~App()
+{
+    saveRecentFiles();
+    m_recent_files.clear();
 }
 
 //***************************************************************************
@@ -92,8 +142,7 @@ int Kwave::App::newInstance()
 	// command line an load it
 	for (unsigned int i = 0; i < argc; i++) {
 	    QString name = args->arg(i);
-	    QFileInfo file(name);
-	    newWindow(file.absoluteFilePath());
+	    newWindow(KUrl(name));
 	}
     }
     if (args) args->clear();
@@ -108,21 +157,27 @@ bool Kwave::App::isOK() const
 }
 
 //***************************************************************************
-bool Kwave::App::executeCommand(const QString &command)
+int Kwave::App::executeCommand(const QString &command)
 {
     Kwave::Parser parser(command);
     if (parser.command() == _("newwindow")) {
+	bool ok;
 	if (parser.hasParams()) {
-	    newWindow(KUrl(parser.params().at(0)));
+	    ok = newWindow(KUrl(parser.params().at(0)));
 	} else {
-	    newWindow(KUrl(QString()));
+	    ok = newWindow(KUrl(QString()));
 	}
+	return (ok) ? 0 : -EIO;
+    } else if (parser.command() == _("openrecent:clear")) {
+	m_recent_files.clear();
+	saveRecentFiles();
+	emit recentFilesChanged();
     } else if (parser.command() == _("help")) {
 	KToolInvocation::invokeHelp();
     } else {
-	return false;
+	return ENOSYS; // command not implemented (here)
     }
-    return true;
+    return 0;
 }
 
 //***************************************************************************
@@ -133,8 +188,8 @@ void Kwave::App::addRecentFile(const QString &newfile)
     // remove old entries if present
     m_recent_files.removeAll(newfile);
 
-    // shorten the list down to 19 entries
-    while (m_recent_files.count() > 19)
+    // shorten the list down to (MAX_RECENT_FILES - 1) entries
+    while (m_recent_files.count() >= MAX_RECENT_FILES)
 	m_recent_files.removeLast();
 
     // insert the new entry at top
@@ -150,52 +205,65 @@ void Kwave::App::addRecentFile(const QString &newfile)
 //***************************************************************************
 bool Kwave::App::newWindow(const KUrl &url)
 {
+    Kwave::TopWidget *new_top_widget = 0;
+
     Kwave::Splash::showMessage(i18n("Opening main window..."));
 
-    Kwave::TopWidget *new_top_widget = new Kwave::TopWidget(*this);
-    if (!new_top_widget || !new_top_widget->init()) {
-	// init failed
-	qWarning("ERROR: initialization of TopWidget failed");
-	delete new_top_widget;
-	return false;
+    switch (m_gui_type) {
+	case Kwave::App::GUI_TAB: /* FALLTHROUGH */
+	case Kwave::App::GUI_MDI:
+	    // re-use the last top widget to open the file
+	    if (!m_top_widgets.isEmpty())
+		new_top_widget = m_top_widgets.last();
+	    break;
+	case Kwave::App::GUI_SDI:
+	    // always create a new top widget, except when handling commands
+	    if ( (url.scheme().toLower() == Kwave::urlScheme()) &&
+		 !m_top_widgets.isEmpty() )
+		new_top_widget = m_top_widgets.last();
+	    break;
     }
 
-    if (m_top_widgets.isEmpty()) {
-	// the first widget is the main widget !
-	setTopWidget(new_top_widget); // sets geometry and other properties
-	setTopWidget(0);              // that's enough, dont quit on close !
-    } else {
-	// create a new widget with the same geometry as
-	// the last created one
-	const QRect &geom = m_top_widgets.last()->geometry();
-	// calling setGeometry(geom) would overlap :-(
-	new_top_widget->resize(geom.width(), geom.height());
+    if (!new_top_widget) {
+	new_top_widget = new(std::nothrow) Kwave::TopWidget(*this);
+	if (!new_top_widget || !new_top_widget->init()) {
+	    // init failed
+	    qWarning("ERROR: initialization of TopWidget failed");
+	    delete new_top_widget;
+	    return false;
+	}
+
+	if (m_top_widgets.isEmpty()) {
+	    // the first widget is the main widget !
+	    setTopWidget(new_top_widget); // sets geometry and other properties
+	    setTopWidget(0);              // that's enough, don't quit on close!
+	} else {
+	    // create a new widget with the same geometry as
+	    // the last created one
+	    const QRect &geom = m_top_widgets.last()->geometry();
+	    // calling setGeometry(geom) would overlap :-(
+	    new_top_widget->resize(geom.width(), geom.height());
+	}
+
+	m_top_widgets.append(new_top_widget);
+	new_top_widget->show();
+
+	// inform the widget about changes in the list of recent files
+	connect(this, SIGNAL(recentFilesChanged()),
+		new_top_widget, SLOT(updateRecentFiles()));
     }
 
-    m_top_widgets.append(new_top_widget);
-    new_top_widget->show();
-
-    // inform the widget about changes in the list of recent files
-    connect(this, SIGNAL(recentFilesChanged()),
-            new_top_widget, SLOT(updateRecentFiles()));
-
-    if (!url.isEmpty()) {
-	Kwave::Splash::showMessage(i18n("Loading file '%1'...",
-	    url.prettyUrl()));
-	new_top_widget->loadFile(url);
-    }
+    if (!url.isEmpty()) new_top_widget->loadFile(url);
 
     Kwave::Splash::showMessage(i18n("Startup done"));
     return true;
 }
 
 //***************************************************************************
-bool Kwave::App::closeWindow(Kwave::TopWidget *todel)
+bool Kwave::App::toplevelWindowHasClosed(Kwave::TopWidget *todel)
 {
-    Q_ASSERT(todel);
-
-    // save the configuration, including the list of recent files
-    saveConfig();
+    // save the list of recent files
+    saveRecentFiles();
 
     // remove the toplevel widget from our list
     if (m_top_widgets.contains(todel))
@@ -205,27 +273,108 @@ bool Kwave::App::closeWindow(Kwave::TopWidget *todel)
     return (m_top_widgets.isEmpty());
 }
 
+//***************************************************************************
+QList<Kwave::App::FileAndInstance> Kwave::App::openFiles() const
+{
+    QList<Kwave::App::FileAndInstance> all_files;
+    foreach (Kwave::TopWidget *topwidget, m_top_widgets) {
+	if (!topwidget) continue;
+	QList<Kwave::App::FileAndInstance> files = topwidget->openFiles();
+	if (!files.isEmpty())
+	    all_files += files;
+    }
+    return all_files;
+}
+
+//***************************************************************************
+void Kwave::App::switchGuiType(Kwave::TopWidget *top, GuiType new_type)
+{
+    Q_ASSERT(top);
+    if (!top) return;
+    if (new_type == m_gui_type) return;
+
+    // collect all contexts of all toplevel widgets, and delete all except
+    // the new top widget that is calling us
+    QList<Kwave::FileContext *> all_contexts;
+    QMutableListIterator<Kwave::TopWidget *> it(m_top_widgets);
+    while (it.hasNext()) {
+	Kwave::TopWidget *topwidget = it.next();
+	if (!topwidget) { it.remove(); continue; }
+	QList<Kwave::FileContext *> contexts = topwidget->detachAllContexts();
+	if (!contexts.isEmpty()) all_contexts += contexts;
+	if (topwidget != top) {
+	    it.remove();
+	    delete topwidget;
+	}
+    }
+
+    // from now on use the new GUI type
+    m_gui_type = new_type;
+
+    // at this point we should have exactly one toplevel widget without
+    // context and a list of contexts (which may be empty)
+    if (!all_contexts.isEmpty()) {
+	bool first = true;
+	foreach (Kwave::FileContext *context, all_contexts) {
+	    Kwave::TopWidget *top_widget = 0;
+
+	    switch (m_gui_type) {
+		case GUI_SDI:
+		    if (first) {
+			// the context reuses the calling toplevel widget
+			top_widget = top;
+			first = false;
+		    } else {
+			// for all other contexts we have to create a new
+			// toplevel widget
+			top_widget = new(std::nothrow) Kwave::TopWidget(*this);
+			if (!top_widget || !top_widget->init()) {
+			    // init failed
+			    qWarning("ERROR: initialization of TopWidget failed");
+			    delete top_widget;
+			    delete context;
+			}
+			m_top_widgets.append(top_widget);
+			top_widget->show();
+
+			// inform the widget about changes in the list of recent
+			// files
+			connect(this, SIGNAL(recentFilesChanged()),
+				top_widget, SLOT(updateRecentFiles()));
+		    }
+		    break;
+		case GUI_MDI: /* FALLTHROUGH */
+		case GUI_TAB:
+		    // all contexts go into the same toplevel widget
+		    top_widget = top;
+		    break;
+	    }
+
+	    top_widget->insertContext(context);
+	}
+    } else {
+	// give our one and only toplevel widget a default context
+	top->insertContext(0);
+    }
+}
+
 //***************************************************************************
 void Kwave::App::saveRecentFiles()
 {
     KConfigGroup cfg = KGlobal::config()->group("Recent Files");
 
     QString num;
-    for (int i = 0 ; i < m_recent_files.count(); i++) {
+    for (int i = 0 ; i < MAX_RECENT_FILES; i++) {
 	num.setNum(i);
-	cfg.writeEntry(num, m_recent_files[i]);
+	if (i < m_recent_files.count())
+	    cfg.writeEntry(num, m_recent_files[i]);
+	else
+	    cfg.deleteEntry(num);
     }
 
     cfg.sync();
 }
 
-//***************************************************************************
-void Kwave::App::saveConfig()
-{
-    // save the list of recent files
-    saveRecentFiles();
-}
-
 //***************************************************************************
 void Kwave::App::readConfig()
 {
@@ -233,7 +382,7 @@ void Kwave::App::readConfig()
     QString key;
     const KConfigGroup cfg = KGlobal::config()->group("Recent Files");
 
-    for (unsigned int i = 0 ; i < 20; i++) {
+    for (unsigned int i = 0 ; i < MAX_RECENT_FILES; i++) {
 	key = QString::number(i);        // generate number
 
 	// read corresponding entry, which is stored in UTF-8
@@ -248,13 +397,6 @@ void Kwave::App::readConfig()
     }
 }
 
-//***************************************************************************
-Kwave::App::~App()
-{
-    saveConfig();
-    m_recent_files.clear();
-}
-
 //***************************************************************************
 #include "App.moc"
 //***************************************************************************
