@@ -15,12 +15,14 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _KWAVE_APP_H_
-#define _KWAVE_APP_H_
+#ifndef KWAVE_APP_H
+#define KWAVE_APP_H
 
 #include "config.h"
 
+#include <QtCore/QObject>
 #include <QtCore/QList>
+#include <QtCore/QPair>
 #include <QtCore/QStringList>
 
 #include <kuniqueapplication.h>
@@ -32,7 +34,7 @@ class KUrl;
 namespace Kwave
 {
 
-    class ApplicationContext;
+    class FileContext;
     class TopWidget;
 
     /**
@@ -45,6 +47,19 @@ namespace Kwave
 	Q_OBJECT
     public:
 
+	typedef enum {
+	    GUI_SDI, /**< single document interface (SDI)          */
+	    GUI_MDI, /**< multi document interface (MDI)           */
+	    GUI_TAB  /**< tabbed interface                         */
+	/*  GUI_IDE       integrated development environment (IDE) */
+	} GuiType;
+
+	/**
+	 * pair of file name and instance
+	 * @see #openFiles()
+	 */
+	typedef QPair<QString,int> FileAndInstance;
+
 	/** Constructor */
 	App();
 
@@ -59,7 +74,7 @@ namespace Kwave
 
 	/**
 	 * Adds a file to the top of the list of recent files. If it was
-	 * already contained in the list the previous occourence is removed.
+	 * already contained in the list the previous occurrence is removed.
 	 * @param filename path to the file
 	 */
 	void addRecentFile(const QString &filename);
@@ -70,28 +85,38 @@ namespace Kwave
 	virtual int newInstance();
 
 	/**
-	 * Opens a new toplevel window. If a filename is specified the will
-	 * will be opened (should be a .wav-file).
+	 * Opens a new toplevel window. If a filename is specified the file
+	 * will be opened.
 	 * @param url URL of the file to be loaded, (optional, might be empty)
-	 * @return true if succeeded
-	 * @see #closeWindow()
+	 * @return true if succeeded, false if failed
+	 * @see #toplevelWindowHasClosed()
 	 * @see TopWidget
 	 */
 	bool newWindow(const KUrl &url);
 
 	/**
-	 * Closes a previously opened toplevel window.
-	 * @param todel the toplevel window that closes down
+	 * Called when a toplevel window has closed.
+	 * @param todel the toplevel window that has closed
 	 * @return true if it was the last toplevel window
-	 * @see #newWindow()
-	 * @see TopWidget
 	 */
-	bool closeWindow(Kwave::TopWidget *todel);
+	bool toplevelWindowHasClosed(Kwave::TopWidget *todel);
 
 	/** Returns a reference to the list of recent files */
-	QStringList recentFiles() {
-	    return m_recent_files;
-	}
+	inline QStringList recentFiles() const { return m_recent_files; }
+
+	/** Returns a list of currently opened files and their instance */
+	QList<FileAndInstance> openFiles() const;
+
+	/** returns the GUI type (e.g. SDI, MDI etc.) */
+	GuiType guiType() const { return m_gui_type; }
+
+	/**
+	 * Switches the GUI type to a new style, using the current toplevel
+	 * widget as start.
+	 * @param top the current toplevel widget
+	 * @param new_type the new GUI type
+	 */
+	void switchGuiType(Kwave::TopWidget *top, GuiType new_type);
 
     signals:
 	/**
@@ -103,14 +128,19 @@ namespace Kwave
     protected:
 	friend class Kwave::TopWidget;
 
-	bool executeCommand(const QString &command);
+	/**
+	 * process an application global Kwave text command
+	 * @param command the text command to handle
+	 * @retval 0 if succeeded
+	 * @retval ENOSYS if the command is unknown
+	 * @retval -EIO if failed
+	 */
+	int executeCommand(const QString &command);
 
-    protected:
+    private:
 
 	/**
-	 * Reads the configuration settings and the list of recent files,
-	 * opposite of saveConfig().
-	 * @see #saveConfig()
+	 * Reads the configuration settings and the list of recent files
 	 */
 	void readConfig();
 
@@ -120,13 +150,6 @@ namespace Kwave
 	 */
 	void saveRecentFiles();
 
-	/**
-	 * Saves the current configuration of kwave to the configuration file,
-	 * opposite of readConfig(). Also saves the list of recent files.
-	 * @see #saveRecentFiles()
-	 */
-	void saveConfig();
-
     private:
 
 	/**
@@ -139,6 +162,8 @@ namespace Kwave
 	/** list of toplevel widgets */
 	QList<Kwave::TopWidget *> m_top_widgets;
 
+	/** the GUI type, e.g. SDI or MDI */
+	GuiType m_gui_type;
     };
 }
 
