@@ -21,18 +21,18 @@
 #include <math.h>
 #include <stdlib.h>
 
+#include <QtCore/QtGlobal>
+#include <QtCore/QPoint>
 #include <QtGui/QApplication>
 #include <QtGui/QFrame>
 #include <QtGui/QGridLayout>
 #include <QtGui/QHBoxLayout>
 #include <QtGui/QResizeEvent>
 #include <QtGui/QScrollBar>
-#include <QtCore/QtGlobal>
 #include <QtGui/QWheelEvent>
 
 #include <klocale.h>
 
-#include "libkwave/ApplicationContext.h"
 #include "libkwave/CodecManager.h"
 #include "libkwave/Drag.h"
 #include "libkwave/FileDrag.h"
@@ -50,6 +50,8 @@
 #include "libgui/OverViewWidget.h"
 #include "libgui/SignalWidget.h"
 
+#include "App.h"
+#include "FileContext.h"
 #include "MainWidget.h"
 
 /**
@@ -70,12 +72,22 @@
 #define DEFAULT_DISPLAY_TIME (5 * 60.0)
 
 //***************************************************************************
-Kwave::MainWidget::MainWidget(QWidget *parent,
-			      Kwave::ApplicationContext &context)
-    :QWidget(parent), m_context(context), m_upper_dock(), m_lower_dock(),
+Kwave::MainWidget::MainWidget(QWidget *parent, Kwave::FileContext &context,
+                              const QSize &preferred_size)
+    :QWidget(parent),
+     Kwave::CommandHandler(),
+     Kwave::Zoomable(),
+     m_context(context), m_upper_dock(), m_lower_dock(),
      m_scroll_area(this), m_horizontal_scrollbar(0),
-     m_signal_widget(&m_scroll_area, context, &m_upper_dock, &m_lower_dock),
-     m_overview(0), m_offset(0), m_zoom(1.0)
+     m_signal_widget(
+         &m_scroll_area,
+         context.signalManager(),
+         &m_upper_dock,
+         &m_lower_dock
+     ),
+     m_overview(0), m_offset(0), m_zoom(1.0),
+     m_preferred_size(preferred_size),
+     m_delayed_update_timer(this)
 {
 //    qDebug("MainWidget::MainWidget()");
 
@@ -133,8 +145,8 @@ Kwave::MainWidget::MainWidget(QWidget *parent,
     topLayout->addWidget(m_overview);
     connect(m_overview, SIGNAL(valueChanged(sample_index_t)),
 	    this,       SLOT(setOffset(sample_index_t)));
-    connect(m_overview, SIGNAL(sigCommand(const QString &)),
-            this,       SIGNAL(sigCommand(const QString &)));
+    connect(m_overview, SIGNAL(sigCommand(QString)),
+            this,       SIGNAL(sigCommand(QString)));
     m_overview->metaDataChanged(signal_manager->metaData());
     m_overview->hide();
 
@@ -159,31 +171,42 @@ Kwave::MainWidget::MainWidget(QWidget *parent,
 
     // -- connect all signals from/to the signal widget --
 
-    connect(&m_signal_widget, SIGNAL(sigCommand(const QString &)),
-	    this,             SIGNAL(sigCommand(const QString &)));
+    connect(&m_signal_widget, SIGNAL(sigCommand(QString)),
+	    this,             SIGNAL(sigCommand(QString)));
+    connect(&m_signal_widget,
+	    SIGNAL(sigMouseChanged(Kwave::MouseMark::Mode,
+	                           sample_index_t, sample_index_t)),
+            this,
+	    SIGNAL(sigMouseChanged(Kwave::MouseMark::Mode,
+	                           sample_index_t, sample_index_t)));
 
     // -- connect all signals from/to the signal manager --
 
     connect(signal_manager,
-	    SIGNAL(sigTrackInserted(unsigned int, Kwave::Track *)),
+	    SIGNAL(sigTrackInserted(uint,Kwave::Track*)),
 	    this,
-	    SLOT(slotTrackInserted(unsigned int, Kwave::Track *)));
+	    SLOT(slotTrackInserted(uint,Kwave::Track*)));
     connect(signal_manager,
-	    SIGNAL(sigTrackDeleted(unsigned int, Kwave::Track *)),
+	    SIGNAL(sigTrackDeleted(uint,Kwave::Track*)),
 	    this,
-	    SLOT(slotTrackDeleted(unsigned int, Kwave::Track *)));
+	    SLOT(slotTrackDeleted(uint,Kwave::Track*)));
     connect(signal_manager,
             SIGNAL(sigMetaDataChanged(Kwave::MetaDataList)),
             this,
             SLOT(updateViewRange()));
 
-    this->setLayout(topLayout);
+    // set up the timer for delayed view range update
+    m_delayed_update_timer.setSingleShot(true);
+    connect(&m_delayed_update_timer, SIGNAL(timeout()),
+            this, SLOT(updateViewRange()));
+
+    setLayout(topLayout);
 }
 
 //***************************************************************************
 bool Kwave::MainWidget::isOK()
 {
-    return (m_overview);
+    return (m_horizontal_scrollbar && m_overview);
 }
 
 //***************************************************************************
@@ -197,8 +220,20 @@ Kwave::MainWidget::~MainWidget()
 //***************************************************************************
 void Kwave::MainWidget::resizeEvent(QResizeEvent *event)
 {
-    Q_UNUSED(event);
-    updateViewRange();
+    QWidget::resizeEvent(event);
+
+    if (!m_context.isActive() &&
+	(m_context.app().guiType() == Kwave::App::GUI_TAB))
+    {
+	// HACK: this is a workaround for stupid bug in Qt, which sends us a
+	//       resize event with bogus size, when we are in tab mode, just
+	//       before getting deactivated !?
+	if (!m_delayed_update_timer.isActive())
+	    m_delayed_update_timer.start(0);
+    } else {
+	// update immediately
+	updateViewRange();
+    }
 }
 
 //***************************************************************************
@@ -239,29 +274,7 @@ void Kwave::MainWidget::dropEvent(QDropEvent *event)
 	    qWarning("MainWidget::dropEvent(%s): failed !", event->format(0));
 	    event->ignore();
 	}
-    } else if (event->mimeData()->hasUrls()) {
-	bool first = true;
-	foreach (QUrl url, event->mimeData()->urls()) {
-	    QString filename = url.toLocalFile();
-	    QString mimetype = Kwave::CodecManager::whatContains(filename);
-	    if (Kwave::CodecManager::canDecode(mimetype)) {
-		if (first) {
-		    // first dropped URL -> open in this window
-		    emit sigCommand(_("open(") +
-		                    Kwave::Parser::escape(filename) +
-		                    _(")"));
-		    first = false;
-		} else {
-		    // all others -> open a new window
-		    emit sigCommand(_("newwindow(") +
-		                    Kwave::Parser::escape(filename) +
-		                    _(")"));
-		}
-	    }
-	}
     }
-
-    qDebug("MainWidget::dropEvent(): done");
 }
 
 //***************************************************************************
@@ -311,6 +324,12 @@ void Kwave::MainWidget::wheelEvent(QWheelEvent *event)
     }
 }
 
+//***************************************************************************
+void Kwave::MainWidget::closeEvent(QCloseEvent *e)
+{
+    m_context.closeFile() ? e->accept() : e->ignore();
+}
+
 //***************************************************************************
 void Kwave::MainWidget::slotTrackInserted(unsigned int index,
                                           Kwave::Track *track)
@@ -356,24 +375,24 @@ int Kwave::MainWidget::executeCommand(const QString &command)
     if (!command.length()) return -EINVAL;
 
     Kwave::Parser parser(command);
-    const sample_index_t visible_samples = displaySamples();
+    const sample_index_t visible_samples = visibleSamples();
     const sample_index_t signal_length   = signal_manager->length();
 
     if (false) {
 
     // -- zoom --
+    CASE_COMMAND("view:zoom_selection")
+	zoomSelection();
     CASE_COMMAND("view:zoom_in")
 	int x = parser.hasParams() ? parser.toInt() : -1;
 	zoomIn(x);
     CASE_COMMAND("view:zoom_out")
 	int x = parser.hasParams() ? parser.toInt() : -1;
 	zoomOut(x);
-    CASE_COMMAND("view:zoom_selection")
-	zoomSelection();
-    CASE_COMMAND("view:zoom_all")
-	zoomAll();
     CASE_COMMAND("view:zoom_normal")
 	zoomNormal();
+    CASE_COMMAND("view:zoom_all")
+	zoomAll();
 
     // -- navigation --
     CASE_COMMAND("goto")
@@ -417,7 +436,7 @@ int Kwave::MainWidget::executeCommand(const QString &command)
 	signal_manager->selectRange(0, signal_manager->length());
     CASE_COMMAND("selectnext")
 	if (signal_manager->selection().length())
-	    signal_manager->selectRange(signal_manager->selection().last()+1,
+	    signal_manager->selectRange(signal_manager->selection().last() + 1,
 	                signal_manager->selection().length());
 	else
 	    signal_manager->selectRange(signal_manager->length() - 1, 0);
@@ -434,15 +453,21 @@ int Kwave::MainWidget::executeCommand(const QString &command)
 	    signal_manager->length() - signal_manager->selection().first()
 	);
     CASE_COMMAND("selectvisible")
-	signal_manager->selectRange(m_offset, displaySamples());
+	signal_manager->selectRange(m_offset, visibleSamples());
     CASE_COMMAND("selectnone")
 	signal_manager->selectRange(m_offset, 0);
 
     // label handling
     CASE_COMMAND("add_label")
 	sample_index_t pos = parser.toSampleIndex();
-	QString description = parser.nextParam();
-	addLabel(pos, description);
+	if (!parser.isDone()) {
+	    // 2 parameters: position + description
+	    QString description = parser.nextParam();
+	    signal_manager->addLabel(pos, description);
+	} else {
+	    // 1 parameter only: open dialog for editing the description
+	    addLabel(pos, QString());
+	}
     CASE_COMMAND("edit_label")
 	int index = parser.toInt();
 	Kwave::LabelList labels(signal_manager->metaData());
@@ -494,7 +519,7 @@ void Kwave::MainWidget::refreshHorizontalScrollBar()
     if (m_context.signalManager()->length() > 1) {
 	// get the view information in samples
 	sample_index_t length  = m_context.signalManager()->length();
-	sample_index_t visible = displaySamples();
+	sample_index_t visible = visibleSamples();
 	if (visible > length) visible = length;
 
 	// calculate the scrollbar ranges in scrollbar's units
@@ -557,7 +582,7 @@ void Kwave::MainWidget::updateViewRange()
     sample_index_t total = (signal_manager) ? signal_manager->length() : 0;
 
     if (m_overview) {
-	m_overview->setRange(m_offset, displaySamples(), total);
+	m_overview->setRange(m_offset, visibleSamples(), total);
 
 	// show/hide the overview widget and the horizontal scroll bar
 	if (!m_context.signalManager()->isEmpty()) {
@@ -607,21 +632,21 @@ int Kwave::MainWidget::samples2pixels(sample_index_t samples) const
 }
 
 //***************************************************************************
-int Kwave::MainWidget::viewPortWidth() const
+int Kwave::MainWidget::visibleWidth() const
 {
-    return m_signal_widget.viewPortWidth();
+    return m_signal_widget.visibleWidth();
 }
 
 //***************************************************************************
-sample_index_t Kwave::MainWidget::displaySamples() const
+sample_index_t Kwave::MainWidget::visibleSamples() const
 {
-    return pixels2samples(viewPortWidth() - 1) + 1;
+    return pixels2samples(visibleWidth() - 1) + 1;
 }
 
 //***************************************************************************
 double Kwave::MainWidget::fullZoom() const
 {
-    const int width = viewPortWidth();
+    const int width = visibleWidth();
     if (width <= 0) return 0.0; // no zoom info, window is not yet ready
 
     Kwave::SignalManager *signal_manager = m_context.signalManager();
@@ -646,6 +671,7 @@ double Kwave::MainWidget::fullZoom() const
 		signal_manager->rate()));
 	}
     }
+    if (!length) return 0; // still no length !? -> bail out
 
     // example: width = 100 [pixels] and length = 3 [samples]
     //          -> samples should be at positions 0, 49.5 and 99
@@ -672,7 +698,7 @@ void Kwave::MainWidget::fixZoomAndOffset(double zoom, sample_index_t offset)
 
     const double         old_zoom   = m_zoom;
     const sample_index_t old_offset = m_offset;
-    const int            width      = viewPortWidth();
+    const int            width      = visibleWidth();
 
     m_zoom   = zoom;
     m_offset = offset;
@@ -732,7 +758,7 @@ void Kwave::MainWidget::fixZoomAndOffset(double zoom, sample_index_t offset)
     if (!qFuzzyCompare(m_zoom, old_zoom)) emit sigZoomChanged(m_zoom);
 
     if ((m_offset != old_offset) || !qFuzzyCompare(m_zoom, old_zoom)) {
-	emit sigVisibleRangeChanged(m_offset, displaySamples(), length);
+	emit sigVisibleRangeChanged(m_offset, visibleSamples(), length);
 	updateViewRange();
     }
 }
@@ -752,7 +778,7 @@ void Kwave::MainWidget::setOffset(sample_index_t new_offset)
 //***************************************************************************
 void Kwave::MainWidget::scrollTo(sample_index_t pos)
 {
-    sample_index_t visible = displaySamples();
+    sample_index_t visible = visibleSamples();
 
     if ( (pos < (m_offset + (visible / 10))) ||
 	 (pos > (m_offset + (visible /  2))) )
@@ -781,7 +807,7 @@ void Kwave::MainWidget::zoomSelection()
     sample_index_t len = signal_manager->selection().length();
 
     if (len) {
-	int width = viewPortWidth();
+	int width = visibleWidth();
 	m_offset = ofs;
 	setZoom((static_cast<double>(len)) / static_cast<double>(width - 1));
     }
@@ -796,8 +822,8 @@ void Kwave::MainWidget::zoomAll()
 //***************************************************************************
 void Kwave::MainWidget::zoomNormal()
 {
-    const sample_index_t shift1 = viewPortWidth() / 2;
-    const sample_index_t shift2 = displaySamples() / 2;
+    const sample_index_t shift1 = visibleWidth() / 2;
+    const sample_index_t shift2 = visibleSamples() / 2;
     m_offset = (m_offset + shift2 >= m_offset) ? (m_offset + shift2) : -shift2;
     m_offset = (m_offset > shift1) ? (m_offset - shift1) : 0;
     setZoom(1.0);
@@ -818,7 +844,7 @@ void Kwave::MainWidget::zoomIn(int pos)
 	// no position given, show centered
 	fixZoomAndOffset(
 	    m_zoom / 3,
-	    m_offset + (displaySamples() / 3)
+	    m_offset + (visibleSamples() / 3)
 	);
     }
 }
@@ -835,7 +861,7 @@ void Kwave::MainWidget::zoomOut(int pos)
 	shift = Kwave::toInt(m_zoom * 2.0) * pos;
     } else {
 	// no position given, show centered
-	shift = displaySamples();
+	shift = visibleSamples();
     }
     fixZoomAndOffset(
 	m_zoom * 3,
