@@ -15,18 +15,26 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _MAIN_WIDGET_H_
-#define _MAIN_WIDGET_H_
+#ifndef MAIN_WIDGET_H
+#define MAIN_WIDGET_H
 
 #include "config.h"
 
 #include <QtCore/QString>
+#include <QtCore/QSize>
+#include <QtCore/QTimer>
+
 #include <QtGui/QScrollArea>
 #include <QtGui/QVBoxLayout>
 #include <QtGui/QWidget>
 
-#include "libgui/SignalWidget.h"
+#include "libkwave/CommandHandler.h"
 
+#include "libgui/MouseMark.h"
+#include "libgui/SignalWidget.h"
+#include "libgui/Zoomable.h"
+
+class QCloseEvent;
 class QDragEnterEvent;
 class QDropEvent;
 class QScrollBar;
@@ -35,7 +43,7 @@ class QWheelEvent;
 namespace Kwave
 {
 
-    class ApplicationContext;
+    class FileContext;
     class OverViewWidget;
     class SignalManager;
 
@@ -73,7 +81,9 @@ namespace Kwave
      * \-----------------------------------------------------------------------/
      * @endcode
      */
-    class MainWidget : public QWidget
+    class MainWidget : public QWidget,
+                       public CommandHandler,
+                       public Zoomable
     {
 	Q_OBJECT
     public:
@@ -82,8 +92,12 @@ namespace Kwave
 	 * Constructor.
 	 * @param parent parent widget
 	 * @param context reference to the context of this instance
+	 * @param preferred_size preferred size of the widget,
+	 *                       needed in MDI mode, otherwise ignored
 	 */
-	MainWidget(QWidget *parent, Kwave::ApplicationContext &context);
+	MainWidget(QWidget *parent,
+	           Kwave::FileContext &context,
+	           const QSize &preferred_size);
 
 	/**
 	 * Returns true if this instance was successfully initialized, or
@@ -95,13 +109,19 @@ namespace Kwave
 	virtual ~MainWidget();
 
 	/** Returns the current zoom factor [samples/pixel] */
-	double zoom() const;
+	virtual double zoom() const;
 
 	/** Returns the width of the current view in pixels */
-	int viewPortWidth() const;
+	virtual int visibleWidth() const;
 
 	/** Returns the width of the current view in samples */
-	sample_index_t displaySamples() const;
+	virtual sample_index_t visibleSamples() const;
+
+	/** Returns the current start position of the visible area [samples] */
+	virtual sample_index_t visibleOffset() { return m_offset; }
+
+	/** Returns the preferred size of the widget */
+	virtual QSize sizeHint () const { return m_preferred_size; }
 
     protected:
 
@@ -123,6 +143,9 @@ namespace Kwave
 	/** slot for mouse wheel events, for scrolling/zooming */
 	virtual void wheelEvent(QWheelEvent *event);
 
+	/** @see QWidget::closeEvent() */
+	virtual void closeEvent(QCloseEvent *e);
+
     protected slots:
 
 	/** updates all widgets that depend on the current view range */
@@ -137,7 +160,7 @@ namespace Kwave
 	 * @retval -ENOSYS is returned if the command is unknown in this
 	 *                 component
 	 */
-	int executeCommand(const QString &command);
+	virtual int executeCommand(const QString &command);
 
 	/**
 	 * Sets the display offset [samples] and refreshes the screen.
@@ -150,7 +173,7 @@ namespace Kwave
 	 * Scrolls the display so that the given position gets visible,
 	 * centered within the display if possible.
 	 */
-	void scrollTo(sample_index_t pos);
+	virtual void scrollTo(sample_index_t pos);
 
 	/**
 	 * sets a new zoom factor [samples/pixel], does not refresh the screen
@@ -235,6 +258,15 @@ namespace Kwave
 	void sigVisibleRangeChanged(sample_index_t offset,
 	                            sample_index_t visible,
 	                            sample_index_t total);
+	/**
+	 * Emits a change in the mouse cursor (forwarded from SignalView).
+	 * @see Kwave::SignalView
+	 * @param mode one of the modes in enum MouseMode
+	 * @param offset selection start (not valid if mode is MouseNormal)
+	 * @param length selection length (not valid if mode is MouseNormal)
+	 */
+	void sigMouseChanged(Kwave::MouseMark::Mode mode,
+	                     sample_index_t offset, sample_index_t length);
 
     private:
 
@@ -297,7 +329,7 @@ namespace Kwave
     private:
 
 	/** context of the Kwave application instance */
-	Kwave::ApplicationContext &m_context;
+	Kwave::FileContext &m_context;
 
 	/** upper docking area, managed by the signal widget */
 	QVBoxLayout m_upper_dock;
@@ -326,10 +358,15 @@ namespace Kwave
 	/** number of samples per pixel */
 	double m_zoom;
 
+	/** preferred size of the widget */
+	QSize m_preferred_size;
+
+	/** timer for delayed update */
+	QTimer m_delayed_update_timer;
     };
 }
 
-#endif /* _MAIN_WIDGET_H_ */
+#endif /* MAIN_WIDGET_H */
 
 //***************************************************************************
 //***************************************************************************
