@@ -69,10 +69,6 @@ static void addDataStrings(KAboutData &aboutdata)
                      "joerg@chaosdorf.de",
                      0);
 
-    // translators
-    aboutdata.setTranslator(ki18n("NAME OF TRANSLATORS"),
-                            ki18n("EMAIL OF TRANSLATORS"));
-
     // people who helped
     aboutdata.addCredit(ki18n("Stefan Westerfeld"),
                      ki18n("Author of aRts"),
@@ -146,6 +142,7 @@ int main( int argc, char **argv )
     options.add("disable-splashscreen", ki18n("Disable the Splash Screen"), 0);
     options.add("iconic",               ki18n("Start Kwave iconified"), 0);
     options.add("logfile <file>",       ki18n("Log all commands into a file"));
+    options.add("gui <sdi|mdi|tab>",    ki18n("GUI type: SDI, MDI or TAB mode"));
     options.add("!+files",              ki18n("List of audio files"), 0 );
 
     KAboutData about(
@@ -161,7 +158,7 @@ int main( int argc, char **argv )
     );
     addDataStrings(about);
 
-    /* process all interesting commandline parameters */
+    /* process all interesting command line parameters */
     KCmdLineArgs::init(argc, argv, &about);
     KCmdLineArgs::addCmdLineOptions(options);
     Kwave::App::addCmdLineOptions();
