@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _FILTER_PLUGIN_H_
-#define _FILTER_PLUGIN_H_
+#ifndef FILTER_PLUGIN_H
+#define FILTER_PLUGIN_H
 
 #include "config.h"
 
@@ -43,7 +43,7 @@ namespace Kwave
     public:
 
 	/** Constructor */
-	FilterPlugin(Kwave::PluginManager &plugin_manager);
+	explicit FilterPlugin(Kwave::PluginManager &plugin_manager);
 
 	/** Destructor */
 	virtual ~FilterPlugin();
@@ -140,7 +140,7 @@ namespace Kwave
     };
 }
 
-#endif /* _FILTER_PLUGIN_H_ */
+#endif /* FILTER_PLUGIN_H */
 
 //***************************************************************************
 //***************************************************************************
