@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _HMS_TIME_WIDGET_H_
-#define _HMS_TIME_WIDGET_H_
+#ifndef HMS_TIME_WIDGET_H
+#define HMS_TIME_WIDGET_H
 
 #include "config.h"
 
@@ -36,7 +36,7 @@ namespace Kwave
     public:
 
 	/** Constructor */
-	HMSTimeWidget(QWidget *parent);
+	explicit HMSTimeWidget(QWidget *parent);
 
 	/** Destructor */
 	virtual ~HMSTimeWidget();
@@ -81,7 +81,7 @@ namespace Kwave
     };
 }
 
-#endif /* _HMS_TIME_WIDGET_H_ */
+#endif /* HMS_TIME_WIDGET_H */
 
 //***************************************************************************
 //***************************************************************************
