@@ -65,6 +65,12 @@ void Kwave::ImageView::mouseMoveEvent(QMouseEvent *e)
     emit sigCursorPos(QPoint(x, y));
 }
 
+//****************************************************************************
+void Kwave::ImageView::mousePressEvent(QMouseEvent *e)
+{
+    mouseMoveEvent(e);
+}
+
 //****************************************************************************
 void Kwave::ImageView::setImage(QImage image)
 {
