@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _LABEL_ITEM_H_
-#define _LABEL_ITEM_H_
+#ifndef LABEL_ITEM_H
+#define LABEL_ITEM_H
 
 #include "config.h"
 
@@ -101,7 +101,7 @@ namespace Kwave
 
 }
 
-#endif /* _LABEL_ITEM_H_ */
+#endif /* LABEL_ITEM_H */
 
 //***************************************************************************
 //***************************************************************************
