@@ -43,7 +43,7 @@ Kwave::MenuItem::MenuItem(Kwave::MenuNode *parent,
     Q_ASSERT(parent);
     if (!parent) return;
 
-    m_action.setText(i18n(__(name)));
+    m_action.setText(i18nc(UTF8(_("menu: ") + path()), UTF8(name)));
     if (shortcut) m_action.setShortcut(shortcut);
 
     connect(&m_action, SIGNAL(triggered(bool)),
@@ -65,26 +65,8 @@ void Kwave::MenuItem::actionTriggered(bool checked)
 //*****************************************************************************
 void Kwave::MenuItem::actionSelected()
 {
-    if (isCheckable()) {
-	Kwave::MenuGroup *group = 0;
-
-	if (m_exclusive_group.length()) {
-	    Kwave::MenuNode *root = getRootNode();
-	    if (root) {
-		group = qobject_cast<Kwave::MenuGroup *>(
-		    root->findUID(m_exclusive_group)
-		);
-	    }
-	}
-
-	if (group) {
-	    // exclusive check == selection
-	    group->selectItem(uid());
-	} else {
-	    // normal check, maybe multiple
-	    setChecked(true);
-	}
-    }
+    if (isCheckable() && !m_exclusive_group.length())
+	setChecked(true);
 
     Kwave::MenuNode::actionSelected();
 }
@@ -92,21 +74,19 @@ void Kwave::MenuItem::actionSelected()
 //*****************************************************************************
 bool Kwave::MenuItem::specialCommand(const QString &command)
 {
+    Kwave::Parser parser(command);
 
-    if (command.startsWith(_("#checkable"))) {
+    if (command == _("#checkable")) {
 	// checking/selecting of the item (non-exclusive)
 	setCheckable(true);
     }
-
-    if (command.startsWith(_("#exclusive("))) {
-	Kwave::Parser parser(command);
-
+    else if (parser.command() == _("#exclusive")) {
 	// join to a list of groups
 	QString group = parser.firstParam();
 	while (group.length()) {
 	    if (!m_exclusive_group.length()) {
 		m_exclusive_group = group;
-		joinGroup(group);
+		joinGroup(group, Kwave::MenuGroup::EXCLUSIVE);
 	    } else if (m_exclusive_group != group) {
 		qWarning("menu item '%s' already member of "
 			"exclusive group '%s'",
@@ -119,10 +99,19 @@ bool Kwave::MenuItem::specialCommand(const QString &command)
 	setCheckable(true);
 	return true;
     }
+    else if (command == _("#hidden")) {
+	setVisible(false);
+    }
 
     return (Kwave::MenuNode::specialCommand(command));
 }
 
+//*****************************************************************************
+void Kwave::MenuItem::setVisible(bool visible)
+{
+    m_action.setVisible(visible);
+}
+
 //*****************************************************************************
 bool Kwave::MenuItem::isEnabled()
 {
