@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _MENU_ITEM_H_
-#define _MENU_ITEM_H_
+#ifndef MENU_ITEM_H
+#define MENU_ITEM_H
 
 #include "config.h"
 
@@ -68,6 +68,12 @@ namespace Kwave
 	 */
 	virtual bool specialCommand(const QString &command);
 
+	/**
+	 * Shows/hides the current menu node.
+	 * @param visible true to show the item, false to hide
+	 */
+	virtual void setVisible(bool visible);
+
 	/**
 	 * Returns true if the node is enabled.
 	 */
