@@ -16,6 +16,8 @@
  ***************************************************************************/
 
 #include "config.h"
+
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -40,7 +42,7 @@
 QMap<QString, QKeySequence> Kwave::MenuManager::m_standard_keys;
 
 /** helper macro for inserting an entry into the m_standard_keys map */
-#define _INS(n,v) m_standard_keys.insert(_(n), v)
+#define INS(n,v) m_standard_keys.insert(_(n), v)
 
 //***************************************************************************
 Kwave::MenuManager::MenuManager(QWidget *parent, KMenuBar &bar)
@@ -50,8 +52,8 @@ Kwave::MenuManager::MenuManager(QWidget *parent, KMenuBar &bar)
     Q_ASSERT(m_menu_root);
     if (m_menu_root) {
 	connect(
-	    m_menu_root, SIGNAL(sigCommand(const QString &)),
-	    this, SIGNAL(sigMenuCommand(const QString &)),
+	    m_menu_root, SIGNAL(sigCommand(QString)),
+	    this, SIGNAL(sigMenuCommand(QString)),
 	    Qt::QueuedConnection
 	);
     }
@@ -63,79 +65,79 @@ Kwave::MenuManager::MenuManager(QWidget *parent, KMenuBar &bar)
     //       list.txt and then:
     //
     // cat list.txt | sed s/^\ \ //g | cut -d \  -f 1 | cut -d \: -f 3 |
-    // awk '{ print "\t_INS(\""$0"\", QKeySequence::"$0");"}'
+    // awk '{ print "\tINS(\""$0"\", QKeySequence::"$0");"}'
 
     if (m_standard_keys.isEmpty()) {
-	_INS("UnknownKey",            QKeySequence::UnknownKey);
-	_INS("HelpContents",          QKeySequence::HelpContents);
-	_INS("WhatsThis",             QKeySequence::WhatsThis);
-	_INS("Open",                  QKeySequence::Open);
-	_INS("Close",                 QKeySequence::Close);
-	_INS("Save",                  QKeySequence::Save);
-	_INS("New",                   QKeySequence::New);
-	_INS("Delete",                QKeySequence::Delete);
-	_INS("Cut",                   QKeySequence::Cut);
-	_INS("Copy",                  QKeySequence::Copy);
-	_INS("Paste",                 QKeySequence::Paste);
-	_INS("Undo",                  QKeySequence::Undo);
-	_INS("Redo",                  QKeySequence::Redo);
-	_INS("Back",                  QKeySequence::Back);
-	_INS("Forward",               QKeySequence::Forward);
-	_INS("Refresh",               QKeySequence::Refresh);
-	_INS("ZoomIn",                QKeySequence::ZoomIn);
-	_INS("ZoomOut",               QKeySequence::ZoomOut);
-	_INS("Print",                 QKeySequence::Print);
-	_INS("AddTab",                QKeySequence::AddTab);
-	_INS("NextChild",             QKeySequence::NextChild);
-	_INS("PreviousChild",         QKeySequence::PreviousChild);
-	_INS("Find",                  QKeySequence::Find);
-	_INS("FindNext",              QKeySequence::FindNext);
-	_INS("FindPrevious",          QKeySequence::FindPrevious);
-	_INS("Replace",               QKeySequence::Replace);
-	_INS("SelectAll",             QKeySequence::SelectAll);
-	_INS("Bold",                  QKeySequence::Bold);
-	_INS("Italic",                QKeySequence::Italic);
-	_INS("Underline",             QKeySequence::Underline);
-	_INS("MoveToNextChar",        QKeySequence::MoveToNextChar);
-	_INS("MoveToPreviousChar",    QKeySequence::MoveToPreviousChar);
-	_INS("MoveToNextWord",        QKeySequence::MoveToNextWord);
-	_INS("MoveToPreviousWord",    QKeySequence::MoveToPreviousWord);
-	_INS("MoveToNextLine",        QKeySequence::MoveToNextLine);
-	_INS("MoveToPreviousLine",    QKeySequence::MoveToPreviousLine);
-	_INS("MoveToNextPage",        QKeySequence::MoveToNextPage);
-	_INS("MoveToPreviousPage",    QKeySequence::MoveToPreviousPage);
-	_INS("MoveToStartOfLine",     QKeySequence::MoveToStartOfLine);
-	_INS("MoveToEndOfLine",       QKeySequence::MoveToEndOfLine);
-	_INS("MoveToStartOfBlock",    QKeySequence::MoveToStartOfBlock);
-	_INS("MoveToEndOfBlock",      QKeySequence::MoveToEndOfBlock);
-	_INS("MoveToStartOfDocument", QKeySequence::MoveToStartOfDocument);
-	_INS("MoveToEndOfDocument",   QKeySequence::MoveToEndOfDocument);
-	_INS("SelectNextChar",        QKeySequence::SelectNextChar);
-	_INS("SelectPreviousChar",    QKeySequence::SelectPreviousChar);
-	_INS("SelectNextWord",        QKeySequence::SelectNextWord);
-	_INS("SelectPreviousWord",    QKeySequence::SelectPreviousWord);
-	_INS("SelectNextLine",        QKeySequence::SelectNextLine);
-	_INS("SelectPreviousLine",    QKeySequence::SelectPreviousLine);
-	_INS("SelectNextPage",        QKeySequence::SelectNextPage);
-	_INS("SelectPreviousPage",    QKeySequence::SelectPreviousPage);
-	_INS("SelectStartOfLine",     QKeySequence::SelectStartOfLine);
-	_INS("SelectEndOfLine",       QKeySequence::SelectEndOfLine);
-	_INS("SelectStartOfBlock",    QKeySequence::SelectStartOfBlock);
-	_INS("SelectEndOfBlock",      QKeySequence::SelectEndOfBlock);
-	_INS("SelectStartOfDocument", QKeySequence::SelectStartOfDocument);
-	_INS("SelectEndOfDocument",   QKeySequence::SelectEndOfDocument);
-	_INS("DeleteStartOfWord",     QKeySequence::DeleteStartOfWord);
-	_INS("DeleteEndOfWord",       QKeySequence::DeleteEndOfWord);
-	_INS("DeleteEndOfLine",       QKeySequence::DeleteEndOfLine);
+	INS("UnknownKey",            QKeySequence::UnknownKey);
+	INS("HelpContents",          QKeySequence::HelpContents);
+	INS("WhatsThis",             QKeySequence::WhatsThis);
+	INS("Open",                  QKeySequence::Open);
+	INS("Close",                 QKeySequence::Close);
+	INS("Save",                  QKeySequence::Save);
+	INS("New",                   QKeySequence::New);
+	INS("Delete",                QKeySequence::Delete);
+	INS("Cut",                   QKeySequence::Cut);
+	INS("Copy",                  QKeySequence::Copy);
+	INS("Paste",                 QKeySequence::Paste);
+	INS("Undo",                  QKeySequence::Undo);
+	INS("Redo",                  QKeySequence::Redo);
+	INS("Back",                  QKeySequence::Back);
+	INS("Forward",               QKeySequence::Forward);
+	INS("Refresh",               QKeySequence::Refresh);
+	INS("ZoomIn",                QKeySequence::ZoomIn);
+	INS("ZoomOut",               QKeySequence::ZoomOut);
+	INS("Print",                 QKeySequence::Print);
+	INS("AddTab",                QKeySequence::AddTab);
+	INS("NextChild",             QKeySequence::NextChild);
+	INS("PreviousChild",         QKeySequence::PreviousChild);
+	INS("Find",                  QKeySequence::Find);
+	INS("FindNext",              QKeySequence::FindNext);
+	INS("FindPrevious",          QKeySequence::FindPrevious);
+	INS("Replace",               QKeySequence::Replace);
+	INS("SelectAll",             QKeySequence::SelectAll);
+	INS("Bold",                  QKeySequence::Bold);
+	INS("Italic",                QKeySequence::Italic);
+	INS("Underline",             QKeySequence::Underline);
+	INS("MoveToNextChar",        QKeySequence::MoveToNextChar);
+	INS("MoveToPreviousChar",    QKeySequence::MoveToPreviousChar);
+	INS("MoveToNextWord",        QKeySequence::MoveToNextWord);
+	INS("MoveToPreviousWord",    QKeySequence::MoveToPreviousWord);
+	INS("MoveToNextLine",        QKeySequence::MoveToNextLine);
+	INS("MoveToPreviousLine",    QKeySequence::MoveToPreviousLine);
+	INS("MoveToNextPage",        QKeySequence::MoveToNextPage);
+	INS("MoveToPreviousPage",    QKeySequence::MoveToPreviousPage);
+	INS("MoveToStartOfLine",     QKeySequence::MoveToStartOfLine);
+	INS("MoveToEndOfLine",       QKeySequence::MoveToEndOfLine);
+	INS("MoveToStartOfBlock",    QKeySequence::MoveToStartOfBlock);
+	INS("MoveToEndOfBlock",      QKeySequence::MoveToEndOfBlock);
+	INS("MoveToStartOfDocument", QKeySequence::MoveToStartOfDocument);
+	INS("MoveToEndOfDocument",   QKeySequence::MoveToEndOfDocument);
+	INS("SelectNextChar",        QKeySequence::SelectNextChar);
+	INS("SelectPreviousChar",    QKeySequence::SelectPreviousChar);
+	INS("SelectNextWord",        QKeySequence::SelectNextWord);
+	INS("SelectPreviousWord",    QKeySequence::SelectPreviousWord);
+	INS("SelectNextLine",        QKeySequence::SelectNextLine);
+	INS("SelectPreviousLine",    QKeySequence::SelectPreviousLine);
+	INS("SelectNextPage",        QKeySequence::SelectNextPage);
+	INS("SelectPreviousPage",    QKeySequence::SelectPreviousPage);
+	INS("SelectStartOfLine",     QKeySequence::SelectStartOfLine);
+	INS("SelectEndOfLine",       QKeySequence::SelectEndOfLine);
+	INS("SelectStartOfBlock",    QKeySequence::SelectStartOfBlock);
+	INS("SelectEndOfBlock",      QKeySequence::SelectEndOfBlock);
+	INS("SelectStartOfDocument", QKeySequence::SelectStartOfDocument);
+	INS("SelectEndOfDocument",   QKeySequence::SelectEndOfDocument);
+	INS("DeleteStartOfWord",     QKeySequence::DeleteStartOfWord);
+	INS("DeleteEndOfWord",       QKeySequence::DeleteEndOfWord);
+	INS("DeleteEndOfLine",       QKeySequence::DeleteEndOfLine);
     }
 }
 
 //***************************************************************************
-void Kwave::MenuManager::executeCommand(const QString &command)
+int Kwave::MenuManager::executeCommand(const QString &command)
 {
 
     Q_ASSERT(command.length());
-    if (!m_menu_root) return; // makes no sense if no menu root
+    if (!m_menu_root) return -EINVAL; // makes no sense if no menu root
 
     Kwave::Parser parser(command);
 
@@ -152,7 +154,7 @@ void Kwave::MenuManager::executeCommand(const QString &command)
     // bail out if no menu position is found
     if (!pos.length()) {
 	qWarning("no position field !");
-	return ;
+	return -EINVAL;
     }
 
     // --- 3rd parameter: bitmask for the key shortcut (optional) ---
@@ -205,6 +207,8 @@ void Kwave::MenuManager::executeCommand(const QString &command)
 
     // --- insert the new node into the menu structure ---
     m_menu_root->insertNode(QString(), pos, com, shortcut, id);
+
+    return 0;
 }
 
 //***************************************************************************
@@ -223,12 +227,12 @@ void Kwave::MenuManager::addNumberedMenuEntry(const QString &uid,
 
     Q_ASSERT(m_menu_root);
     Kwave::MenuNode *node = (m_menu_root) ? m_menu_root->findUID(uid) : 0;
-    if (node) {
+    Kwave::MenuNode *parent = (node) ? node->parentNode() : 0;
+    if (parent) {
 	QString cmd     = node->command();
 	QString command = cmd.contains(_("%1")) ?
 	    cmd.arg(Kwave::Parser::escape(entry)) : cmd;
-
-	node->insertLeaf(entry, command, 0, QString());
+	node->insertLeaf(entry, command, 0, uid);
     } else
 	qWarning("MenuManager: could not find numbered Menu '%s'", DBG(uid));
 
@@ -237,31 +241,31 @@ void Kwave::MenuManager::addNumberedMenuEntry(const QString &uid,
 //***************************************************************************
 void Kwave::MenuManager::selectItem(const QString &group, const QString &uid)
 {
+    if (!m_menu_root)
+	return;
+
     if (!group.length()) {
 	qWarning("MenuManager::selectItem('','%s'): no group!?", DBG(uid));
-	return ;
+	return;
     }
 
     if (group[0] != QLatin1Char('@')) {
 	qWarning("MenuManager::selectItem('%s','%s'): "
 		"invalid group name, does not start with '@'!",
 		DBG(group), DBG(uid));
-	return ;
+	return;
     }
 
-    Kwave::MenuNode *node = (m_menu_root) ? m_menu_root->findUID(group) : 0;
-    if (!node) {
+    QHash<QString, Kwave::MenuGroup *> &groups = m_menu_root->groupList();
+    if (!groups.contains(group)) {
 	qWarning("MenuManager::selectItem(): group '%s' not found!",
 	         DBG(group));
-	return ;
+	return;
     }
 
-    if (!qobject_cast<Kwave::MenuGroup *>(node)) {
-	qWarning("MenuManager::selectItem(): '%s' is not a group!", DBG(group));
-	return ;
-    }
-
-    (reinterpret_cast<Kwave::MenuGroup *>(node))->selectItem(uid);
+    Kwave::MenuGroup *group_node = groups[group];
+    Q_ASSERT(group_node);
+    if (group_node) group_node->selectItem(uid);
 }
 
 //***************************************************************************
@@ -279,14 +283,46 @@ void Kwave::MenuManager::setItemText(const QString &uid, const QString &text)
 }
 
 //***************************************************************************
-void Kwave::MenuManager::setItemEnabled(const QString &uid, bool enable)
+void Kwave::MenuManager::setItemVisible(const QString &uid, bool show)
 {
     if (!m_menu_root) return;
 
     Kwave::MenuNode *node = m_menu_root->findUID(uid);
-    if (node) node->setEnabled(enable);
-    else qWarning("MenuManager::setItemEnabled('%s', '%d'): uid not found!",
-		  DBG(uid), enable);
+    if (node) {
+	/* show/hide a single menu node */
+	node->setVisible(show);
+    } else {
+	qWarning("MenuManager::setItemVisible('%s', '%d'): uid not found!",
+	         DBG(uid), show);
+    }
+}
+
+//***************************************************************************
+void Kwave::MenuManager::setItemEnabled(const QString &uid, bool enable)
+{
+    if (!m_menu_root) return;
+
+    bool found = false;
+    Kwave::MenuNode *node = m_menu_root->findUID(uid);
+    if (node) {
+	/* enable/disable a single menu node */
+	node->setEnabled(enable);
+	found = true;
+    } else {
+	/* enable/disable a group */
+	QHash<QString, Kwave::MenuGroup *> &groups = m_menu_root->groupList();
+	if (groups.contains(uid)) {
+	    Kwave::MenuGroup *group = groups[uid];
+	    if (group) {
+		group->setEnabled(enable);
+		found = true;
+	    }
+	}
+    }
+
+    if (!found)
+	qWarning("MenuManager::setItemEnabled('%s', '%d'): uid not found!",
+	         DBG(uid), enable);
 }
 
 //***************************************************************************
