@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _MENU_NODE_H_
-#define _MENU_NODE_H_
+#ifndef MENU_NODE_H
+#define MENU_NODE_H
 
 #include "config.h"
 
@@ -28,23 +28,24 @@
 #include <QtCore/QString>
 #include <QtCore/QStringList>
 
+#include "libgui/MenuGroup.h"
+
 class QAction;
 
 namespace Kwave
 {
 
-    class MenuGroup;
     class MenuSub;
 
     /**
-     * Base class for the MenuRoot, MenuEntry, SubMenu and
-     * the ToplevelMenu class.
+     * Base class for the MenuItem, MenuSub and the MenuRoot class.
      */
     class MenuNode: public QObject
     {
 	Q_OBJECT
 
     public:
+
 	/**
 	 * Constructor.
 	 * @param parent pointer to the node's parent (might be 0)
@@ -66,6 +67,9 @@ namespace Kwave
 	 */
 	virtual ~MenuNode();
 
+	/** Returns the path of this menu entry */
+	const QString path() const;
+
 	/** Returns the (non-localized) name of the node. */
 	inline const QString &name() const { return m_name; }
 
@@ -123,6 +127,12 @@ namespace Kwave
 	/** returns a pointer to the menu's parent node */
 	virtual Kwave::MenuNode *parentNode() const;
 
+	/**
+	 * Shows/hides the current menu node.
+	 * @param visible true to show the item, false to hide
+	 */
+	virtual void setVisible(bool visible);
+
 	/**
 	 * Returns true if the node is enabled.
 	 */
@@ -163,7 +173,7 @@ namespace Kwave
 	Kwave::MenuNode *findChild(const QString &name);
 
 	/**
-	 * Removes a child node of the curren node. If the child
+	 * Removes a child node of the current node. If the child
 	 * was not found or is already removed this does nothing.
 	 * @param child pointer to the child node
 	 */
@@ -207,8 +217,11 @@ namespace Kwave
 	/**
 	 * Registers a node as a child of the current node.
 	 * @param node pointer to the child node
+	 * @param before the node before which the node should be inserted
+	 *               (optional, can be null for "append")
 	 */
-	virtual void registerChild(Kwave::MenuNode *node);
+	virtual void insertChild(Kwave::MenuNode *node,
+	                         Kwave::MenuNode *before);
 
 	/**
 	 * Inserts a new child node into the structure. If the specified
@@ -251,19 +264,20 @@ namespace Kwave
 
 	/**
 	 * Returns a reference to the list of groups. It recursively calls
-	 * all parent node's getGroupList() function until it reaches the
+	 * all parent node's groupList() function until it reaches the
 	 * root node of the menu structure that holds the list of groups and
 	 * overwrites this function.
 	 * @return reference to the list of groups
 	 */
-	virtual QHash<QString, Kwave::MenuGroup *> &getGroupList();
+	virtual QHash<QString, Kwave::MenuGroup *> &groupList();
 
 	/**
 	 * Adds the node to a group. If it is already a member of the
 	 * group this function will do nothing.
 	 * @param group name of the group
+	 * @param mode the mode of the group (normal or exclusive)
 	 */
-	void joinGroup(const QString &group);
+	void joinGroup(const QString &group, Kwave::MenuGroup::Mode mode);
 
 	/**
 	 * Removes the node from a group (opposite of joinGroup).
@@ -276,13 +290,13 @@ namespace Kwave
 	/**
 	 * Returns the address of the root node of the menu structure.
 	 */
-	Kwave::MenuNode *getRootNode();
+	Kwave::MenuNode *rootNode();
 
 	/**
 	 * Emits a command if the node is the root node. If it is a client
 	 * node it will call the root node's emitCommand() function.
 	 * @see #emitCommand()
-	 * @see #getRootNode()
+	 * @see #rootNode()
 	 */
 	void emitCommand(const QString &command);
 
@@ -293,7 +307,7 @@ namespace Kwave
 	 * root node, client nodes call the root node's emitCommand()
 	 * function.
 	 * @see #emitCommand()
-	 * @see #getRootNode()
+	 * @see #rootNode()
 	 */
 	void sigCommand(const QString &command);
 
