@@ -17,6 +17,8 @@
 
 #include "config.h"
 
+#include <QtCore/QListIterator>
+
 #include <klocale.h>
 #include <kmenubar.h>
 
@@ -44,7 +46,7 @@ Kwave::MenuRoot::~MenuRoot()
 }
 
 //***************************************************************************
-QHash<QString, Kwave::MenuGroup *> &Kwave::MenuRoot::getGroupList()
+QHash<QString, Kwave::MenuGroup *> &Kwave::MenuRoot::groupList()
 {
     return m_group_list;
 }
@@ -58,7 +60,7 @@ void Kwave::MenuRoot::insertNode(const QString &name,
 {
     Kwave::MenuNode::insertNode(name, position, command, shortcut, uid);
 
-    // now delete all leafes that have been converted to branches
+    // now delete all leafs that have been converted to branches
     while (!m_garbage.isEmpty()) {
 	Kwave::MenuNode *node = m_garbage.takeFirst();
 	if (node) delete node;
@@ -80,7 +82,7 @@ Kwave::MenuSub *Kwave::MenuRoot::insertBranch(const QString &name,
     Q_ASSERT(sub);
     if (!sub) return 0;
 
-    registerChild(sub);
+    insertChild(sub, 0);
 
     return sub;
 }
@@ -96,20 +98,56 @@ Kwave::MenuNode *Kwave::MenuRoot::insertLeaf(const QString &name,
     Q_ASSERT(item);
     if (!item) return 0;
 
-    registerChild(item);
+    insertChild(item, 0);
     m_menu_bar.addAction(item->action());
 
     return item;
 }
 
+//***************************************************************************
+void Kwave::MenuRoot::hideChild(Kwave::MenuSub *child)
+{
+    Q_ASSERT(child);
+    if (!child) return;
+    if (!m_children.contains(child)) return;
+    if (groupList().contains(child->name())) return;
+
+    QAction *action = child->action();
+    if (action) m_menu_bar.removeAction(action);
+}
+
+//***************************************************************************
+void Kwave::MenuRoot::showChild(Kwave::MenuSub *child)
+{
+    Q_ASSERT(child);
+    if (!child) return;
+    if (!m_children.contains(child)) return;
+    if (groupList().contains(child->name())) return;
+
+    // find the menu bar entry after which we can insert
+    QAction *action_before = 0;
+    QListIterator<Kwave::MenuNode *> it(m_children);
+    it.toBack();
+    while (it.hasPrevious()) {
+	Kwave::MenuNode *c = it.previous();
+	if (c == child) break;
+	if (c) action_before = c->action();
+    }
+
+    if (action_before)
+	m_menu_bar.insertMenu(action_before, child->menu());
+    else
+	m_menu_bar.addMenu(child->menu());
+}
+
 //***************************************************************************
 void Kwave::MenuRoot::removeChild(Kwave::MenuNode *child)
 {
     Q_ASSERT(child);
-    if (!child) return ;
-    if (!m_children.contains(child)) return ;
+    if (!child) return;
+    if (!m_children.contains(child)) return;
 
-    QHash<QString, Kwave::MenuGroup *> &group_list = getGroupList();
+    QHash<QString, Kwave::MenuGroup *> &group_list = groupList();
     if (!group_list.contains(child->name())) {
         // only remove what has been added to the menu bar,
         // but not menu groups
