@@ -25,6 +25,7 @@
 
 #include "libgui/MenuItem.h"
 #include "libgui/MenuSub.h"
+#include "libgui/MenuRoot.h"
 
 //***************************************************************************
 Kwave::MenuSub::MenuSub(Kwave::MenuNode *parent,
@@ -37,7 +38,7 @@ Kwave::MenuSub::MenuSub(Kwave::MenuNode *parent,
 {
     QAction *act = action();
     Q_ASSERT(act);
-    if (act) act->setText(i18n(__(name)));
+    if (act) act->setText(i18nc(UTF8(_("menu: ") + path()), UTF8(name)));
 }
 
 //***************************************************************************
@@ -45,6 +46,27 @@ Kwave::MenuSub::~MenuSub()
 {
 }
 
+//*****************************************************************************
+void Kwave::MenuSub::setVisible(bool visible)
+{
+    if (!m_menu) return;
+
+    Kwave::MenuRoot *root = qobject_cast<Kwave::MenuRoot *>(rootNode());
+    Q_ASSERT(root);
+    if (root && (parentNode() == root)) {
+	// special case: entries of the main menu can only be made
+	// visible/invisible by adding to/removing from the main menu
+	if (visible) {
+	    root->showChild(this);
+	}
+	else
+	    root->hideChild(this);
+    } else {
+	// normal menu entry
+	m_menu->setVisible(visible);
+    }
+}
+
 //*****************************************************************************
 bool Kwave::MenuSub::isEnabled()
 {
@@ -85,7 +107,7 @@ Kwave::MenuSub *Kwave::MenuSub::insertBranch(const QString &name,
     Q_ASSERT(sub);
     if (!sub) return 0;
 
-    registerChild(sub);
+    insertChild(sub, 0);
 
     return sub;
 }
@@ -105,8 +127,31 @@ Kwave::MenuNode *Kwave::MenuSub::insertLeaf(const QString &name,
     Q_ASSERT(item);
     if (!item) return 0;
 
-    registerChild(item);
-    m_menu->addAction(item->action());
+    /*
+     * find out where to insert the leaf: if there is a placeholder
+     * with the matching uid, insert after that one, otherwise append
+     * to the end
+     */
+    bool found = false;
+    Kwave::MenuNode *child_after = 0;
+    QListIterator<Kwave::MenuNode *> it(m_children);
+    it.toBack();
+    while (!found && it.hasPrevious()) {
+	Kwave::MenuNode *child = it.previous();
+	if (!child) continue;
+	if (uid.length() && ((uid == child->uid()) || (uid == child->name())))
+	    found = true;
+	else if (child->action())
+	    child_after = child;
+    }
+
+    insertChild(item, (found) ? child_after : 0);
+
+    QAction *action_after = (found && child_after) ? child_after->action() : 0;
+    if (action_after)
+	m_menu->insertAction(action_after, item->action());
+    else
+	m_menu->addAction(item->action());
 
     return item;
 }
@@ -114,7 +159,7 @@ Kwave::MenuNode *Kwave::MenuSub::insertLeaf(const QString &name,
 //***************************************************************************
 void Kwave::MenuSub::removeChild(Kwave::MenuNode *child)
 {
-    QAction *act = action();
+    QAction *act = (child) ? child->action() : 0;
     if (act && m_menu) m_menu->removeAction(act);
 
     Kwave::MenuNode::removeChild(child);
@@ -128,8 +173,6 @@ bool Kwave::MenuSub::specialCommand(const QString &command)
 
     if (command.startsWith(_("#exclusive"))) {
 	return true;
-    } else if (command.startsWith(_("#number"))) {
-	return true;
     } else if (command.startsWith(_("#separator"))) {
 	if (m_menu) m_menu->addSeparator();
 	return true;
