@@ -75,7 +75,7 @@ Kwave::OverViewWidget::OverViewWidget(Kwave::SignalManager &signal,
                                       QWidget *parent)
     :Kwave::ImageView(parent), m_view_offset(0), m_view_width(0),
      m_signal_length(0), m_selection_start(0), m_selection_length(0),
-     m_playback_position(0), m_last_offset(0), m_cache(signal),
+     m_playback_position(0), m_last_offset(0), m_cache(signal, 0, 0, 0),
      m_repaint_timer(), m_labels(), m_worker_thread(this)
 {
     // check: start() must be called from the GUI thread only!
@@ -92,7 +92,7 @@ Kwave::OverViewWidget::OverViewWidget(Kwave::SignalManager &signal,
 
     // get informed about selection changes
     connect(&(signal.selection()),
-            SIGNAL(changed(sample_index_t, sample_index_t)),
+            SIGNAL(changed(sample_index_t,sample_index_t)),
             this,
             SLOT(setSelection(sample_index_t,sample_index_t)));
 
@@ -360,7 +360,7 @@ void Kwave::OverViewWidget::calculateBitmap()
 
     int width  = this->width();
     int height = this->height();
-    if (!width || !height || !m_view_width || !length || !m_signal_length)
+    if (!width || !height || !m_view_width || !length)
 	return;
 
     const double scale = static_cast<double>(width) /
