@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _SCALE_WIDGET_H_
-#define _SCALE_WIDGET_H_
+#ifndef SCALE_WIDGET_H
+#define SCALE_WIDGET_H
 
 #include "config.h"
 
@@ -39,7 +39,7 @@ namespace Kwave
 	 * Primitve constructor for usage in a Qt designer's dialog
 	 * @param parent the widget's parent widget
 	 */
-	ScaleWidget(QWidget *parent);
+	explicit ScaleWidget(QWidget *parent);
 
 	/**
 	 * Constructor with initialization.
