@@ -43,7 +43,6 @@
 #include <kfiledialog.h>
 #include <kiconloader.h>
 
-#include "libkwave/ApplicationContext.h"
 #include "libkwave/ClipBoard.h"
 #include "libkwave/LabelList.h"
 #include "libkwave/SignalManager.h"
@@ -85,11 +84,11 @@
 
 //***************************************************************************
 Kwave::SignalWidget::SignalWidget(QWidget *parent,
-                                  Kwave::ApplicationContext &context,
+                                  Kwave::SignalManager *signal_manager,
                                   QVBoxLayout *upper_dock,
                                   QVBoxLayout *lower_dock)
     :QWidget(parent),
-     m_context(context),
+     m_signal_manager(signal_manager),
      m_views(),
      m_layout(this),
      m_upper_dock(upper_dock),
@@ -102,12 +101,12 @@ Kwave::SignalWidget::SignalWidget(QWidget *parent,
 //    qDebug("SignalWidget::SignalWidget()");
 
     // connect to the signal manager's signals
-    Kwave::SignalManager *sig = m_context.signalManager();
+    Kwave::SignalManager *sig = m_signal_manager;
 
-    connect(sig,  SIGNAL(sigTrackInserted(unsigned int, Kwave::Track *)),
-            this, SLOT( slotTrackInserted(unsigned int, Kwave::Track *)));
-    connect(sig,  SIGNAL(sigTrackDeleted(unsigned int, Kwave::Track *)),
-            this, SLOT( slotTrackDeleted(unsigned int, Kwave::Track *)));
+    connect(sig,  SIGNAL(sigTrackInserted(uint,Kwave::Track*)),
+            this, SLOT(slotTrackInserted(uint,Kwave::Track*)));
+    connect(sig,  SIGNAL(sigTrackDeleted(uint,Kwave::Track*)),
+            this, SLOT(slotTrackDeleted(uint,Kwave::Track*)));
 
     // use a timer for limiting the repaint rate
     m_repaint_timer.setSingleShot(true);
@@ -182,12 +181,11 @@ void Kwave::SignalWidget::contextMenuEvent(QContextMenuEvent *e)
 {
     Q_ASSERT(e);
 
-    Kwave::SignalManager *manager = m_context.signalManager();
-    bool have_signal = manager && !manager->isEmpty();
+    bool have_signal = m_signal_manager && !m_signal_manager->isEmpty();
     if (!have_signal)return;
-    bool have_selection = manager && (manager->selection().length() > 1);
-    bool have_labels = manager &&
-	!(Kwave::LabelList(manager->metaData()).isEmpty());
+    bool have_selection = (m_signal_manager->selection().length() > 1);
+    bool have_labels =
+	!(Kwave::LabelList(m_signal_manager->metaData()).isEmpty());
 
     QMenu *context_menu = new QMenu(this);
     Q_ASSERT(context_menu);
@@ -205,7 +203,7 @@ void Kwave::SignalWidget::contextMenuEvent(QContextMenuEvent *e)
 	Qt::CTRL + Qt::Key_Z);
     Q_ASSERT(action);
     if (!action) return;
-    if (!manager || !manager->canUndo())
+    if (!m_signal_manager->canUndo())
 	action->setEnabled(false);
 
     // redo
@@ -215,7 +213,7 @@ void Kwave::SignalWidget::contextMenuEvent(QContextMenuEvent *e)
 	Qt::CTRL + Qt::Key_Y);
     Q_ASSERT(action);
     if (!action) return;
-    if (!manager || !manager->canRedo())
+    if (!m_signal_manager->canRedo())
 	action->setEnabled(false);
     context_menu->addSeparator();
 
@@ -246,7 +244,7 @@ void Kwave::SignalWidget::contextMenuEvent(QContextMenuEvent *e)
     if (mouse_y >= height())  mouse_y = height()  - 1;
 
 
-    QMenu *submenu_select = context_menu->addMenu(i18n("&Selection"));
+    QMenu *submenu_select = context_menu->addMenu(i18n("Selection"));
     Q_ASSERT(submenu_select);
     if (!submenu_select) return;
 
@@ -305,8 +303,8 @@ void Kwave::SignalWidget::contextMenuEvent(QContextMenuEvent *e)
 
 	    // if found, give the item the chance to extend the context menu
 	    if (!item.isNull()) {
-		connect(item.data(), SIGNAL(sigCommand(const QString &)),
-		        this, SLOT(forwardCommand(const QString &)));
+		connect(item.data(), SIGNAL(sigCommand(QString)),
+		        this,        SLOT(forwardCommand(QString)));
 		item->appendContextMenu(context_menu);
 	    }
 
@@ -372,7 +370,7 @@ int Kwave::SignalWidget::mapToViewPort(const QPoint &pos) const
 }
 
 //***************************************************************************
-int Kwave::SignalWidget::viewPortWidth() const
+int Kwave::SignalWidget::visibleWidth() const
 {
     if (m_views.isEmpty()) return width(); // if empty
     return m_layout.cellRect(0, 1).width();
@@ -563,16 +561,17 @@ void Kwave::SignalWidget::insertView(Kwave::SignalView *view,
     view->setZoomAndOffset(m_zoom, m_offset);
 
     // connect all signals
-    QWidget *top_widget = reinterpret_cast<QWidget *>(m_context.topWidget());
-    connect(view,       SIGNAL(sigMouseChanged(Kwave::MouseMark::Mode)),
-	    top_widget, SLOT(mouseChanged(Kwave::MouseMark::Mode)));
+    connect(view,       SIGNAL(sigMouseChanged(Kwave::MouseMark::Mode,
+                                               sample_index_t, sample_index_t)),
+            this,       SIGNAL(sigMouseChanged(Kwave::MouseMark::Mode,
+                                               sample_index_t, sample_index_t)));
 
     connect(view,       SIGNAL(sigCommand(QString)),
 	    this,       SIGNAL(sigCommand(QString)),
 	    Qt::QueuedConnection);
 
-    connect(view,       SIGNAL(sigNeedRepaint(Kwave::SignalView *)),
-	    this,       SLOT(requestRepaint(Kwave::SignalView *)));
+    connect(view,       SIGNAL(sigNeedRepaint(Kwave::SignalView*)),
+	    this,       SLOT(requestRepaint(Kwave::SignalView*)));
 
     connect(view,       SIGNAL(contentSizeChanged()),
 	    this,       SLOT(updateMinimumHeight()));
@@ -596,7 +595,7 @@ void Kwave::SignalWidget::slotTrackInserted(unsigned int index,
 
     // create a new view for the track's signal
     Kwave::SignalView *new_view = new Kwave::TrackView(
-	this, controls, m_context.signalManager(), track);
+	this, controls, m_signal_manager, track);
     Q_ASSERT(new_view);
     if (!new_view) {
 	delete controls;
