@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _TRACK_PIXMAP_H_
-#define _TRACK_PIXMAP_H_
+#ifndef TRACK_PIXMAP_H
+#define TRACK_PIXMAP_H
 
 #include "config.h"
 
@@ -72,7 +72,7 @@ namespace Kwave
     public:
 
 	/** Default constructor */
-	TrackPixmap(Kwave::Track &track);
+	explicit TrackPixmap(Kwave::Track &track);
 
 	/** Destructor */
 	virtual ~TrackPixmap();
@@ -300,7 +300,7 @@ namespace Kwave
 	/**
 	 * Index of the first sample. Needed for converting pixel
 	 * positions into absolute sample numbers. This is always
-	 * in units of samples, independend of the current mode!
+	 * in units of samples, independent of the current mode!
 	 */
 	sample_index_t m_offset;
 
@@ -370,7 +370,7 @@ namespace Kwave
     };
 }
 
-#endif /* _TRACK_PIXMAP_H_ */
+#endif /* TRACK_PIXMAP_H */
 
 //***************************************************************************
 //***************************************************************************
