@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _TRACK_VIEW_H_
-#define _TRACK_VIEW_H_
+#ifndef TRACK_VIEW_H
+#define TRACK_VIEW_H
 
 #include "config.h"
 
@@ -172,7 +172,7 @@ namespace Kwave
     };
 }
 
-#endif /* _TRACK_VIEW_H_ */
+#endif /* TRACK_VIEW_H */
 
 //***************************************************************************
 //***************************************************************************
