@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _VIEW_ITEM_H_
-#define _VIEW_ITEM_H_
+#ifndef VIEW_ITEM_H
+#define VIEW_ITEM_H
 
 #include "config.h"
 
@@ -79,7 +79,7 @@ namespace Kwave
     };
 }
 
-#endif /* _VIEW_ITEM_H_ */
+#endif /* VIEW_ITEM_H */
 
 //***************************************************************************
 //***************************************************************************
