@@ -16,8 +16,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _CLIP_BOARD_H_
-#define _CLIP_BOARD_H_
+#ifndef CLIP_BOARD_H
+#define CLIP_BOARD_H
 
 #include "config.h"
 
@@ -118,7 +118,7 @@ namespace Kwave
     };
 }
 
-#endif /* _CLIP_BOARD_H_ */
+#endif /* CLIP_BOARD_H */
 
 //***************************************************************************
 //***************************************************************************
