@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _CODEC_BASE_H_
-#define _CODEC_BASE_H_
+#ifndef CODEC_BASE_H
+#define CODEC_BASE_H
 
 #include "config.h"
 
@@ -105,7 +105,7 @@ namespace Kwave
     };
 }
 
-#endif /* _CODEC_BASE_H_ */
+#endif /* CODEC_BASE_H */
 
 //***************************************************************************
 //***************************************************************************
