@@ -17,9 +17,10 @@
 
 #include "config.h"
 
-#include <float.h> // for FLT_MAX, DBL_MIN, DBL_MAX
 #include <math.h>
 
+#include <limits>
+
 #include <QtCore/QtAlgorithms>
 
 #include "libkwave/Curve.h"
@@ -29,7 +30,8 @@
 
 //***************************************************************************
 
-QPointF Kwave::Curve::NoPoint(FLT_MAX, FLT_MAX);
+QPointF Kwave::Curve::NoPoint(std::numeric_limits<qreal>::max(),
+                              std::numeric_limits<qreal>::max());
 
 //***************************************************************************
 Kwave::Curve::Curve()
@@ -74,7 +76,7 @@ QString Kwave::Curve::getCommand()
     QString cmd = _("curve(");
     cmd += m_interpolation.name(m_interpolation.type());
 
-    foreach (Point p, *this) {
+    foreach (const Point &p, *this) {
 	QString par = _(",%1,%2");
 	cmd += par.arg(p.x()).arg(p.y());
     }
@@ -122,7 +124,9 @@ void Kwave::Curve::secondHalf()
 {
     if (isEmpty()) return;
 
-    foreach (Point p, *this) {
+    QMutableListIterator<Point> it(*this);
+    while (it.hasNext()) {
+	Point &p = it.next();
 	p.setX(0.5 + p.x() / 2.0);
     }
 
@@ -158,7 +162,9 @@ void Kwave::Curve::firstHalf()
 {
     if (isEmpty()) return;
 
-    foreach (Point p, *this) {
+    QMutableListIterator<Point> it(*this);
+    while (it.hasNext()) {
+	Point &p = it.next();
 	p.setX(p.x() / 2.0);
     }
     append(Point(1.0, first().y()));
@@ -169,7 +175,9 @@ void Kwave::Curve::VFlip()
 {
     if (isEmpty()) return;
 
-    foreach (Point p, *this) {
+    QMutableListIterator<Point> it(*this);
+    while (it.hasNext()) {
+	Point &p = it.next();
 	p.setY(1.0 - p.y());
     }
 }
@@ -180,7 +188,9 @@ void Kwave::Curve::HFlip()
     if (isEmpty()) return;
 
     // flip all x coordinates
-    foreach (Point p, *this) {
+    QMutableListIterator<Point> it(*this);
+    while (it.hasNext()) {
+	Point &p = it.next();
 	p.setX(1.0 - p.x());
     }
 
@@ -191,8 +201,8 @@ void Kwave::Curve::HFlip()
 //***************************************************************************
 void Kwave::Curve::scaleFit(unsigned int range)
 {
-    double min = DBL_MAX;
-    double max = DBL_MIN;
+    double min = std::numeric_limits<double>::max();
+    double max = std::numeric_limits<double>::min();
 
     Kwave::Interpolation interpolation(m_interpolation.type());
 
@@ -202,7 +212,9 @@ void Kwave::Curve::scaleFit(unsigned int range)
 	if (yi < min) min = yi;
     }
 
-    foreach (Point p, *this) {
+    QMutableListIterator<Point> it(*this);
+    while (it.hasNext()) {
+	Point &p = it.next();
 	p.ry() -= min;
 	if (!qFuzzyCompare(max, min))
 	    p.ry() /= (max - min);
@@ -219,7 +231,9 @@ Kwave::Curve::Point Kwave::Curve::findPoint(double px, double py, double tol)
     double dist;
     double min_dist = tol;
 
-    foreach (Point p, *this) {
+    QMutableListIterator<Point> it(*this);
+    while (it.hasNext()) {
+	Point &p = it.next();
 	// use the length of the difference vector as criterium
 	dist = hypot(px - p.x(), py - p.y());
 	if (dist < min_dist) {
