@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _DECODER_H_
-#define _DECODER_H_
+#ifndef DECODER_H
+#define DECODER_H
 
 #include "config.h"
 
@@ -96,7 +96,7 @@ namespace Kwave
     };
 }
 
-#endif /* _DECODER_H_ */
+#endif /* DECODER_H */
 
 //***************************************************************************
 //***************************************************************************
