@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _DRAG_H_
-#define _DRAG_H_
+#ifndef DRAG_H
+#define DRAG_H
 
 #include "config.h"
 
@@ -53,7 +53,7 @@ namespace Kwave
 	 * Constructor
 	 * @see QDragObject
 	 */
-	Drag(QWidget *dragSource = 0);
+	explicit Drag(QWidget *dragSource = 0);
 
 	/** Destructor */
 	virtual ~Drag();
@@ -89,7 +89,7 @@ namespace Kwave
     };
 }
 
-#endif /* _DRAG_H_ */
+#endif /* DRAG_H */
 
 //***************************************************************************
 //***************************************************************************
