@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _FILTER_H_
-#define _FILTER_H_
+#ifndef FILTER_H
+#define FILTER_H
 
 #include "config.h"
 #include <QtCore/QVector>
@@ -40,13 +40,13 @@ namespace Kwave
 	 * Constructor, creates an empty filter with a given sample rate.
 	 * @param rate number of samples per second
 	 */
-	Filter(int rate);
+	explicit Filter(int rate);
 
 	/**
 	 * Constructor, creates a filter from a Kwave command string.
 	 * @param command part of the Kwave command with parameters
 	 */
-	Filter(const QString &command);
+	explicit Filter(const QString &command);
 
 	/** Destructor */
 	virtual ~Filter();
@@ -126,7 +126,7 @@ namespace Kwave
 
 }
 
-#endif /* _FILTER_H_ */
+#endif /* FILTER_H */
 
 //*****************************************************************************
 //*****************************************************************************
