@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _GENRE_TYPE_H_
-#define _GENRE_TYPE_H_
+#ifndef GENRE_TYPE_H
+#define GENRE_TYPE_H
 
 #include "config.h"
 
@@ -71,7 +71,7 @@ namespace Kwave
     };
 }
 
-#endif /* _GENRE_TYPE_H_ */
+#endif /* GENRE_TYPE_H */
 
 //***************************************************************************
 //***************************************************************************
