@@ -14,8 +14,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#ifndef _INTERPOLATION_H_
-#define _INTERPOLATION_H_
+#ifndef INTERPOLATION_H
+#define INTERPOLATION_H
 
 #include "config.h"
 
@@ -49,7 +49,7 @@ namespace Kwave
     {
     public:
 	/** Constructor, initializes type by enum type */
-	Interpolation(Kwave::interpolation_t type = INTPOL_LINEAR);
+	explicit Interpolation(Kwave::interpolation_t type = INTPOL_LINEAR);
 
 	/** Destructor. */
 	virtual ~Interpolation();
@@ -208,7 +208,7 @@ namespace Kwave
 
 }
 
-#endif /* _INTERPOLATION_H_ */
+#endif /* INTERPOLATION_H */
 
 //***************************************************************************
 //***************************************************************************
