@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _LRU_CACHE_H_
-#define _LRU_CACHE_H_
+#ifndef LRU_CACHE_H
+#define LRU_CACHE_H
 
 #include "config.h"
 
@@ -155,7 +155,7 @@ namespace Kwave
 
 }
 
-#endif /* _LRU_CACHE_H_ */
+#endif /* LRU_CACHE_H */
 
 //***************************************************************************
 //***************************************************************************
