@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "config.h"
+
 #include <limits.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -40,6 +41,7 @@
 #include "libkwave/MemoryManager.h"
 #include "libkwave/String.h"
 #include "libkwave/SwapFile.h"
+#include "libkwave/Utils.h"
 
 /** number of elements in the m_cached_swap list */
 #define CACHE_SIZE 16
@@ -52,13 +54,91 @@ Kwave::Handle Kwave::MemoryManager::m_last_handle = 0;
 
 //***************************************************************************
 Kwave::MemoryManager::MemoryManager()
-    :m_physical_allocated(0), m_physical_limit(0), m_virtual_allocated(0),
-     m_virtual_limit(0), m_swap_dir(_("/tmp")), m_undo_limit(0),
+    :m_physical_limit(0), m_physical_max(0), m_virtual_limit(0),
+     m_swap_dir(_("/tmp")), m_undo_limit(0),
      m_physical(), m_unmapped_swap(), m_mapped_swap(),
      m_cached_swap(), m_lock()
 {
+    // reset statistics
+#ifdef DEBUG_MEMORY
+    memset(&m_stats, 0x00, sizeof(m_stats));
+#endif /* DEBUG_MEMORY */
+
     // determine amount of physical memory
-    m_physical_limit = totalPhysical();
+    // start with 1/4 of the theoretical address space
+
+    // if sizeof(void *) == 4 -> 32 bit ->  1024 MB
+    // if sizeof(void *) == 8 -> 64 bit -> 4.398E12 MB
+    quint64 total = (1ULL << ((sizeof(void *) * 8ULL) - 22ULL));
+
+    // limit the total memory to a 32bit value [MB]
+    if (total > (1ULL << 32)) total = (1ULL << 32) - 1;
+#ifdef DEBUG
+    qDebug("Kwave::MemoryManager: theoretical limit: %llu MB", total);
+#endif /* DEBUG */
+
+#ifdef HAVE_SYSINFO
+    // get the physically installed memory
+    quint64 installed_physical;
+    struct sysinfo info;
+
+    sysinfo(&info);
+
+    // find out installed memory and convert to megabytes
+#ifdef HAVE_SYSINFO_MEMUNIT
+    installed_physical = (info.totalram * info.mem_unit) >> 20;
+#ifdef DEBUG
+    qDebug("Kwave::MemoryManager: sysinfo/memunit: %llu MB", installed_physical);
+#endif /* DEBUG */
+#else /* HAVE_SYSINFO_MEMUNIT */
+    installed_physical = info.totalram >> 20;
+    qDebug("Kwave::MemoryManager: sysinfo: %llu MB", installed_physical);
+#endif /* HAVE_SYSINFO_MEMUNIT */
+    if (installed_physical && (installed_physical < total))
+	total = installed_physical;
+#endif /* HAVE_SYSINFO */
+
+#ifdef HAVE_GETRLIMIT
+    struct rlimit limit;
+
+    // check ulimit of data segment size
+    if (getrlimit(RLIMIT_DATA, &limit) == 0) {
+	quint64 physical_ulimit =
+	    qMin(limit.rlim_cur, limit.rlim_max) >> 20;
+#ifdef DEBUG
+	qDebug("Kwave::MemoryManager: RLIMIT_DATA: %llu MB", physical_ulimit);
+#endif /* DEBUG */
+	if (physical_ulimit < total) total = physical_ulimit;
+    }
+
+    // check ulimit of total (virtual) system memory (address space)
+#ifdef RLIMIT_AS
+    if (getrlimit(RLIMIT_AS, &limit) == 0) {
+	quint64 total_ulimit =
+	    qMin(limit.rlim_cur, limit.rlim_max) >> 20;
+#ifdef DEBUG
+	qDebug("Kwave::MemoryManager: RLIMIT_AS: %llu MB", total_ulimit);
+#endif /* DEBUG */
+	if (total_ulimit < total) total = total_ulimit;
+    }
+#endif /* RLIMIT_AS */
+#endif /* HAVE_GETRLIMIT */
+
+    // limit the total memory to a int value [MB]
+    // (values go into the GUI)
+    total = qMin(total, static_cast<quint64>(INT_MAX));
+
+#ifdef DEBUG
+    qDebug("Kwave::MemoryManager: => using up to %llu MB RAM", total);
+#endif /* DEBUG */
+
+    m_physical_max   = total;
+    m_physical_limit = total;
+
+#ifdef DEBUG_MEMORY
+    m_stats.physical.limit = m_physical_limit << 20ULL;
+    m_stats.swap.limit     = m_virtual_limit  << 20ULL;
+#endif /* DEBUG_MEMORY */
 }
 
 //***************************************************************************
@@ -88,21 +168,27 @@ Kwave::MemoryManager &Kwave::MemoryManager::instance()
 }
 
 //***************************************************************************
-void Kwave::MemoryManager::setPhysicalLimit(unsigned int mb)
+void Kwave::MemoryManager::setPhysicalLimit(quint64 mb)
 {
     QMutexLocker lock(&m_lock);
 
     m_physical_limit = mb;
     mb = totalPhysical();
     if (m_physical_limit > mb) m_physical_limit = mb;
+#ifdef DEBUG_MEMORY
+    m_stats.physical.limit = m_physical_limit << 20ULL;
+#endif /* DEBUG_MEMORY */
 }
 
 //***************************************************************************
-void Kwave::MemoryManager::setVirtualLimit(unsigned int mb)
+void Kwave::MemoryManager::setVirtualLimit(quint64 mb)
 {
     QMutexLocker lock(&m_lock);
 
     m_virtual_limit = mb;
+#ifdef DEBUG_MEMORY
+    m_stats.swap.limit = m_virtual_limit << 20ULL;
+#endif /* DEBUG_MEMORY */
 
 /** @todo write a function to find out the limit of virtual memory */
 //    mb = totalVirtual();
@@ -117,7 +203,7 @@ void Kwave::MemoryManager::setSwapDirectory(const QString &dir)
 }
 
 //***************************************************************************
-void Kwave::MemoryManager::setUndoLimit(unsigned int mb)
+void Kwave::MemoryManager::setUndoLimit(quint64 mb)
 {
     QMutexLocker lock(&m_lock);
 
@@ -127,54 +213,15 @@ void Kwave::MemoryManager::setUndoLimit(unsigned int mb)
 }
 
 //***************************************************************************
-unsigned int Kwave::MemoryManager::undoLimit() const
+quint64 Kwave::MemoryManager::undoLimit() const
 {
     return m_undo_limit;
 }
 
 //***************************************************************************
-unsigned int Kwave::MemoryManager::totalPhysical()
+quint64 Kwave::MemoryManager::totalPhysical()
 {
-    quint64 total = 2 * 1024;
-
-#ifdef HAVE_SYSINFO
-    // get the physically installed memory
-    quint64 installed_physical;
-    struct sysinfo info;
-
-    sysinfo(&info);
-
-    // find out installed memory and convert to megabytes
-#ifdef HAVE_SYSINFO_MEMUNIT
-    installed_physical = (info.totalram * info.mem_unit) >> 20;
-#else /* HAVE_SYSINFO_MEMUNIT */
-    installed_physical = info.totalram >> 20;
-#endif /* HAVE_SYSINFO_MEMUNIT */
-    if (installed_physical && (installed_physical < total))
-	total = installed_physical;
-#endif /* HAVE_SYSINFO */
-
-#ifdef HAVE_GETRLIMIT
-    struct rlimit limit;
-
-    // check ulimit of data segment size
-    if (getrlimit(RLIMIT_DATA, &limit) == 0) {
-	unsigned int physical_ulimit =
-	    qMin(limit.rlim_cur, limit.rlim_max) >> 20;
-	if (physical_ulimit < total) total = physical_ulimit;
-    }
-
-    // check ulimit of total (physical+virtual) system memory
-#ifdef RLIMIT_AS
-    if (getrlimit(RLIMIT_AS, &limit) == 0) {
-	unsigned int total_ulimit =
-	    qMin(limit.rlim_cur, limit.rlim_max) >> 20;
-	if (total_ulimit < total) total = total_ulimit;
-    }
-#endif /* RLIMIT_AS */
-#endif /* HAVE_GETRLIMIT */
-
-    return total;
+    return m_physical_max;
 }
 
 //***************************************************************************
@@ -221,10 +268,12 @@ bool Kwave::MemoryManager::freePhysical(size_t size)
 
 	// convert to swapfile
 	size_t s = p.m_size;
+#if 0
 	qDebug("Kwave::MemoryManager[%9d] - swapping %2u MB out to make "\
 	       "space for %2u MB", handle,
-	       static_cast<unsigned int>(s >> 20),
-	       static_cast<unsigned int>(size >> 20));
+	       Kwave::toUint(s >> 20),
+	       Kwave::toUint(size >> 20));
+#endif
 
 	if (convertToVirtual(handle, s)) {
 	    freed += s;
@@ -259,7 +308,7 @@ Kwave::Handle Kwave::MemoryManager::allocate(size_t size)
 
     if (!handle) {
 	qWarning("Kwave::MemoryManager::allocate(%u) - out of memory!",
-	          static_cast<unsigned int>(size));
+	          Kwave::toUint(size));
     }
 
     dump("allocate");
@@ -270,10 +319,10 @@ Kwave::Handle Kwave::MemoryManager::allocate(size_t size)
 Kwave::Handle Kwave::MemoryManager::allocatePhysical(size_t size)
 {
     // check for limits
-    unsigned limit = totalPhysical();
+    quint64 limit = totalPhysical();
     if (m_physical_limit < limit) limit = m_physical_limit;
-    unsigned int used = physicalUsed();
-    unsigned int available = (used < limit) ? (limit - used) : 0;
+    quint64 used = physicalUsed();
+    quint64 available = (used < limit) ? (limit - used) : 0;
     if ((size >> 20) >= available) return 0;
 
     // get a new handle
@@ -291,23 +340,28 @@ Kwave::Handle Kwave::MemoryManager::allocatePhysical(size_t size)
     phys.m_mapcount = 0;
     Q_ASSERT(!m_physical.contains(handle));
     m_physical.insert(handle, phys);
+#ifdef DEBUG_MEMORY
+    m_stats.physical.handles++;
+    m_stats.physical.allocs++;
+    m_stats.physical.bytes += size;
+#endif /* DEBUG_MEMORY */
 
     return handle;
 }
 
 //***************************************************************************
-size_t Kwave::MemoryManager::physicalUsed()
+quint64 Kwave::MemoryManager::physicalUsed()
 {
-    size_t used = 0;
+    quint64 used = 0;
     foreach (const physical_memory_t &mem, m_physical.values())
 	used += (mem.m_size >> 10) + 1;
     return (used >> 10);
 }
 
 //***************************************************************************
-size_t Kwave::MemoryManager::virtualUsed()
+quint64 Kwave::MemoryManager::virtualUsed()
 {
-    size_t used = 0;
+    quint64 used = 0;
 
     foreach (const Kwave::SwapFile *swapfile, m_cached_swap.values())
 	used += (swapfile->size() >> 10) + 1;
@@ -340,14 +394,14 @@ QString Kwave::MemoryManager::nextSwapFileName(Kwave::Handle handle)
 Kwave::Handle Kwave::MemoryManager::allocateVirtual(size_t size)
 {
     // check for limits
-    unsigned int limit = INT_MAX; // totalVirtual() in MB
+    quint64 limit = INT_MAX; // totalVirtual() in MB
     if (m_virtual_limit < limit) limit = m_virtual_limit;
-    unsigned int used = virtualUsed(); // in MB
-    unsigned int available = (used < limit) ? (limit - used) : 0;
+    quint64 used = virtualUsed(); // in MB
+    quint64 available = (used < limit) ? (limit - used) : 0;
     if ((size >> 20) >= available) {
 	qWarning("Kwave::MemoryManager::allocateVirtual(%u): out of memory, "\
-	         "(used: %uMB, available: %uMB, limit=%uMB)",
-	         static_cast<unsigned int>(size), used, available, limit);
+	         "(used: %lluMB, available: %lluMB, limit=%lluMB)",
+	         Kwave::toUint(size), used, available, limit);
 	dump("allocateVirtual");
         return 0;
     }
@@ -364,11 +418,16 @@ Kwave::Handle Kwave::MemoryManager::allocateVirtual(size_t size)
     if (swap->allocate(size)) {
 	// succeeded, store the object in our map
 	m_unmapped_swap.insert(handle, swap);
+#ifdef DEBUG_MEMORY
+	m_stats.swap.unmapped.bytes += size;
+	m_stats.swap.unmapped.handles++;
+	m_stats.swap.allocs++;
+#endif /* DEBUG_MEMORY */
 	return handle;
     } else {
 	qWarning("Kwave::MemoryManager::allocateVirtual(%u): OOM, "\
-	         "(used: %uMB) - failed resizing swap file",
-	         static_cast<unsigned int>(size), used);
+	         "(used: %lluMB) - failed resizing swap file",
+	         Kwave::toUint(size), used);
 	// failed: give up, delete the swapfile object
 	delete swap;
     }
@@ -397,11 +456,17 @@ bool Kwave::MemoryManager::convertToVirtual(Kwave::Handle handle,
 
     // copy old stuff to new location
     Kwave::SwapFile *swap = m_unmapped_swap[temp_handle];
+    Q_ASSERT(swap);
     swap->write(0, mem.m_data, mem.m_size);
 
     // free the old physical memory
     ::free(mem.m_data);
     m_physical.remove(handle);
+#ifdef DEBUG_MEMORY
+    m_stats.physical.handles--;
+    m_stats.physical.frees++;
+    m_stats.physical.bytes -= mem.m_size;
+#endif /* DEBUG_MEMORY */
 
     // discard the new (temporary) handle and re-use the old one
     m_unmapped_swap.remove(temp_handle); // temp_handle is now no longer valid
@@ -436,10 +501,6 @@ bool Kwave::MemoryManager::convertToPhysical(Kwave::Handle handle,
     physical_memory_t mem = m_physical[temp_handle];
     Q_ASSERT(mem.m_data);
     Q_ASSERT(mem.m_size >= new_size);
-    if (!mem.m_data || !mem.m_size) {
-	m_physical.remove(temp_handle);
-	return false;
-    }
 
     // copy old stuff to new location
     if (new_size <= swap->size()) {
@@ -450,6 +511,12 @@ bool Kwave::MemoryManager::convertToPhysical(Kwave::Handle handle,
 	swap->read(0, mem.m_data, swap->size());
     }
 
+#ifdef DEBUG_MEMORY
+    m_stats.swap.unmapped.bytes -= swap->size();
+    m_stats.swap.unmapped.handles--;
+    m_stats.swap.frees++;
+#endif /* DEBUG_MEMORY */
+
     // free the old swapfile
     m_unmapped_swap.remove(handle);
     delete swap;
@@ -459,8 +526,8 @@ bool Kwave::MemoryManager::convertToPhysical(Kwave::Handle handle,
     m_physical.insert(handle, mem);
 
     // we now have the old data with new size and old handle in m_physical
-    qDebug("Kwave::MemoryManager[%9d] - reloaded %2u MB from swap",
-           handle, static_cast<unsigned int>(mem.m_size >> 20));
+//     qDebug("Kwave::MemoryManager[%9d] - reloaded %2u MB from swap",
+//            handle, Kwave::toUint(mem.m_size >> 20));
 
     dump("convertToPhysical");
     return true;
@@ -483,10 +550,10 @@ void Kwave::MemoryManager::tryToMakePhysical(Kwave::Handle handle)
 
     size_t size = swap->size();
 
-    unsigned limit = totalPhysical();
+    quint64 limit = totalPhysical();
     if (m_physical_limit < limit) limit = m_physical_limit;
-    unsigned int used = physicalUsed();
-    unsigned int available = (used < limit) ? (limit - used) : 0;
+    quint64 used = physicalUsed();
+    quint64 available = (used < limit) ? (limit - used) : 0;
 
     // if we would go over the physical limit...
     if ((size >> 20) >= available) {
@@ -504,7 +571,7 @@ bool Kwave::MemoryManager::resize(Kwave::Handle handle, size_t size)
     QMutexLocker lock(&m_lock);
 
 //     qDebug("Kwave::MemoryManager[%9d] - resize to %u", handle,
-//            static_cast<unsigned int>(size));
+//            Kwave::toUint(size));
 
     // case 1: physical memory
     if (m_physical.contains(handle)) {
@@ -527,7 +594,7 @@ bool Kwave::MemoryManager::resize(Kwave::Handle handle, size_t size)
 	    if (!physical_freed) {
 		// still too large -> move to virtual memory
 		qDebug("Kwave::MemoryManager[%9d] - resize(%uMB) -> moving to swap",
-		    handle, static_cast<unsigned int>(size >> 20));
+		    handle, Kwave::toUint(size >> 20));
 		return convertToVirtual(handle, size);
 	    }
 	}
@@ -541,6 +608,10 @@ bool Kwave::MemoryManager::resize(Kwave::Handle handle, size_t size)
 	    phys.m_size     = size;
 	    phys.m_mapcount = 0;
 	    m_physical[handle] = phys;
+#ifdef DEBUG_MEMORY
+	    m_stats.physical.bytes -= current_size;
+	    m_stats.physical.bytes += size;
+#endif /* DEBUG_MEMORY */
 
 	    dump("resize");
 	    return true;
@@ -556,7 +627,7 @@ bool Kwave::MemoryManager::resize(Kwave::Handle handle, size_t size)
     // case 3: mapped swapfile -> forbidden !
     Q_ASSERT(!m_mapped_swap.contains(handle));
     if (m_mapped_swap.contains(handle))
-	return 0;
+	return false;
 
     // case 4: unmapped swapfile -> resize
     Q_ASSERT(m_unmapped_swap.contains(handle));
@@ -576,17 +647,59 @@ bool Kwave::MemoryManager::resize(Kwave::Handle handle, size_t size)
 	// not enough free RAM: resize the pagefile
 // 	qDebug("Kwave::MemoryManager[%9d] - resize swap %u -> %u MB",
 // 	        handle,
-// 	        static_cast<unsigned int>(swap->size() >> 20),
-// 	        static_cast<unsigned int>(size >> 20));
+// 	        Kwave::toUint(swap->size() >> 20),
+// 	        Kwave::toUint(size >> 20));
 
 	dump("resize");
 	Kwave::SwapFile *swap = m_unmapped_swap[handle];
-	return swap->resize(size);
+#ifdef DEBUG_MEMORY
+	size_t old_size = swap->size();
+#endif /* DEBUG_MEMORY */
+	bool ok = swap->resize(size);
+	if (!ok) return false;
+#ifdef DEBUG_MEMORY
+	m_stats.swap.unmapped.bytes -= old_size;
+	m_stats.swap.unmapped.bytes += size;
+#endif /* DEBUG_MEMORY */
+	return true;
     }
 
     return false; // nothing known about this object / invalid handle?
 }
 
+//***************************************************************************
+size_t Kwave::MemoryManager::sizeOf(Kwave::Handle handle)
+{
+    if (!handle) return 0;
+    QMutexLocker lock(&m_lock);
+
+    // case 1: physical memory
+    if (m_physical.contains(handle)) {
+	const physical_memory_t phys_c = m_physical[handle];
+	return phys_c.m_size;
+    }
+
+    // case 2: cached mapped swapfile
+    if (m_cached_swap.contains(handle)) {
+	const Kwave::SwapFile *swapfile = m_cached_swap[handle];
+	return swapfile->size();
+    }
+
+    // case 3: mapped swapfile
+    if (m_mapped_swap.contains(handle)) {
+	const Kwave::SwapFile *swapfile = m_mapped_swap[handle];
+	return swapfile->size();
+    }
+
+    // case 4: unmapped swapfile
+    if (m_unmapped_swap.contains(handle)) {
+	const Kwave::SwapFile *swapfile = m_unmapped_swap[handle];
+	return swapfile->size();
+    }
+
+    return 0;
+}
+
 //***************************************************************************
 void Kwave::MemoryManager::free(Kwave::Handle &handle)
 {
@@ -598,6 +711,13 @@ void Kwave::MemoryManager::free(Kwave::Handle &handle)
     if (m_physical.contains(handle)) {
 	// physical memory (must not be mapped)
 	Q_ASSERT(!m_physical[handle].m_mapcount);
+
+#ifdef DEBUG_MEMORY
+	m_stats.physical.handles--;
+	m_stats.physical.frees++;
+	m_stats.physical.bytes -= m_physical[handle].m_size;
+#endif /* DEBUG_MEMORY */
+
 	void *b = m_physical[handle].m_data;
 	Q_ASSERT(b);
 	m_physical.remove(handle);
@@ -619,6 +739,11 @@ void Kwave::MemoryManager::free(Kwave::Handle &handle)
     if (m_unmapped_swap.contains(handle)) {
 	// remove the pagefile
 	Kwave::SwapFile *swap = m_unmapped_swap[handle];
+#ifdef DEBUG_MEMORY
+	m_stats.swap.unmapped.handles--;
+	m_stats.swap.unmapped.bytes -= swap->size();
+	m_stats.swap.frees++;
+#endif /* DEBUG_MEMORY */
 	m_unmapped_swap.remove(handle);
 	Q_ASSERT(!swap->mapCount());
 	delete swap;
@@ -657,6 +782,12 @@ void *Kwave::MemoryManager::map(Kwave::Handle handle)
 	Kwave::SwapFile *swap = m_cached_swap[handle];
 	m_cached_swap.remove(handle);
 	m_mapped_swap.insert(handle, swap);
+#ifdef DEBUG_MEMORY
+	m_stats.swap.cached.handles--;
+	m_stats.swap.cached.bytes -= swap->size();
+	m_stats.swap.mapped.handles++;
+	m_stats.swap.mapped.bytes += swap->size();
+#endif /* DEBUG_MEMORY */
 // 	qDebug("Kwave::MemoryManager[%9d] - mmap -> cache hit", handle);
 	Q_ASSERT(swap->mapCount() == 1);
 	return swap->address();
@@ -679,7 +810,16 @@ void *Kwave::MemoryManager::map(Kwave::Handle handle)
 	void *mapped = swap->map();
 	if (!mapped) {
 	    qDebug("Kwave::MemoryManager[%9d] - mmap FAILED", handle);
-	    return 0;
+	    // maybe address space is already full wil already cached
+	    // mapped swap files -> kick out the last one and try again
+	    while (!mapped && !m_cached_swap.isEmpty()) {
+		Kwave::Handle h = m_cached_swap.keys().last();
+		unmapFromCache(h);
+		mapped = swap->map();
+		qDebug("Kwave::MemoryManager[%9d] - retry: %p", handle, mapped);
+	    }
+
+	    if (!mapped) return 0;
 	}
 
 	// remember that we have mapped it, move the entry from the
@@ -687,6 +827,12 @@ void *Kwave::MemoryManager::map(Kwave::Handle handle)
 	m_unmapped_swap.remove(handle);
 	m_mapped_swap.insert(handle, swap);
 
+#ifdef DEBUG_MEMORY
+	m_stats.swap.unmapped.handles--;
+	m_stats.swap.unmapped.bytes -= swap->size();
+	m_stats.swap.mapped.handles++;
+	m_stats.swap.mapped.bytes += swap->size();
+#endif /* DEBUG_MEMORY */
 // 	qDebug("Kwave::MemoryManager[%9d] - mmap -> new mapping", handle);
 	return mapped;
     } else {
@@ -708,6 +854,12 @@ void Kwave::MemoryManager::unmapFromCache(Kwave::Handle handle)
 	Q_ASSERT(!swap->mapCount());
 	m_cached_swap.remove(handle);
 	m_unmapped_swap.insert(handle, swap);
+#ifdef DEBUG_MEMORY
+	m_stats.swap.cached.handles--;
+	m_stats.swap.cached.bytes -= swap->size();
+	m_stats.swap.unmapped.handles++;
+	m_stats.swap.unmapped.bytes += swap->size();
+#endif /* DEBUG_MEMORY */
     }
 
     dump("unmap");
@@ -760,6 +912,12 @@ void Kwave::MemoryManager::unmap(Kwave::Handle handle)
 	    // move it into the swap file cache
 	    m_mapped_swap.remove(handle);
 	    m_cached_swap.insert(handle, swap);
+#ifdef DEBUG_MEMORY
+	    m_stats.swap.mapped.handles--;
+	    m_stats.swap.mapped.bytes -= swap->size();
+	    m_stats.swap.cached.handles++;
+	    m_stats.swap.cached.bytes += swap->size();
+#endif /* DEBUG_MEMORY */
 // 	    qDebug("Kwave::MemoryManager[%9d] - unmap -> moved to cache",
 // 	           handle);
 	}
@@ -795,7 +953,7 @@ int Kwave::MemoryManager::readFrom(Kwave::Handle handle, unsigned int offset,
 	Q_ASSERT(data);
 	if (!data) return 0;
 	MEMCPY(buffer, data + offset, length);
-	qDebug("Kwave::MemoryManager[%9d] - readFrom -> cached swap", handle);
+// 	qDebug("Kwave::MemoryManager[%9d] - readFrom -> cached swap", handle);
 	return length;
     }
 
@@ -807,14 +965,14 @@ int Kwave::MemoryManager::readFrom(Kwave::Handle handle, unsigned int offset,
 	Q_ASSERT(data);
 	if (!data) return 0;
 	MEMCPY(buffer, data + offset, length);
-	qDebug("Kwave::MemoryManager[%9d] - readFrom -> mapped swap", handle);
+// 	qDebug("Kwave::MemoryManager[%9d] - readFrom -> mapped swap", handle);
 	return length;
     }
 
     // now it must be in unmapped swap -> read(...)
     Q_ASSERT(m_unmapped_swap.contains(handle));
     if (m_unmapped_swap.contains(handle)) {
-	qDebug("Kwave::MemoryManager[%9d] - readFrom -> unmapped swap", handle);
+// 	qDebug("Kwave::MemoryManager[%9d] - readFrom -> unmapped swap", handle);
 	Kwave::SwapFile *swap = m_unmapped_swap[handle];
 	length = swap->read(offset, buffer, length);
 	return length;
@@ -858,7 +1016,7 @@ int Kwave::MemoryManager::writeTo(Kwave::Handle handle, unsigned int offset,
     // now it must be in unmapped swap
     Q_ASSERT(m_unmapped_swap.contains(handle));
     if (m_unmapped_swap.contains(handle)) {
-	qDebug("Kwave::MemoryManager[%9d] - writeTo -> unmapped swap", handle);
+// 	qDebug("Kwave::MemoryManager[%9d] - writeTo -> unmapped swap", handle);
 	Kwave::SwapFile *swap = m_unmapped_swap[handle];
 	swap->write(offset, buffer, length);
 	return length;
@@ -871,8 +1029,8 @@ int Kwave::MemoryManager::writeTo(Kwave::Handle handle, unsigned int offset,
 void Kwave::MemoryManager::dump(const char *function)
 {
 #if 0
-    unsigned int v_used  = static_cast<unsigned int>(virtualUsed());
-    unsigned int p_used  = static_cast<unsigned int>(physicalUsed());
+    quint64 v_used  = virtualUsed();
+    quint64 p_used  = physicalUsed();
 
     qDebug("------- %s -------", function);
     foreach (const Kwave::Handle &handle, m_physical.keys())
@@ -900,11 +1058,35 @@ void Kwave::MemoryManager::dump(const char *function)
 	                              m_unmapped_swap[handle]->size() >> 20);
     }
 
-    qDebug("physical: %5u MB, virtual: %5u MB [m:%5u, c:%5u, u:%5u]",
+    qDebug("physical: %5llu MB, virtual: %5llu MB [m:%5u, c:%5u, u:%5u]",
            p_used, v_used, m, c, u);
-#else
-    Q_UNUSED(function);
 #endif
+
+#ifdef DEBUG_MEMORY
+    qDebug("------- %s -------", function);
+    qDebug("physical:    %12llu, %12llu / %12llu (%12llu : %12llu)",
+	   m_stats.physical.handles,
+	   m_stats.physical.bytes,
+	   m_stats.physical.limit,
+	   m_stats.physical.allocs,
+	   m_stats.physical.frees);
+    qDebug("mapped swap: %12llu, %12llu / %12llu (%12llu : %12llu)",
+	   m_stats.swap.mapped.handles,
+	   m_stats.swap.mapped.bytes,
+	   m_stats.swap.limit,
+	   m_stats.swap.allocs,
+	   m_stats.swap.frees);
+    qDebug("cached:      %12llu, %12llu",
+	   m_stats.swap.cached.handles,
+	   m_stats.swap.cached.bytes);
+    qDebug("unmapped:    %12llu, %12llu",
+	   m_stats.swap.unmapped.handles,
+	   m_stats.swap.unmapped.bytes);
+    qDebug("-----------------------------------------------------------------");
+
+#else /* DEBUG_MEMORY */
+    Q_UNUSED(function);
+#endif /* DEBUG_MEMORY */
 }
 
 //***************************************************************************
