@@ -14,8 +14,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#ifndef _META_DATA_H_
-#define _META_DATA_H_
+#ifndef META_DATA_H
+#define META_DATA_H
 
 #include "config.h"
 
@@ -104,7 +104,7 @@ namespace Kwave
 	MetaData(const MetaData &other);
 
 	/** constructor */
-	MetaData(Scope scope);
+	explicit MetaData(Scope scope);
 
 	/** destructor */
 	virtual ~MetaData();
@@ -122,7 +122,7 @@ namespace Kwave
 	Scope scope() const;
 
 	/**
-	 * Sets the the scope of the meta data
+	 * Sets the scope of the meta data
 	 * @param scope the new scope
 	 */
 	void setScope(Scope scope);
@@ -252,7 +252,7 @@ namespace Kwave
     };
 }
 
-#endif /* _META_DATA_H_ */
+#endif /* META_DATA_H */
 
 //***************************************************************************
 //***************************************************************************
