@@ -41,7 +41,6 @@
 #include "libkwave/String.h"
 #include "libkwave/Utils.h"
 #include "libkwave/MultiTrackReader.h"
-#include "libkwave/MultiTrackWriter.h"
 #include "libkwave/Writer.h"
 
 #include "libkwave/modules/ChannelMixer.h"
@@ -210,7 +209,7 @@ bool Kwave::MimeData::encode(QWidget *widget,
     info.set(Kwave::INF_COMPRESSION, QVariant(Kwave::Compression::NONE));
     info.setLength(last - first + 1);
     info.setTracks(src.tracks());
-    new_meta_data.replace(info);
+    new_meta_data.replace(Kwave::MetaDataList(info));
 
     // encode into the buffer
     m_buffer.close(); // discard old stuff
@@ -244,7 +243,7 @@ sample_index_t Kwave::MimeData::decode(QWidget *widget, const QMimeData *e,
     unsigned int   decoded_tracks = 0;
 
     // try to find a suitable decoder
-    foreach (QString format, e->formats()) {
+    foreach (const QString &format, e->formats()) {
 	// skip all non-supported formats
 	if (!Kwave::CodecManager::canDecode(format)) continue;
 
@@ -331,7 +330,7 @@ sample_index_t Kwave::MimeData::decode(QWidget *widget, const QMimeData *e,
 		    dst_tracks, widget);
 	    Q_ASSERT(rate_converter);
 	    if (rate_converter)
-		rate_converter->setAttribute(SLOT(setRatio(const QVariant)),
+		rate_converter->setAttribute(SLOT(setRatio(QVariant)),
 	                                     QVariant(dst_rate / src_rate));
 	    else
 		ok = false;
