@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _MIME_DATA_H_
-#define _MIME_DATA_H_
+#ifndef MIME_DATA_H
+#define MIME_DATA_H
 
 #include "config.h"
 
@@ -154,7 +154,7 @@ namespace Kwave
     };
 }
 
-#endif /* _MIME_DATA_H_ */
+#endif /* MIME_DATA_H */
 
 //***************************************************************************
 //***************************************************************************
