@@ -16,8 +16,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _MULTI_TRACK_READER_H_
-#define _MULTI_TRACK_READER_H_
+#ifndef MULTI_TRACK_READER_H
+#define MULTI_TRACK_READER_H
 
 #include "config.h"
 
@@ -140,7 +140,7 @@ namespace Kwave
     };
 }
 
-#endif /* _MULTI_TRACK_READER_H_ */
+#endif /* MULTI_TRACK_READER_H */
 
 //***************************************************************************
 //***************************************************************************
