@@ -16,8 +16,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _MULTI_TRACK_WRITER_H_
-#define _MULTI_TRACK_WRITER_H_
+#ifndef MULTI_TRACK_WRITER_H
+#define MULTI_TRACK_WRITER_H
 
 #include "config.h"
 
@@ -94,7 +94,7 @@ namespace Kwave
     };
 }
 
-#endif /* _MULTI_TRACK_WRITER_H_ */
+#endif /* MULTI_TRACK_WRITER_H */
 
 //***************************************************************************
 //***************************************************************************
