@@ -16,8 +16,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _PARSER_H_
-#define _PARSER_H_
+#ifndef PARSER_H
+#define PARSER_H
 
 #include "config.h"
 
@@ -25,6 +25,7 @@
 #include <QtCore/QStringList>
 
 #include <kdemacros.h>
+#include <kurl.h>
 
 #include "libkwave/Sample.h" // for sample_index_t
 
@@ -90,6 +91,9 @@ namespace Kwave
 	 */
 	const QString &nextParam();
 
+	/** Returns all remaining parameters in a string list */
+	QStringList remainingParams();
+
 	/**
 	 * Skips a parameter and advances the current position
 	 * by one if the end has not already been reached.
@@ -150,6 +154,21 @@ namespace Kwave
 	 */
 	static QString unescape(const QString &text);
 
+	/**
+	 * Converts a string command into a URL suitable for passing to
+	 * Kwave as command line parameter
+	 * @param command the string command to encode as URL
+	 * @return a KUrl with the kwave:// scheme
+	 */
+	static KUrl toUrl(const QString &command);
+
+	/**
+	 * Converts a kwave:// URL into a string command
+	 * @param url a URL using the kwave:// scheme
+	 * @return a Kwave string command parsed from the URL
+	 */
+	static QString fromUrl(const KUrl &url);
+
     protected:
 
 	/** Splits a line into a list of commands */
@@ -171,7 +190,7 @@ namespace Kwave
     };
 }
 
-#endif /* _PARSER_H_ */
+#endif /* PARSER_H */
 
 //***************************************************************************
 //***************************************************************************
