@@ -386,9 +386,8 @@ void Kwave::PlaybackController::stopDevicePlayBack()
 	emit sigDevicePlaybackDone();
     }
     closeDevice();
-
-
 }
+
 //***************************************************************************
 void Kwave::PlaybackController::trackSelectionChanged()
 {
@@ -484,7 +483,7 @@ void Kwave::PlaybackController::run_wrapper(const QVariant &params)
 	    if (seek_done)  seekDone(pos);;
 
 	    // fill input buffer with samples
-	    for (x = 0; x < audible_count; x++) {
+	    for (x = 0; x < audible_count; ++x) {
 		in_samples[x] = 0;
 		Kwave::SampleReader *stream = input[audible_tracks[x]];
 		Q_ASSERT(stream);
@@ -495,9 +494,9 @@ void Kwave::PlaybackController::run_wrapper(const QVariant &params)
 
 	    // multiply matrix with input to get output
 	    const Kwave::SampleArray &in = in_samples;
-	    for (y = 0; y < out_channels; y++) {
+	    for (y = 0; y < out_channels; ++y) {
 		double sum = 0;
-		for (x = 0; x < audible_count; x++) {
+		for (x = 0; x < audible_count; ++x) {
 		    sum += static_cast<double>(in[x]) * (*mixer)[x][y];
 		}
 		out_samples[y] = static_cast<sample_t>(sum);
