@@ -51,6 +51,8 @@
 QMap<QString, Kwave::PluginManager::PluginModule>
     Kwave::PluginManager::m_plugin_modules;
 
+Kwave::PluginManager *Kwave::PluginManager::m_active_instance = 0;
+
 //***************************************************************************
 Kwave::PluginManager::PluginManager(QWidget *parent,
                                     Kwave::SignalManager &signal_manager)
@@ -101,14 +103,15 @@ Kwave::PluginManager::~PluginManager()
 	    m_plugin_modules.remove(name);
 
 	    // now the handle of the shared object can be released too
-	    if (module) {
-		module->unload();
-		delete module;
-	    }
+	    if (module) delete module;
 	} else {
 	    // still in use
 	}
     }
+
+    // we are no longer the active instance
+    if (m_active_instance == this)
+	m_active_instance = 0;
 }
 
 //***************************************************************************
@@ -208,7 +211,7 @@ int Kwave::PluginManager::executePlugin(const QString &name,
     Q_ASSERT(this->thread() == qApp->thread());
 
     // synchronize: wait until any currently running plugins are done
-    sync();
+    this->sync();
 
     // load the new plugin
     KwavePluginPointer plugin = createPluginInstance(name);
@@ -303,37 +306,36 @@ void Kwave::PluginManager::sync()
     Q_ASSERT(this->thread() == QThread::currentThread());
     Q_ASSERT(this->thread() == qApp->thread());
 
-    qApp->processEvents();
-    qApp->flush();
-
     while (onePluginRunning()) {
 	Kwave::yield();
-	qApp->processEvents();
+	qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
 	qApp->flush();
 	usleep(100000);
     }
 }
 
 //***************************************************************************
-int Kwave::PluginManager::setupPlugin(const QString &name)
+int Kwave::PluginManager::setupPlugin(const QString &name,
+                                      const QStringList &params)
 {
     // load the plugin
-    Kwave::Plugin* plugin = createPluginInstance(name);
+    Kwave::Plugin *plugin = createPluginInstance(name);
     if (!plugin) return -ENOMEM;
 
     // now the plugin is present and loaded
-    QStringList last_params = loadPluginDefaults(name);
+    QStringList prev_params = (!params.isEmpty()) ?
+	params : loadPluginDefaults(name);
 
-    // call the plugin's setup function
-    QStringList *params = plugin->setup(last_params);
-    if (params) {
+    // call the plugins' setup function
+    QStringList *new_params = plugin->setup(prev_params);
+    if (new_params) {
 	// we have a non-zero parameter list, so
 	// the setup function has not been aborted.
-	savePluginDefaults(name, *params);
-	delete params;
+	savePluginDefaults(name, *new_params);
+	delete new_params;
     } else {
 	plugin->release();
-	return -1;
+	return 1;
     }
 
     plugin->release();
@@ -543,16 +545,16 @@ void Kwave::PluginManager::connectPlugin(Kwave::Plugin *plugin)
     connect(this, SIGNAL(sigClosed()),
 	    plugin, SLOT(close()));
 
-    connect(plugin, SIGNAL(sigClosed(Kwave::Plugin *)),
-	    this, SLOT(pluginClosed(Kwave::Plugin *)),
+    connect(plugin, SIGNAL(sigClosed(Kwave::Plugin*)),
+	    this, SLOT(pluginClosed(Kwave::Plugin*)),
 	    Qt::QueuedConnection);
 
-    connect(plugin, SIGNAL(sigRunning(Kwave::Plugin *)),
-	    this, SLOT(pluginStarted(Kwave::Plugin *)),
+    connect(plugin, SIGNAL(sigRunning(Kwave::Plugin*)),
+	    this, SLOT(pluginStarted(Kwave::Plugin*)),
 	    Qt::DirectConnection);
 
-    connect(plugin, SIGNAL(sigDone(Kwave::Plugin *)),
-	    this, SLOT(pluginDone(Kwave::Plugin *)),
+    connect(plugin, SIGNAL(sigDone(Kwave::Plugin*)),
+	    this, SLOT(pluginDone(Kwave::Plugin*)),
 	    Qt::QueuedConnection);
 }
 
@@ -562,17 +564,17 @@ void Kwave::PluginManager::disconnectPlugin(Kwave::Plugin *plugin)
     Q_ASSERT(plugin);
     if (!plugin) return;
 
-    disconnect(plugin, SIGNAL(sigDone(Kwave::Plugin *)),
-	       this, SLOT(pluginDone(Kwave::Plugin *)));
+    disconnect(plugin, SIGNAL(sigDone(Kwave::Plugin*)),
+	       this, SLOT(pluginDone(Kwave::Plugin*)));
 
-    disconnect(plugin, SIGNAL(sigRunning(Kwave::Plugin *)),
-	       this, SLOT(pluginStarted(Kwave::Plugin *)));
+    disconnect(plugin, SIGNAL(sigRunning(Kwave::Plugin*)),
+	       this, SLOT(pluginStarted(Kwave::Plugin*)));
 
     disconnect(this, SIGNAL(sigClosed()),
 	       plugin, SLOT(close()));
 
-    disconnect(plugin, SIGNAL(sigClosed(Kwave::Plugin *)),
-	       this, SLOT(pluginClosed(Kwave::Plugin *)));
+    disconnect(plugin, SIGNAL(sigClosed(Kwave::Plugin*)),
+	       this, SLOT(pluginClosed(Kwave::Plugin*)));
 
 }
 
@@ -675,6 +677,32 @@ const QList<Kwave::PluginManager::PluginModule>
     return m_plugin_modules.values();
 }
 
+//***************************************************************************
+void Kwave::PluginManager::migratePluginToActiveContext(Kwave::Plugin *plugin)
+{
+    // check: this must be called from the GUI thread only!
+    Q_ASSERT(this->thread() == QThread::currentThread());
+    Q_ASSERT(this->thread() == qApp->thread());
+
+    Q_ASSERT(plugin);
+    if (!plugin) return;
+    if (m_active_instance == this) return; // nothing to do
+    Q_ASSERT(m_active_instance);
+    if (!m_active_instance) return; // should never happen
+
+    Kwave::PluginManager *old_mgr = this;
+    old_mgr->m_plugin_instances.removeAll(plugin);
+    old_mgr->m_running_plugins.removeAll(plugin);
+    old_mgr->disconnectPlugin(plugin);
+
+    Kwave::PluginManager *new_mgr = m_active_instance;
+    new_mgr->m_plugin_instances.append(plugin);
+    new_mgr->m_running_plugins.append(plugin);
+    new_mgr->connectPlugin(plugin);
+
+    plugin->setPluginManager(new_mgr);
+}
+
 //***************************************************************************
 #include "PluginManager.moc"
 //***************************************************************************
