@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _PLUGIN_MANAGER_H_
-#define _PLUGIN_MANAGER_H_
+#ifndef PLUGIN_MANAGER_H
+#define PLUGIN_MANAGER_H
 
 #include "config.h"
 
@@ -26,7 +26,7 @@
 #include <QtCore/QMutableListIterator>
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
-#include <QtCore/QVector>
+#include <QtGui/QWidget>
 
 #include <kdemacros.h>
 
@@ -37,7 +37,6 @@
 class QLibrary;
 class QString;
 class QStringList;
-class QWidget;
 
 namespace Kwave
 {
@@ -90,6 +89,9 @@ namespace Kwave
 
 	/**
 	 * Executes a plugin in the context of a given parent widget.
+	 * @param name the name of the plugin
+	 * @param params pointer to a parameter list
+	 *               or null if defaults should be used
 	 * @return zero on success or negative error code
 	 */
 	int executePlugin(const QString &name, QStringList *params);
@@ -104,7 +106,7 @@ namespace Kwave
 	bool onePluginRunning();
 
 	/**
-	 * Waits until all currently running acions have completed.
+	 * Waits until all currently running actions have completed.
 	 */
 	void sync();
 
@@ -112,8 +114,14 @@ namespace Kwave
 	 * Loads a plugin, calls it's setup function and then closes
 	 * it again. The parameters will be loaded before the setup
 	 * and saved if the setup has not been aborted.
+	 * @param name the name of the plugin
+	 * @param params pointer to a parameter list
+	 *               or null if defaults should be used
+	 * @retval  0 if succeeded and accepted
+	 * @retval  1 if canceled
+	 * @retval -1 if failed
 	 */
-	int setupPlugin(const QString &name);
+	int setupPlugin(const QString &name, const QStringList &params);
 
 	/**
 	 * Returns the length of the current signal in samples.
@@ -165,6 +173,14 @@ namespace Kwave
 	 */
 	Kwave::PlaybackController &playbackController();
 
+	/**
+	 * assigns a new parent widget, to be used for messages
+	 * @param new_parent pointer to a QWidget
+	 */
+	inline void setParentWidget(QWidget *new_parent) {
+	    m_parent_widget = new_parent;
+	}
+
 	/** returns a pointer to the parent widget */
 	inline QPointer<QWidget> parentWidget()
 	{
@@ -229,6 +245,18 @@ namespace Kwave
 	 */
 	const QList<PluginModule> pluginInfoList() const;
 
+	/**
+	 * Migrate a plugin to the currently active file context (which
+	 * might be different from the one that is currently executing
+	 * the plugin). The plugin will be removed from our lists and
+	 * inserted into the currently active plugin manager instance.
+	 * @param plugin the plugin to migrate
+	 */
+	void migratePluginToActiveContext(Kwave::Plugin *plugin);
+
+	/** Let this instance be the active one */
+	void setActive() { m_active_instance = this; }
+
     signals:
 
 	/**
@@ -337,6 +365,9 @@ namespace Kwave
 
     private:
 
+	/** pointer to the currently active instance */
+	static Kwave::PluginManager *m_active_instance;
+
 	/**
 	 * map with plugin information: key = short name of the plugin,
 	 * data = plugin info (description, author, version etc...)
@@ -357,10 +388,11 @@ namespace Kwave
 
 	/** interface for registering a SignalView */
 	ViewManager *m_view_manager;
+
     };
 }
 
-#endif /* _PLUGIN_MANAGER_H_ */
+#endif /* PLUGIN_MANAGER_H */
 
 //***************************************************************************
 //***************************************************************************
