@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _SAMPLE_ARRAY_H_
-#define _SAMPLE_ARRAY_H_
+#ifndef SAMPLE_ARRAY_H
+#define SAMPLE_ARRAY_H
 
 #include "config.h"
 
@@ -46,7 +46,7 @@ namespace Kwave
 	 * (not initialized)
 	 * @param size number of samples to hold
 	 */
-	SampleArray(unsigned int size);
+	explicit SampleArray(unsigned int size);
 
 	/** Destructor */
 	virtual ~SampleArray();
@@ -154,7 +154,7 @@ namespace Kwave
     };
 }
 
-#endif /* _SAMPLE_ARRAY_H_ */
+#endif /* SAMPLE_ARRAY_H */
 
 //***************************************************************************
 //***************************************************************************
