@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _SAMPLE_ENCODER_H_
-#define _SAMPLE_ENCODER_H_
+#ifndef SAMPLE_ENCODER_H
+#define SAMPLE_ENCODER_H
 
 #include "config.h"
 
@@ -54,7 +54,7 @@ namespace Kwave
     };
 }
 
-#endif /* _SAMPLE_ENCODER_H_ */
+#endif /* SAMPLE_ENCODER_H */
 
 //***************************************************************************
 //***************************************************************************
