@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _SAMPLE_FIFO_H_
-#define _SAMPLE_FIFO_H_
+#ifndef SAMPLE_FIFO_H
+#define SAMPLE_FIFO_H
 
 #include "config.h"
 
@@ -75,7 +75,7 @@ namespace Kwave
 	virtual void setSize(unsigned int size);
 
 	/**
-	 * discards all superflous content until the size
+	 * discards all superfluous content until the size
 	 * condition is met.
 	 */
 	virtual void crop();
@@ -105,7 +105,7 @@ namespace Kwave
     };
 }
 
-#endif /* _SAMPLE_FIFO_H_ */
+#endif /* SAMPLE_FIFO_H */
 
 //***************************************************************************
 //***************************************************************************
