@@ -16,8 +16,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _SAMPLE_READER_H_
-#define _SAMPLE_READER_H_
+#ifndef SAMPLE_READER_H
+#define SAMPLE_READER_H
 
 #include "config.h"
 
@@ -88,7 +88,7 @@ namespace Kwave
 	                  unsigned int length);
 
 	/**
-	 * Returns the minumum and maximum sample value within a range
+	 * Returns the minimum and maximum sample value within a range
 	 * of samples.
 	 * @param first index of the first sample
 	 * @param last index of the last sample
@@ -205,7 +205,7 @@ namespace Kwave
     };
 }
 
-#endif /* _SAMPLE_READER_H_ */
+#endif /* SAMPLE_READER_H */
 
 //***************************************************************************
 //***************************************************************************
