@@ -95,10 +95,10 @@ Kwave::SignalManager::SignalManager(QWidget *parent)
 {
     // connect to the track's signals
     Kwave::Signal *sig = &m_signal;
-    connect(sig, SIGNAL(sigTrackInserted(unsigned int, Kwave::Track *)),
-            this, SLOT(slotTrackInserted(unsigned int, Kwave::Track *)));
-    connect(sig, SIGNAL(sigTrackDeleted(unsigned int, Kwave::Track *)),
-            this, SLOT(slotTrackDeleted(unsigned int, Kwave::Track *)));
+    connect(sig, SIGNAL(sigTrackInserted(uint,Kwave::Track*)),
+            this, SLOT(slotTrackInserted(uint,Kwave::Track*)));
+    connect(sig, SIGNAL(sigTrackDeleted(uint,Kwave::Track*)),
+            this, SLOT(slotTrackDeleted(uint,Kwave::Track*)));
     connect(sig, SIGNAL(sigTrackSelectionChanged(bool)),
             this,SIGNAL(sigTrackSelectionChanged(bool)));
     connect(sig, SIGNAL(sigSamplesDeleted(unsigned int, sample_index_t,
@@ -127,6 +127,20 @@ int Kwave::SignalManager::loadFile(const KUrl &url)
     int res = 0;
     Kwave::FileProgress *dialog = 0;
 
+    // take over the new file name, so that we have a valid signal
+    // name during loading
+    QString filename = url.path();
+    QFile src(filename);
+    QFileInfo fi(src);
+    {
+	Kwave::FileInfo info(m_meta_data);
+	info.set(Kwave::INF_FILENAME, fi.absoluteFilePath());
+	m_meta_data.replace(Kwave::MetaDataList(info));
+    }
+
+    // work with a copy of meta data, to avoid flicker effects
+    Kwave::MetaDataList meta_data(m_meta_data);
+
     // enter and stay in not modified state
     enableModifiedChange(true);
     setModified(false);
@@ -144,8 +158,6 @@ int Kwave::SignalManager::loadFile(const KUrl &url)
 	m_signal.close();
 
 	// open the source file
-	QString filename = url.path();
-	QFile src(filename);
 	if (!(res = decoder->open(m_parent_widget, src))) {
 	    qWarning("unable to open source: '%s'", DBG(url.prettyUrl()));
 	    res = -EIO;
@@ -153,8 +165,11 @@ int Kwave::SignalManager::loadFile(const KUrl &url)
 	}
 
 	// get the initial meta data from the decoder
-	m_meta_data = decoder->metaData();
-	Kwave::FileInfo info(m_meta_data);
+	meta_data = decoder->metaData();
+	Kwave::FileInfo info(meta_data);
+
+	// take the preliminary meta data, needed for estimated length
+	m_meta_data = meta_data;
 
 	// detect stream mode. if so, use one sample as display
 	bool streaming = (!info.length());
@@ -223,8 +238,8 @@ int Kwave::SignalManager::loadFile(const KUrl &url)
 	} else {
 	    // read information back from the decoder, some settings
 	    // might have become available during the decoding process
-	    m_meta_data = decoder->metaData();
-	    info = Kwave::FileInfo(m_meta_data);
+	    meta_data = decoder->metaData();
+	    info = Kwave::FileInfo(meta_data);
 	}
 
 	decoder->close();
@@ -242,7 +257,6 @@ int Kwave::SignalManager::loadFile(const KUrl &url)
 	}
 
 	// enter the filename/mimetype and size into the file info
-	QFileInfo fi(src);
 	info.set(Kwave::INF_FILENAME, fi.absoluteFilePath());
 	info.set(Kwave::INF_FILESIZE, src.size());
 	if (!info.contains(Kwave::INF_MIMETYPE))
@@ -252,7 +266,8 @@ int Kwave::SignalManager::loadFile(const KUrl &url)
 	info.set(Kwave::INF_ESTIMATED_LENGTH, QVariant());
 
 	// take over the decoded and updated file info
-	m_meta_data.replace(info);
+	meta_data.replace(Kwave::MetaDataList(info));
+	m_meta_data = meta_data;
 
 	// update the length info in the progress dialog if needed
 	if (dialog && use_src_size) {
@@ -272,8 +287,8 @@ int Kwave::SignalManager::loadFile(const KUrl &url)
 	delete decoder;
     }
 
-    // flush the envent queue, to avoid delayed modifications of the signal
-    qApp->sendPostedEvents();
+    // process any queued events of the writers, like "sigSamplesInserted"
+    qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
 
     // remember the last length and selection
     m_last_length = length();
@@ -344,7 +359,7 @@ int Kwave::SignalManager::save(const KUrl &url, bool selection)
 		qWarning("SignalManager::save(): unsupported property '%s'",
 		    DBG(file_info.name(it.key())));
 		all_supported = false;
-		lost_properties += i18n(__(file_info.name(it.key()))) + _("\n");
+		lost_properties += i18n(UTF8(file_info.name(it.key()))) + _("\n");
 	    }
 	}
 	if (!all_supported) {
@@ -421,7 +436,7 @@ int Kwave::SignalManager::save(const KUrl &url, bool selection)
 
 	// invoke the encoder...
 	bool encoded = false;
-	m_meta_data.replace(file_info);
+	m_meta_data.replace(Kwave::MetaDataList(file_info));
 
 	if (selection) {
 	    // use a copy, don't touch the original !
@@ -437,13 +452,13 @@ int Kwave::SignalManager::save(const KUrl &url, bool selection)
 	    // file which is currently open keeps it's name
 	    Kwave::FileInfo info(meta);
 	    info.set(Kwave::INF_FILENAME, filename);
-	    meta.replace(info);
+	    meta.replace(Kwave::MetaDataList(info));
 
 	    encoded = encoder->encode(m_parent_widget, src, dst, meta);
 	} else {
 	    // in case of a "save as" -> modify the current filename
 	    file_info.set(Kwave::INF_FILENAME, filename);
-	    m_meta_data.replace(file_info);
+	    m_meta_data.replace(Kwave::MetaDataList(file_info));
 	    encoded = encoder->encode(m_parent_widget, src, dst, m_meta_data);
 	}
 	if (!encoded) {
@@ -502,19 +517,22 @@ void Kwave::SignalManager::newSignal(sample_index_t samples, double rate,
     file_info.setRate(rate);
     file_info.setBits(bits);
     file_info.setTracks(tracks);
-    m_meta_data.replace(file_info);
+    m_meta_data.replace(Kwave::MetaDataList(file_info));
 
     // now the signal is considered not to be empty
     m_closed = false;
     m_empty = false;
 
     // add all empty tracks
-    while (tracks--) m_signal.appendTrack(samples, 0);
+    while (tracks) {
+	m_signal.appendTrack(samples, 0);
+	tracks--;
+    }
 
     // remember the last length
     m_last_length = samples;
     file_info.setLength(length());
-    m_meta_data.replace(file_info);
+    m_meta_data.replace(Kwave::MetaDataList(file_info));
     rememberCurrentSelection();
 
     // from now on, undo is enabled
@@ -670,22 +688,24 @@ int Kwave::SignalManager::executeCommand(const QString &command)
     CASE_COMMAND("clipboard_flush")
 	Kwave::ClipBoard::instance().clear();
     CASE_COMMAND("crop")
-	Kwave::UndoTransactionGuard undo(*this, i18n("Crop"));
-	sample_index_t rest = this->length() - offset;
-	rest = (rest > length) ? (rest-length) : 0;
-	QList<unsigned int> tracks = selectedTracks();
-	if (saveUndoDelete(tracks, offset+length, rest) &&
-	    saveUndoDelete(tracks, 0, offset))
-	{
-	    // remember the last selection
-	    rememberCurrentSelection();
+	if (length) {
+	    Kwave::UndoTransactionGuard undo(*this, i18n("Crop"));
+	    sample_index_t rest = this->length() - offset;
+	    rest = (rest > length) ? (rest-length) : 0;
+	    QList<unsigned int> tracks = selectedTracks();
+	    if (saveUndoDelete(tracks, offset+length, rest) &&
+		saveUndoDelete(tracks, 0, offset))
+	    {
+		// remember the last selection
+		rememberCurrentSelection();
 
-	    unsigned int count = tracks.count();
-	    while (count--) {
-		m_signal.deleteRange(count, offset+length, rest);
-		m_signal.deleteRange(count, 0, offset);
+		unsigned int count = tracks.count();
+		while (count--) {
+		    m_signal.deleteRange(count, offset+length, rest);
+		    m_signal.deleteRange(count, 0, offset);
+		}
+		selectRange(0, length);
 	    }
-	    selectRange(0, length);
 	}
     CASE_COMMAND("delete")
 	Kwave::UndoTransactionGuard undo(*this, i18n("Delete"));
@@ -730,7 +750,7 @@ int Kwave::SignalManager::executeCommand(const QString &command)
 
 	// the last label <= selection start -> label_left
 	// the first label >= selection end  -> label_right
-	foreach (Kwave::Label label, labels) {
+	foreach (const Kwave::Label &label, labels) {
 	    sample_index_t lp = label.pos();
 	    if (lp <= selection_left)
 		label_left = label;
@@ -782,7 +802,8 @@ int Kwave::SignalManager::executeCommand(const QString &command)
 	// default selection end = end of the file
 	selection_right = (label_right.isNull()) ?
 	    (this->length() - 1) : label_right.pos();
-	sample_index_t len = selection_right - selection_left + 1;
+	sample_index_t len = (selection_right > selection_left) ?
+	    (selection_right - selection_left + 1) : 1;
 	selectRange(selection_left, len);
 
     CASE_COMMAND("selectprevlabels")
@@ -795,7 +816,7 @@ int Kwave::SignalManager::executeCommand(const QString &command)
 	if (labels.isEmpty()) return false; // we need labels for this
 
 	// find the last label before the start of the selection
-	foreach (Kwave::Label label, labels) {
+	foreach (const Kwave::Label &label, labels) {
 	    if (label.pos() > selection_left)
 		break; // done
 	    label_left  = label_right;
@@ -873,9 +894,11 @@ int Kwave::SignalManager::executeCommand(const QString &command)
 	    }
 	}
 
-	if (found)
-	    m_meta_data.replace(info);
-	else
+	if (found) {
+	    m_meta_data.replace(Kwave::MetaDataList(info));
+	    // we now have new meta data
+	    emit sigMetaDataChanged(m_meta_data);
+	} else
 	    return -EINVAL;
     CASE_COMMAND("dump_metadata")
 	qDebug("DUMP OF META DATA => %s", DBG(parser.firstParam()));
@@ -975,7 +998,7 @@ void Kwave::SignalManager::slotTrackInserted(unsigned int index,
 
     Kwave::FileInfo file_info(m_meta_data);
     file_info.setTracks(tracks());
-    m_meta_data.replace(file_info);
+    m_meta_data.replace(Kwave::MetaDataList(file_info));
 
     emit sigTrackInserted(index, track);
     emit sigMetaDataChanged(m_meta_data);
@@ -989,7 +1012,7 @@ void Kwave::SignalManager::slotTrackDeleted(unsigned int index,
 
     Kwave::FileInfo file_info(m_meta_data);
     file_info.setTracks(tracks());
-    m_meta_data.replace(file_info);
+    m_meta_data.replace(Kwave::MetaDataList(file_info));
 
     emit sigTrackDeleted(index, track);
     emit sigMetaDataChanged(m_meta_data);
@@ -1014,7 +1037,7 @@ void Kwave::SignalManager::slotSamplesInserted(unsigned int track,
 
     Kwave::FileInfo info(m_meta_data);
     info.setLength(m_last_length);
-    m_meta_data.replace(info);
+    m_meta_data.replace(Kwave::MetaDataList(info));
     emit sigMetaDataChanged(m_meta_data);
 }
 
@@ -1037,7 +1060,7 @@ void Kwave::SignalManager::slotSamplesDeleted(unsigned int track,
 
     Kwave::FileInfo info(m_meta_data);
     info.setLength(m_last_length);
-    m_meta_data.replace(info);
+    m_meta_data.replace(Kwave::MetaDataList(info));
     emit sigMetaDataChanged(m_meta_data);
 }
 
@@ -1380,9 +1403,9 @@ bool Kwave::SignalManager::continueWithoutUndo()
 	_("</b><br><br><i>") +
 	i18n("<b>Hint</b>: you can configure the amount of memory<br>"
 	     "available for undo under '%1'/'%2'.").arg(
-	     i18n("&Options").replace(QRegExp(_("&(.)")),
+	     i18n("Settings").replace(QRegExp(_("&(.)")),
 	     _("<u>\\1</u>"))).arg(
-	     i18n("&Memory").replace(QRegExp(_("&(.)")),
+	     i18n("Memory").replace(QRegExp(_("&(.)")),
 	     _("<u>\\1</u>")) +
 	_("</i></html>"))) == KMessageBox::Continue)
     {
@@ -1829,11 +1852,12 @@ void Kwave::SignalManager::setFileInfo(Kwave::FileInfo &new_info,
 	                                             i18n("Modify File Info"));
 	Kwave::FileInfo old_inf(m_meta_data);
 	if (!registerUndoAction(
-	    new(std::nothrow) Kwave::UndoModifyMetaDataAction(old_inf)))
+	    new(std::nothrow) Kwave::UndoModifyMetaDataAction(
+		Kwave::MetaDataList(old_inf))))
 	    return;
     }
 
-    m_meta_data.replace(new_info);
+    m_meta_data.replace(Kwave::MetaDataList(new_info));
     setModified(true);
     emitUndoRedoInfo();
     emit sigMetaDataChanged(m_meta_data);
@@ -1874,7 +1898,8 @@ Kwave::Label Kwave::SignalManager::addLabel(sample_index_t pos,
     // register the undo action
     if (m_undo_enabled) {
 	Kwave::UndoTransactionGuard undo(*this, i18n("Add Label"));
-	if (!registerUndoAction(new(std::nothrow) UndoAddMetaDataAction(label)))
+	if (!registerUndoAction(new(std::nothrow) UndoAddMetaDataAction(
+	        Kwave::MetaDataList(label))))
 	    return Kwave::Label();
     }
 
@@ -1894,8 +1919,6 @@ void Kwave::SignalManager::deleteLabel(int index, bool with_undo)
 {
     Kwave::LabelList labels(m_meta_data);
 
-    Q_ASSERT(index >= 0);
-    Q_ASSERT(index < Kwave::toInt(labels.count()));
     if ((index < 0) || (index >= Kwave::toInt(labels.count()))) return;
 
     Kwave::MetaData label(labels.at(index));
@@ -1904,7 +1927,7 @@ void Kwave::SignalManager::deleteLabel(int index, bool with_undo)
     if (with_undo) {
 	Kwave::UndoTransactionGuard undo(*this, i18n("Delete Label"));
 	if (!registerUndoAction(new(std::nothrow)
-	    UndoDeleteMetaDataAction(label)))
+	    UndoDeleteMetaDataAction(Kwave::MetaDataList(label))))
 	    return;
     }
 
@@ -1921,8 +1944,6 @@ bool Kwave::SignalManager::modifyLabel(int index, sample_index_t pos,
                                        const QString &name)
 {
     Kwave::LabelList labels(m_meta_data);
-    Q_ASSERT(index >= 0);
-    Q_ASSERT(index < Kwave::toInt(labels.count()));
     if ((index < 0) || (index >= Kwave::toInt(labels.count())))
 	return false;
 
@@ -1936,7 +1957,8 @@ bool Kwave::SignalManager::modifyLabel(int index, sample_index_t pos,
     // add a undo action
     if (m_undo_enabled) {
 	Kwave::UndoModifyMetaDataAction *undo_modify =
-	    new(std::nothrow) Kwave::UndoModifyMetaDataAction(label);
+	    new(std::nothrow) Kwave::UndoModifyMetaDataAction(
+	            Kwave::MetaDataList(label));
 	if (!registerUndoAction(undo_modify))
 	    return false;
     }
