@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _SIGNAL_MANAGER_H_
-#define _SIGNAL_MANAGER_H_
+#ifndef SIGNAL_MANAGER_H
+#define SIGNAL_MANAGER_H
 
 #include "config.h"
 #include <limits.h>
@@ -68,13 +68,11 @@ namespace Kwave
 
     public:
 	/** Default constructor. */
-	SignalManager(QWidget *parent);
+	explicit SignalManager(QWidget *parent);
 
 	/** Default destructor */
 	virtual ~SignalManager();
 
-    public:
-
 	/**
 	 * Closes the current signal and loads a new file.
 	 * @param url URL of the file to be loaded
@@ -266,7 +264,7 @@ namespace Kwave
 	}
 
 	/**
-	 * Opens a stream for reading samples. If the the last position
+	 * Opens a stream for reading samples. If the last position
 	 * is omitted, the value UINT_MAX will be used.
 	 * @param mode a reader mode, see SampleReader::Mode
 	 * @param track index of the track. If the track does not exist, this
@@ -336,7 +334,7 @@ namespace Kwave
 	void disableUndo();
 
 	/**
-	 * Sets a complete set of file infos, including undo information
+	 * Sets a complete set of file info, including undo information
 	 * @param new_info a new FileInfo
 	 * @param with_undo if true, store undo information
 	 */
@@ -404,6 +402,14 @@ namespace Kwave
 	    return m_signal.uuidOfTrack(track);
 	}
 
+	/**
+	 * assigns a new parent widget, to be used for messages
+	 * @param new_parent pointer to a QWidget
+	 */
+	inline void setParentWidget(QWidget *new_parent) {
+	    m_parent_widget = new_parent;
+	}
+
     signals:
 
 	/**
@@ -761,7 +767,7 @@ namespace Kwave
     };
 }
 
-#endif  /* _SIGNAL_MANAGER_H_ */
+#endif  /* SIGNAL_MANAGER_H */
 
 //***************************************************************************
 //***************************************************************************
