@@ -67,27 +67,6 @@ unsigned int Kwave::Stripe::MappedArray::copy(unsigned int dst,
     return cnt;
 }
 
-//***************************************************************************
-unsigned int Kwave::Stripe::MappedArray::copy(unsigned int dst,
-    const Kwave::SampleArray &source, unsigned int offset,
-    unsigned int cnt)
-{
-//  qDebug("    Stripe::MappedArray::copy(%u, ... ,%u, %u)", dst,
-//         offset, cnt);
-    if (!m_length || !m_storage) return 0;
-
-#ifdef STRICTLY_QT
-    unsigned int rest = cnt;
-    while (rest--) {
-	(*this)[dst++] = source[offset++];
-    }
-#else
-    MEMCPY(&(m_storage[dst]), &(source[offset]), cnt * sizeof(sample_t));
-#endif
-
-    return cnt;
-}
-
 //***************************************************************************
 unsigned int Kwave::Stripe::MappedArray::read(Kwave::SampleArray &buffer,
     unsigned int dstoff, unsigned int offset,  unsigned int length)
@@ -600,10 +579,11 @@ void Kwave::Stripe::minMax(unsigned int first, unsigned int last,
 	}
 	remaining -= block;
     }
-    while (Q_LIKELY(remaining--)) {
+    while (Q_LIKELY(remaining)) {
 	register sample_t s = *(buffer++);
 	if (Q_UNLIKELY(s < lo)) lo = s;
 	if (Q_UNLIKELY(s > hi)) hi = s;
+	remaining--;
     }
     min = lo;
     max = hi;
