@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _STRIPE_H_
-#define _STRIPE_H_
+#ifndef STRIPE_H
+#define STRIPE_H
 
 #include "config.h"
 
@@ -163,7 +163,7 @@ namespace Kwave
 	                  unsigned int offset, unsigned int length);
 
 	/**
-	 * Returns the minumum and maximum sample value within a range
+	 * Returns the minimum and maximum sample value within a range
 	 * of samples.
 	 * @param first index of the first sample
 	 * @param last index of the last sample
@@ -250,7 +250,7 @@ namespace Kwave
 	     * Constructor
 	     * @param stripe should be *this of the stripe
 	     */
-	    MappedArray(Stripe &stripe);
+	    explicit MappedArray(Stripe &stripe);
 
 	    /** Destructor */
 	    virtual ~MappedArray();
@@ -268,20 +268,6 @@ namespace Kwave
 	    unsigned int copy(unsigned int dst, unsigned int src,
 	                      unsigned int cnt);
 
-	    /**
-	     * Copy a portion of samples from an array of samples.
-	     *
-	     * @param dst destination index [samples]
-	     * @param source array with samples to copy from
-	     * @param offset offset within the source array to start copy
-	     * @param cnt number of samples
-	     * @return cnt if succeeded or zero if the mapping has failed
-	     * @note this is optimized for speed, no range checks!
-	     */
-	    unsigned int copy(unsigned int dst,
-	                      const Kwave::SampleArray &source,
-	                      unsigned int offset, unsigned int cnt);
-
 	    /**
 	     * Read a portion of samples into an array of samples.
 	     *
@@ -372,7 +358,7 @@ namespace Kwave
     };
 }
 
-#endif /* _STRIPE_H_ */
+#endif /* STRIPE_H */
 
 //***************************************************************************
 //***************************************************************************
