@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _SWAP_FILE_H_
-#define _SWAP_FILE_H_
+#ifndef SWAP_FILE_H
+#define SWAP_FILE_H
 
 #include "config.h"
 #include <sys/types.h>  // for size_t
@@ -37,7 +37,7 @@ namespace Kwave
 	 * @param name full path to the swap file, actually a template
 	 *             that <b>must</b> contain 6 "X" characters at the end!
 	 */
-	SwapFile(const QString &name);
+	explicit SwapFile(const QString &name);
 
 	/** Destructor */
 	virtual ~SwapFile();
@@ -140,7 +140,7 @@ namespace Kwave
     };
 }
 
-#endif /* _SWAP_FILE_H_ */
+#endif /* SWAP_FILE_H */
 
 //***************************************************************************
 //***************************************************************************
