@@ -57,7 +57,7 @@ bool Kwave::ChannelMixer::init()
     if (m_input_queue.count() != Kwave::toInt(m_inputs)) return false;
 
     // create the buffers for the output data
-    for (unsigned int index = 0; index < m_outputs; index++) {
+    for (unsigned int index = 0; index < m_outputs; ++index) {
 	// create a buffer for the input
 	Kwave::SampleBuffer *out_buffer = new Kwave::SampleBuffer();
 	Q_ASSERT(out_buffer);
@@ -66,15 +66,15 @@ bool Kwave::ChannelMixer::init()
     }
 
     // create indexing proxies and connect their output to this mixer
-    for (unsigned int index = 0; index < m_inputs; index++) {
+    for (unsigned int index = 0; index < m_inputs; ++index) {
 	Kwave::StreamObject *indexer = new Kwave::Indexer(index);
 	Q_ASSERT(indexer);
 	if (!indexer) return false;
 
 	m_indexer.append(indexer);
 	bool ok = Kwave::connect(
-	    *indexer, SIGNAL(output(unsigned int, Kwave::SampleArray)),
-	    *this,    SLOT(idxInput(unsigned int, Kwave::SampleArray)));
+	    *indexer, SIGNAL(output(uint,Kwave::SampleArray)),
+	    *this,    SLOT(idxInput(uint,Kwave::SampleArray)));
 	Q_ASSERT(ok);
 	if (!ok) return false;
     }
@@ -128,7 +128,7 @@ unsigned int Kwave::ChannelMixer::tracksOfPort(const char *port) const
 	// output ports
 	return m_outputs;
     } else if (_sig(port) ==
-               _sig(SLOT(idxInput(unsigned int, Kwave::SampleArray)))) {
+               _sig(SLOT(idxInput(uint,Kwave::SampleArray)))) {
 	return 1;
     }
     qFatal("unknown port");
@@ -152,7 +152,7 @@ Kwave::StreamObject *Kwave::ChannelMixer::port(const char *port,
 	if (Kwave::toInt(track) >= m_output_buffer.count()) return 0;
 	return m_output_buffer[track];
     } else if (_sig(port) ==
-	       _sig(SLOT(idxInput(unsigned int, Kwave::SampleArray)))) {
+	       _sig(SLOT(idxInput(uint,Kwave::SampleArray)))) {
 	return this;
     }
     qFatal("unknown port");
