@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _INDEXER_H_
-#define _INDEXER_H_
+#ifndef INDEXER_H
+#define INDEXER_H
 
 #include "config.h"
 
@@ -61,7 +61,7 @@ namespace Kwave
 
 }
 
-#endif /* _INDEXER_H_ */
+#endif /* INDEXER_H */
 
 //***************************************************************************
 //***************************************************************************
