@@ -116,10 +116,10 @@ void Kwave::Mul::multiply()
 	return;
 
     // do the multiplication of the whole buffer
-    while (count--)
+    for (; count; count--)
     {
-	if (!m_a_is_const) a = sample2float(*(p_a++));
-	if (!m_b_is_const) b = sample2float(*(p_b++));
+	if (!m_a_is_const) { a = sample2float(*p_a); ++p_a; }
+	if (!m_b_is_const) { b = sample2float(*p_b); ++p_b; }
 	float y = a * b;
 	if (y >  1.0) y =  1.0;
 	if (y < -1.0) y = -1.0;
