@@ -17,57 +17,24 @@
 
 #include "config.h"
 
-#include <threadweaver/DebuggingAids.h>
+#include <QtCore/QFuture>
+#include <QtCore/QtConcurrentRun>
 
 #include "libkwave/Utils.h"
 #include "libkwave/modules/SampleBuffer.h"
 
-//***************************************************************************
-Kwave::SampleBuffer::BufferJob::BufferJob(Kwave::SampleBuffer *buffer)
-    :ThreadWeaver::Job(), m_buffer(buffer), m_data(), m_sema(1)
-{
-}
-
-//***************************************************************************
-Kwave::SampleBuffer::BufferJob::~BufferJob()
-{
-    m_sema.acquire();
-
-    int i = 0;
-    while (!isFinished()) {
-	qDebug("buffer job %p waiting... #%u", static_cast<void *>(this), i++);
-	Kwave::yield();
-    }
-    Q_ASSERT(isFinished());
-}
-
-//***************************************************************************
-void Kwave::SampleBuffer::BufferJob::enqueue(Kwave::SampleArray data)
-{
-    m_sema.acquire();
-    m_data = data;
-}
-
-//***************************************************************************
-void Kwave::SampleBuffer::BufferJob::run()
-{
-    if (!m_buffer) return;
-    m_buffer->emitData(m_data);
-    m_sema.release();
-}
-
 //***************************************************************************
 //***************************************************************************
 Kwave::SampleBuffer::SampleBuffer(QObject *parent)
     :Kwave::SampleSink(parent),
-     m_data(), m_offset(0), m_buffered(0), m_weaver(), m_job(this)
+     m_data(), m_offset(0), m_buffered(0), m_sema(1)
 {
 }
 
 //***************************************************************************
 Kwave::SampleBuffer::~SampleBuffer()
 {
-    m_weaver.finish();
+    m_sema.acquire();
 }
 
 //***************************************************************************
@@ -83,7 +50,7 @@ Kwave::SampleArray &Kwave::SampleBuffer::data()
 }
 
 //***************************************************************************
-const Kwave::SampleArray &Kwave::SampleBuffer::data() const
+const Kwave::SampleArray &Kwave::SampleBuffer::constData() const
 {
     return m_data;
 }
@@ -105,7 +72,7 @@ const sample_t *Kwave::SampleBuffer::get(unsigned int len)
     if (len > size) len = size;
 
     // get a pointer to the raw data
-    const sample_t *raw = m_data.data() + m_offset;
+    const sample_t *raw = m_data.constData() + m_offset;
 
     // advance the offset
     m_offset += len;
@@ -121,7 +88,9 @@ void Kwave::SampleBuffer::put(sample_t sample)
     if (m_buffered >= block_size) finished();
 
     // initial fill of the buffer?
-    if (m_data.size() < block_size) m_data.resize(block_size);
+    bool ok = m_data.resize(block_size);
+    Q_ASSERT(ok);
+    Q_UNUSED(ok);
 
     m_data[m_buffered++] = sample;
     if (m_buffered >= block_size) finished();
@@ -131,12 +100,15 @@ void Kwave::SampleBuffer::put(sample_t sample)
 //***************************************************************************
 void Kwave::SampleBuffer::finished()
 {
-    if (m_buffered && (m_data.size() != m_buffered))
-	m_data.resize(m_buffered);
-    enqueue(m_data);
+    bool ok = true;
 
+    if (m_buffered && (m_data.size() != m_buffered))
+	ok &= m_data.resize(m_buffered);
+
+    enqueue(m_data);
     m_buffered = 0;
-    m_data.resize(Kwave::StreamObject::blockSize());
+    ok &= m_data.resize(Kwave::StreamObject::blockSize());
+    Q_ASSERT(ok);
 }
 
 //***************************************************************************
@@ -144,7 +116,9 @@ void Kwave::SampleBuffer::input(Kwave::SampleArray data)
 {
     // if we have buffered data, flush that first
     if (m_buffered) {
-	m_data.resize(m_buffered);
+	bool ok = m_data.resize(m_buffered);
+	Q_ASSERT(ok);
+	Q_UNUSED(ok);
 	m_buffered = 0;
 	enqueue(m_data);
     }
@@ -158,16 +132,16 @@ void Kwave::SampleBuffer::input(Kwave::SampleArray data)
 //***************************************************************************
 void Kwave::SampleBuffer::enqueue(Kwave::SampleArray data)
 {
-    m_job.enqueue(data);
-    m_weaver.suspend();
-    m_weaver.enqueue(&m_job);
-    m_weaver.resume();
+    m_sema.acquire();
+    QtConcurrent::run(this, &Kwave::SampleBuffer::emitData, data);
 }
 
 //***************************************************************************
 void Kwave::SampleBuffer::emitData(Kwave::SampleArray data)
 {
+    // NOTE: this signal could be connected to a slot that blocks for a while
     emit output(data);
+    m_sema.release();
 }
 
 //***************************************************************************
