@@ -18,6 +18,8 @@
 
 #include "config.h"
 
+#include <new>
+
 #include <QtCore/QVariant>
 #include <QtCore/QtAlgorithms>
 
@@ -77,8 +79,8 @@ Kwave::UndoAddMetaDataAction::UndoAddMetaDataAction(
 
     // fix first/last in case that nothing was found, select everything
     if (first > last) {
-	m_offset = 0;
-	m_length = SAMPLE_INDEX_MAX;
+	m_offset = SAMPLE_INDEX_MAX;
+	m_length = 0;
     } else {
 	m_offset = first;
 	m_length = (last - first) + 1;
@@ -147,13 +149,13 @@ QString Kwave::UndoAddMetaDataAction::description()
 }
 
 //***************************************************************************
-unsigned int Kwave::UndoAddMetaDataAction::undoSize()
+qint64 Kwave::UndoAddMetaDataAction::undoSize()
 {
     return sizeof(*this);
 }
 
 //***************************************************************************
-int Kwave::UndoAddMetaDataAction::redoSize()
+qint64 Kwave::UndoAddMetaDataAction::redoSize()
 {
     return sizeof(UndoDeleteMetaDataAction);
 }
@@ -177,7 +179,7 @@ Kwave::UndoAction *Kwave::UndoAddMetaDataAction::undo(
 
     // store data for redo
     if (with_redo && !meta_data.isEmpty()) {
-	redo = new Kwave::UndoDeleteMetaDataAction(meta_data);
+	redo = new(std::nothrow) Kwave::UndoDeleteMetaDataAction(meta_data);
 	Q_ASSERT(redo);
 	if (redo) redo->store(manager);
     }
