@@ -17,6 +17,9 @@
  ***************************************************************************/
 
 #include "config.h"
+
+#include <new>
+
 #include <klocale.h>
 
 #include "libkwave/SignalManager.h"
@@ -43,9 +46,11 @@ QString Kwave::UndoDeleteMetaDataAction::description()
     if (m_meta_data.isEmpty()) return _("");
 
     QString name;
-    const Kwave::MetaData &m = m_meta_data.values().first();
-    if (m.hasProperty(Kwave::MetaData::STDPROP_TYPE))
-	name = m[Kwave::MetaData::STDPROP_TYPE].toString();
+    {
+	const Kwave::MetaData &m = m_meta_data.values().first();
+	if (m.hasProperty(Kwave::MetaData::STDPROP_TYPE))
+	    name = m[Kwave::MetaData::STDPROP_TYPE].toString();
+    }
 
     // if the meta data list contains only one object: try to find
     // out the object's name
@@ -80,13 +85,13 @@ QString Kwave::UndoDeleteMetaDataAction::description()
 }
 
 //***************************************************************************
-unsigned int Kwave::UndoDeleteMetaDataAction::undoSize()
+qint64 Kwave::UndoDeleteMetaDataAction::undoSize()
 {
     return sizeof(*this);
 }
 
 //***************************************************************************
-int Kwave::UndoDeleteMetaDataAction::redoSize()
+qint64 Kwave::UndoDeleteMetaDataAction::redoSize()
 {
     return sizeof(Kwave::UndoAddMetaDataAction);
 }
@@ -113,7 +118,7 @@ Kwave::UndoAction *Kwave::UndoDeleteMetaDataAction::undo(
 
     // store data for redo
     if (with_redo) {
-	redo = new Kwave::UndoAddMetaDataAction(m_meta_data);
+	redo = new(std::nothrow) Kwave::UndoAddMetaDataAction(m_meta_data);
 	Q_ASSERT(redo);
 	if (redo) redo->store(manager);
     }
