@@ -16,8 +16,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _UNDO_DELETE_TRACK_H_
-#define _UNDO_DELETE_TRACK_H_
+#ifndef UNDO_DELETE_TRACK_H
+#define UNDO_DELETE_TRACK_H
 
 #include "config.h"
 
@@ -88,7 +88,7 @@ namespace Kwave
     };
 }
 
-#endif /* _UNDO_DELETE_TRACK_H_ */
+#endif /* UNDO_DELETE_TRACK_H */
 
 //***************************************************************************
 //***************************************************************************
