@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _LOGO_WIDGET_H_
-#define _LOGO_WIDGET_H_
+#ifndef LOGO_WIDGET_H
+#define LOGO_WIDGET_H
 
 #include "config.h"
 
@@ -38,7 +38,7 @@ namespace Kwave
 
     public:
 	/** Constructor */
-	LogoWidget(QWidget *parent);
+	explicit LogoWidget(QWidget *parent);
 
 	/** Destructor */
 	virtual ~LogoWidget();
@@ -78,7 +78,7 @@ namespace Kwave
     };
 }
 
-#endif  /* _LOGO_WIDGET_H_ */
+#endif  /* LOGO_WIDGET_H */
 
 //***************************************************************************
 //***************************************************************************
