@@ -20,6 +20,7 @@
 #include <QtGui/QPushButton>
 
 #include <klocale.h>
+#include <ktoolinvocation.h>
 
 #include "libkwave/Parser.h"
 #include "libkwave/String.h"
@@ -46,6 +47,9 @@ Kwave::AmplifyFreeDialog::AmplifyFreeDialog(QWidget *parent)
     yScale->setLogMode(false);
     yScale->setUnit(i18n("%"));
 
+    connect(buttonBox_Help->button(QDialogButtonBox::Help), SIGNAL(clicked()),
+            this,   SLOT(invokeHelp()));
+
     // set the focus onto the "OK" button
     buttonBox->button(QDialogButtonBox::Ok)->setFocus();
 }
@@ -88,6 +92,12 @@ void Kwave::AmplifyFreeDialog::setParams(QStringList &params)
     if (curveWidget) curveWidget->setCurve(cmd);
 }
 
+//***************************************************************************
+void Kwave::AmplifyFreeDialog::invokeHelp()
+{
+    KToolInvocation::invokeHelp(_("plugin_sect_amplifyfree"));
+}
+
 //***************************************************************************
 #include "AmplifyFreeDialog.moc"
 //***************************************************************************
