@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _AMPLIFY_FREE_DIALOG_H_
-#define _AMPLIFY_FREE_DIALOG_H_
+#ifndef AMPLIFY_FREE_DIALOG_H
+#define AMPLIFY_FREE_DIALOG_H
 
 #include "config.h"
 
@@ -36,7 +36,7 @@ namespace Kwave
     public:
 
 	/** Constructor */
-	AmplifyFreeDialog(QWidget *parent);
+	explicit AmplifyFreeDialog(QWidget *parent);
 
 	/** Destructor */
 	virtual ~AmplifyFreeDialog();
@@ -47,10 +47,15 @@ namespace Kwave
 	/** Sets the curve parameters and points from a list of parameters */
 	void setParams(QStringList &params);
 
+    private slots:
+
+	/** invoke the online help */
+	void invokeHelp();
+
     };
 }
 
-#endif /* _AMPLIFY_FREE_DIALOG_H_ */
+#endif /* AMPLIFY_FREE_DIALOG_H */
 
 //***************************************************************************
 //***************************************************************************
