@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _AMPLIFY_FREE_PLUGIN_H_
-#define _AMPLIFY_FREE_PLUGIN_H_
+#ifndef AMPLIFY_FREE_PLUGIN_H
+#define AMPLIFY_FREE_PLUGIN_H
 
 #include "config.h"
 
@@ -38,7 +38,7 @@ namespace Kwave
     public:
 
 	/** Constructor */
-	AmplifyFreePlugin(Kwave::PluginManager &plugin_manager);
+	explicit AmplifyFreePlugin(Kwave::PluginManager &plugin_manager);
 
 	/** Destructor */
 	virtual ~AmplifyFreePlugin();
@@ -92,7 +92,7 @@ namespace Kwave
     };
 }
 
-#endif /* _AMPLIFY_FREE_PLUGIN_H_ */
+#endif /* AMPLIFY_FREE_PLUGIN_H */
 
 //***************************************************************************
 //***************************************************************************
