@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _NOTCH_FILTER_DIALOG_H_
-#define _NOTCH_FILTER_DIALOG_H_
+#ifndef NOTCH_FILTER_DIALOG_H
+#define NOTCH_FILTER_DIALOG_H
 
 #include "config.h"
 
@@ -103,6 +103,11 @@ namespace Kwave
 	 */
 	void listenStopped();
 
+    private slots:
+
+	/** invoke the online help */
+	void invokeHelp();
+
     protected:
 
 	/** Update the graphic display */
@@ -125,7 +130,7 @@ namespace Kwave
     };
 }
 
-#endif /* _NOTCH_FILTER_DIALOG_H_ */
+#endif /* NOTCH_FILTER_DIALOG_H */
 
 //***************************************************************************
 //***************************************************************************
