@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _FLAC_DECODER_H_
-#define _FLAC_DECODER_H_
+#ifndef FLAC_DECODER_H
+#define FLAC_DECODER_H
 
 #include "config.h"
 
@@ -143,7 +143,7 @@ namespace Kwave
     };
 }
 
-#endif /* _FLAC_DECODER_H_ */
+#endif /* FLAC_DECODER_H */
 
 //***************************************************************************
 //***************************************************************************
