@@ -15,12 +15,13 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _FLAC_ENCODER_H_
-#define _FLAC_ENCODER_H_
+#ifndef FLAC_ENCODER_H
+#define FLAC_ENCODER_H
 
 #include "config.h"
 
 #include <QtCore/QList>
+#include <QtCore/QVector>
 
 #include <FLAC/format.h>
 #include <FLAC++/encoder.h>
@@ -138,7 +139,7 @@ namespace Kwave
     };
 }
 
-#endif /* _FLAC_ENCODER_H_ */
+#endif /* FLAC_ENCODER_H */
 
 //***************************************************************************
 //***************************************************************************
