@@ -171,6 +171,9 @@ bool Kwave::MP3Decoder::parseMp3Header(const Mp3_Headerinfo &header,
 	int modeext = header.modeext;
 	if (header.layer >= 3) modeext += 4;
 	info.set(Kwave::INF_MPEG_MODEEXT, modeext);
+    } else {
+	int modeext = header.modeext;
+	info.set(Kwave::INF_MPEG_MODEEXT, modeext);
     }
 
     /* Emphasis mode */
@@ -192,7 +195,7 @@ bool Kwave::MP3Decoder::parseMp3Header(const Mp3_Headerinfo &header,
     info.setBits(SAMPLE_BITS);      // fake Kwave's default resolution
     info.setLength(header.time * header.frequency);
 
-    metaData().replace(info);
+    metaData().replace(Kwave::MetaDataList(info));
 
     return true;
 }
@@ -262,7 +265,7 @@ bool Kwave::MP3Decoder::parseID3Tags(ID3_Tag &tag)
 		    ID3_FreeString(lang);
 		}
 
-		// append to already existing tag, seperated by a slash
+		// append to already existing tag, separated by a slash
 		if (info.contains(property))
 		    s = info.get(property).toString() + _(" / ") + s;
 		info.set(property, QVariant(s));
@@ -336,7 +339,7 @@ bool Kwave::MP3Decoder::parseID3Tags(ID3_Tag &tag)
 	    }
 	    case ID3_PropertyMap::ENC_TEXT_SLASH:
 	    {
-		// append to already existing tag, seperated by a slash
+		// append to already existing tag, separated by a slash
 		QString s = parseId3Frame2String(frame);
 		if (info.contains(property))
 		    s = info.get(property).toString() + _(" / ") + s;
@@ -380,7 +383,7 @@ bool Kwave::MP3Decoder::parseID3Tags(ID3_Tag &tag)
 	info.set(Kwave::INF_CREATION_DATE, creation_date.toString(_("yyyy")));
     }
 
-    metaData().replace(info);
+    metaData().replace(Kwave::MetaDataList(info));
 
     return true;
 }
@@ -406,7 +409,6 @@ bool Kwave::MP3Decoder::open(QWidget *widget, QIODevice &src)
     if (m_source) qWarning("MP3Decoder::open(), already open !");
 
     /* open the file in readonly mode with seek enabled */
-    Q_ASSERT(!src.isSequential());
     if (src.isSequential()) return false;
     if (!src.open(QIODevice::ReadOnly)) {
 	qWarning("unable to open source in read-only mode!");
@@ -449,7 +451,7 @@ bool Kwave::MP3Decoder::open(QWidget *widget, QIODevice &src)
     m_source = &src;
     Kwave::FileInfo info(metaData());
     info.set(Kwave::INF_MIMETYPE, _("audio/mpeg"));
-    metaData().replace(info);
+    metaData().replace(Kwave::MetaDataList(info));
 
     // allocate a transfer buffer with 128 kB
     if (m_buffer) free(m_buffer);
