@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _MP3_DECODER_H_
-#define _MP3_DECODER_H_
+#ifndef MP3_DECODER_H
+#define MP3_DECODER_H
 
 #include "config.h"
 
@@ -132,7 +132,7 @@ namespace Kwave
     };
 }
 
-#endif /* _MP3_DECODER_H_ */
+#endif /* MP3_DECODER_H */
 
 //***************************************************************************
 //***************************************************************************
