@@ -280,7 +280,7 @@ bool Kwave::MP3Encoder::encode(QWidget *widget, Kwave::MultiTrackReader &src,
     const sample_index_t length   = src.last() - src.first() + 1;
     unsigned int       bits       = qBound(8U, ((info.bits() + 7) & ~0x7), 32U);
     const double       rate       = info.rate();
-    const unsigned int out_tracks = qMax(tracks, 2U);
+    const unsigned int out_tracks = qMin(tracks, 2U);
 
     // when encoding track count > 2, show a warning that we will mix down
     // to stereo
@@ -378,14 +378,14 @@ bool Kwave::MP3Encoder::encode(QWidget *widget, Kwave::MultiTrackReader &src,
 	int emphasis = info.get(Kwave::INF_MPEG_EMPHASIS).toInt();
 	switch (emphasis) {
 	    case  1:
-		OPTION(m_encoding.m_emphasis.m_50_15ms);   // 1 = 50/15ms
+		OPTION(m_encoding.m_emphasis.m_50_15ms);  // 1 = 50/15ms
 		break;
 	    case  3:
 		OPTION(m_encoding.m_emphasis.m_ccit_j17); // 3 = CCIT J.17
 		break;
 	    case  0: /* FALLTHROUGH */
 	    default:
-		OPTION(m_encoding.m_emphasis.m_none);      // 0 = none
+		OPTION(m_encoding.m_emphasis.m_none);     // 0 = none
 		break;
 	}
     }
@@ -402,7 +402,7 @@ bool Kwave::MP3Encoder::encode(QWidget *widget, Kwave::MultiTrackReader &src,
     }
 
     OPTION(m_flags.m_protect);          // CRC protection
-    OPTION(m_flags.m_append);           // optional paramters at the end
+    OPTION(m_flags.m_append);           // optional parameters at the end
 
     m_params.append(_("-")); // infile  = stdin
     m_params.append(_("-")); // outfile = stdout
@@ -453,7 +453,7 @@ bool Kwave::MP3Encoder::encode(QWidget *widget, Kwave::MultiTrackReader &src,
 	    const sample_t *src_buf = 0;
 
 	    // fill input buffer with samples
-	    for (x = 0; x < tracks; x++) {
+	    for (x = 0; x < tracks; ++x) {
 		in_samples[x] = 0;
 		Kwave::SampleReader *stream = src[x];
 		Q_ASSERT(stream);
@@ -465,9 +465,9 @@ bool Kwave::MP3Encoder::encode(QWidget *widget, Kwave::MultiTrackReader &src,
 	    if (tracks > 2) {
 		// multiply matrix with input to get output
 		const Kwave::SampleArray &in = in_samples;
-		for (y = 0; y < out_tracks; y++) {
+		for (y = 0; y < out_tracks; ++y) {
 		    double sum = 0;
-		    for (x = 0; x < tracks; x++)
+		    for (x = 0; x < tracks; ++x)
 			sum += static_cast<double>(in[x]) * mixer[x][y];
 		    out_samples[y] = static_cast<sample_t>(sum);
 		}
@@ -480,7 +480,7 @@ bool Kwave::MP3Encoder::encode(QWidget *widget, Kwave::MultiTrackReader &src,
 	    }
 
 	    // sample conversion from 24bit to raw PCM, native endian
-	    for (y = 0; y < out_tracks; y++) {
+	    for (y = 0; y < out_tracks; ++y) {
 		register sample_t s = *(src_buf++);
 #if Q_BYTE_ORDER == Q_BIG_ENDIAN
 		// big endian
