@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _OGG_CODEC_PLUGIN_H_
-#define _OGG_CODEC_PLUGIN_H_
+#ifndef OGG_CODEC_PLUGIN_H
+#define OGG_CODEC_PLUGIN_H
 
 #include "config.h"
 
@@ -32,7 +32,7 @@ namespace Kwave
     public:
 
 	/** Constructor */
-	OggCodecPlugin(Kwave::PluginManager &plugin_manager);
+	explicit OggCodecPlugin(Kwave::PluginManager &plugin_manager);
 
 	/** Destructor */
 	virtual ~OggCodecPlugin();
@@ -76,7 +76,7 @@ namespace Kwave
 
 #define DEFAULT_MIME_TYPE "audio/ogg"
 
-#endif /* _OGG_CODEC_PLUGIN_H_ */
+#endif /* OGG_CODEC_PLUGIN_H */
 
 //***************************************************************************
 //***************************************************************************
