@@ -78,7 +78,7 @@ int Kwave::VorbisDecoder::open(QWidget *widget, Kwave::FileInfo &info)
     // I handle the initial header first instead of just having the code
     // read all three Vorbis headers at once because reading the initial
     // header is an easy way to identify a Vorbis bitstream and it's
-    // useful to see that functionality seperated out.
+    // useful to see that functionality separated out.
     vorbis_info_init(&m_vi);
     vorbis_comment_init(&m_vc);
 
@@ -152,13 +152,16 @@ int Kwave::VorbisDecoder::open(QWidget *widget, Kwave::FileInfo &info)
     info.setRate(m_vi.rate);
     info.set(Kwave::INF_COMPRESSION, Kwave::Compression::OGG_VORBIS);
     info.set(Kwave::INF_SOURCE, _(m_vc.vendor));
-    if (m_vi.bitrate_nominal > 0)
+    if ((m_vi.bitrate_nominal > 0) &&
+	(m_vi.bitrate_nominal < std::numeric_limits<int>::max()))
 	info.set(Kwave::INF_BITRATE_NOMINAL,
 	QVariant(Kwave::toInt(m_vi.bitrate_nominal)));
-    if (m_vi.bitrate_lower > 0)
+    if ((m_vi.bitrate_lower > 0) &&
+	(m_vi.bitrate_lower < std::numeric_limits<int>::max()))
 	info.set(Kwave::INF_BITRATE_LOWER,
 	QVariant(Kwave::toInt(m_vi.bitrate_lower)));
-    if (m_vi.bitrate_upper > 0)
+    if ((m_vi.bitrate_upper > 0) &&
+	(m_vi.bitrate_upper < std::numeric_limits<int>::max()))
 	info.set(Kwave::INF_BITRATE_UPPER,
 	QVariant(Kwave::toInt(m_vi.bitrate_upper)));
 
@@ -208,13 +211,14 @@ int Kwave::VorbisDecoder::open(QWidget *widget, Kwave::FileInfo &info)
     // estimate a length
     // estimate the length of the file from file size, bitrate, channels
     if (!m_source->isSequential()) {
-	int br = -1;
+	long int br = -1;
 	if ((br < 0) && (m_vi.bitrate_nominal > 0)) br = m_vi.bitrate_nominal;
 	if ((br < 0) && (m_vi.bitrate_upper   > 0)) br = m_vi.bitrate_upper;
 	if ((br < 0) && (m_vi.bitrate_lower   > 0)) br = m_vi.bitrate_lower;
 	qint64 file_size       = m_source->size();
 	qreal rate             = m_vi.rate;
-	qreal seconds          = file_size / (br / 8);
+	qreal seconds          = (br > 0) ? (file_size / (br / 8)) :
+	                                     DEFAULT_BITRATE;
 	sample_index_t samples = static_cast<sample_index_t>(seconds * rate);
 
 	qDebug("    estimated length: %llu samples", samples);
