@@ -62,14 +62,14 @@ Kwave::VorbisEncoder::~VorbisEncoder()
 /***************************************************************************/
 void Kwave::VorbisEncoder::encodeProperties(const Kwave::FileInfo &info)
 {
-    foreach (QString key, m_comments_map.keys()) {
+    foreach (const QString &key, m_comments_map.keys()) {
 	Kwave::FileProperty property = m_comments_map[key];
 	if (!info.contains(property)) continue; // skip if not present
 
 	// encode the property as string
 	vorbis_comment_add_tag(&m_vc,
-	    __(key),
-	    __(info.get(property).toString())
+	    UTF8(key),
+	    UTF8(info.get(property).toString())
 	);
     }
 }
@@ -144,13 +144,11 @@ bool Kwave::VorbisEncoder::open(QWidget *widget, const Kwave::FileInfo &info,
 	ret = vorbis_encode_setup_managed(&m_vi, tracks, sample_rate,
 	      -1, bitrate_nominal, -1);
 
-#ifdef OV_ECTL_RATEMANAGE2_SET
+	// If OV_ECTL_RATEMANAGE2_SET is not defined, then your
+	// libvorbis is just too old.
 	if (!ret) ret =
 	      vorbis_encode_ctl(&m_vi, OV_ECTL_RATEMANAGE2_SET, 0) ||
 	      vorbis_encode_setup_init(&m_vi);
-#else /* OV_ECTL_RATEMANAGE2_SET */
-    #warning "OV_ECTL_RATEMANAGE2_SET not supported, maybe libvorbis is too old?"
-#endif /* OV_ECTL_RATEMANAGE2_SET */
 
 	qDebug("VorbisEncoder: CBR with %d Bits/s", bitrate_nominal);
     } else if (vbr_quality >= 0) {
@@ -260,7 +258,7 @@ bool Kwave::VorbisEncoder::encode(Kwave::MultiTrackReader &src,
 		const unsigned int block = 8;
 		pos = 0;
 		while (pos + block < l) {
-		    for (unsigned int i = 0; i < block; i++, pos++)
+		    for (unsigned int i = 0; i < block; ++i, ++pos)
 			p[pos] = sample2float(s[pos]);
 		}
 		while (pos < l) {
