@@ -23,6 +23,8 @@
 #include <QtCore/QtEndian>
 #include <QtCore/QtGlobal>
 #include <QtCore/QList>
+#include <QtCore/QVector>
+
 #include <QtGui/QApplication>
 #include <QtGui/QProgressDialog>
 
@@ -75,7 +77,7 @@ Kwave::WavDecoder::WavDecoder()
     m_known_chunks.append(_("smpl")); /* Sampler */
 
     // add all sub-chunks of the LIST chunk (properties)
-    foreach (QByteArray name, m_property_map.chunks())
+    foreach (const QByteArray &name, m_property_map.chunks())
 	m_known_chunks.append(QLatin1String(name));
 
     // some chunks known from AIFF format
@@ -140,8 +142,8 @@ bool Kwave::WavDecoder::open(QWidget *widget, QIODevice &src)
     progress.setLabelText(i18n("Reading..."));
     connect(&parser,   SIGNAL(progress(int)),
             &progress, SLOT(setValue(int)));
-    connect(&parser,   SIGNAL(action(const QString &)),
-            &progress, SLOT(setLabelText(const QString &)));
+    connect(&parser,   SIGNAL(action(QString)),
+            &progress, SLOT(setLabelText(QString)));
     Kwave::ConfirmCancelProxy confirm_cancel(widget,
                        &progress, SIGNAL(canceled()),
                        &parser,   SLOT(cancel()));
@@ -549,7 +551,7 @@ bool Kwave::WavDecoder::open(QWidget *widget, QIODevice &src)
 	}
     }
     labels.sort();
-    metaData().replace(info);
+    metaData().replace(Kwave::MetaDataList(info));
     metaData().replace(labels.toMetaDataList());
 
     // set up libaudiofile to produce Kwave's internal sample format
@@ -580,11 +582,11 @@ bool Kwave::WavDecoder::decode(QWidget */*widget*/, Kwave::MultiWriter &dst)
     const unsigned int tracks = dst.tracks();
 
     // allocate an array of Writers, for speeding up
-    QVector<Kwave::Writer *>writers;
-    for (unsigned int t = 0; t < tracks; t++)
-	writers.append(dst[t]);
+    QVector<Kwave::Writer *>writers(tracks);
     Q_ASSERT(writers.count() == Kwave::toInt(dst.tracks()));
     if (writers.count() != Kwave::toInt(dst.tracks())) return false;
+    for (unsigned int t = 0; t < tracks; t++)
+	writers[t] = dst[t];
     Kwave::Writer **writer_fast = writers.data();
 
     unsigned int frame_size = Kwave::toUint(
@@ -592,7 +594,8 @@ bool Kwave::WavDecoder::decode(QWidget */*widget*/, Kwave::MultiWriter &dst)
 
     // allocate a buffer for input data
     const unsigned int buffer_frames = (8 * 1024);
-    qint32 *buffer = static_cast<qint32 *>(malloc(buffer_frames * frame_size));
+    sample_storage_t *buffer = static_cast<sample_storage_t *>(
+	malloc(buffer_frames * frame_size));
     Q_ASSERT(buffer);
     if (!buffer) return false;
 
@@ -610,11 +613,10 @@ bool Kwave::WavDecoder::decode(QWidget */*widget*/, Kwave::MultiWriter &dst)
 	rest -= buffer_used;
 
 	// split into the tracks
-	qint32 *p = buffer;
-	unsigned int count = buffer_used;
-	while (count--) {
+	sample_storage_t *p = buffer;
+	for (unsigned int count = buffer_used; count; count--) {
 	    for (unsigned int track = 0; track < tracks; track++) {
-		qint32 s = *p++;
+		sample_storage_t s = *p++;
 
 		// adjust precision
 		if (SAMPLE_STORAGE_BITS != SAMPLE_BITS) {
@@ -622,7 +624,7 @@ bool Kwave::WavDecoder::decode(QWidget */*widget*/, Kwave::MultiWriter &dst)
 		}
 
 		// the following cast is only necessary if
-		// sample_t is not equal to a quint32
+		// sample_t is not equal to a sample_storage_t
 		Q_ASSERT(writer_fast[track]);
 		*(writer_fast[track]) << static_cast<sample_t>(s);
 	    }
