@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _SELECT_DATE_DIALOG_H_
-#define _SELECT_DATE_DIALOG_H_
+#ifndef SELECT_DATE_DIALOG_H
+#define SELECT_DATE_DIALOG_H
 
 #include "config.h"
 
@@ -57,7 +57,7 @@ namespace Kwave
     };
 }
 
-#endif /* _SELECT_DATE_DIALOG_H_ */
+#endif /* SELECT_DATE_DIALOG_H */
 
 //***************************************************************************
 //***************************************************************************
