@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _GOTO_PLUGIN_H_
-#define _GOTO_PLUGIN_H_
+#ifndef GOTO_PLUGIN_H
+#define GOTO_PLUGIN_H
 
 #include "config.h"
 
@@ -34,7 +34,7 @@ namespace Kwave
     public:
 
 	/** Constructor */
-	GotoPlugin(Kwave::PluginManager &plugin_manager);
+	explicit GotoPlugin(Kwave::PluginManager &plugin_manager);
 
 	/** Destructor */
 	virtual ~GotoPlugin();
@@ -53,7 +53,7 @@ namespace Kwave
     };
 }
 
-#endif /* _GOTO_PLUGIN_H_ */
+#endif /* GOTO_PLUGIN_H */
 
 //***************************************************************************
 //***************************************************************************
