@@ -46,15 +46,18 @@ Kwave::GotoPluginBase::~GotoPluginBase()
 //***************************************************************************
 QStringList *Kwave::GotoPluginBase::setup(QStringList &previous_params)
 {
-    // try to interprete the previous parameters
+    // try to interpret the previous parameters
     interpreteParameters(previous_params);
 
     // create the setup dialog
     double rate = signalRate();
     sample_index_t length = signalLength();
 
+    // get the name of the help section
+    QString help_section = _("plugin_sect_") + command();
+
     Kwave::GotoDialog *dialog = new Kwave::GotoDialog(parentWidget(),
-        m_mode, m_position, rate, length);
+        m_mode, m_position, rate, length, help_section);
     Q_ASSERT(dialog);
     if (!dialog) return 0;
 
