@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _LOW_PASS_DIALOG_H_
-#define _LOW_PASS_DIALOG_H_
+#ifndef LOW_PASS_DIALOG_H
+#define LOW_PASS_DIALOG_H
 
 #include "config.h"
 
@@ -93,6 +93,11 @@ namespace Kwave
 	*/
 	void listenStopped();
 
+    private slots:
+
+	/** invoke the online help */
+	void invokeHelp();
+
     protected:
 
 	/** Update the graphic display */
@@ -112,7 +117,7 @@ namespace Kwave
     };
 }
 
-#endif /* _LOW_PASS_DIALOG_H_ */
+#endif /* LOW_PASS_DIALOG_H */
 
 //***************************************************************************
 //***************************************************************************
