@@ -137,15 +137,17 @@ void Kwave::LowPassFilter::normed_setfilter_shelvelowpass(double freq)
 //***************************************************************************
 void Kwave::LowPassFilter::input(Kwave::SampleArray data)
 {
-    if (m_buffer.size() != data.size()) m_buffer.resize(data.size());
+    const Kwave::SampleArray &in = data;
+    bool ok = m_buffer.resize(in.size());
+    Q_ASSERT(ok);
+    Q_UNUSED(ok);
 
     normed_setfilter_shelvelowpass(m_f_cutoff);
-    Q_ASSERT(data.size() == m_buffer.size());
 
-    for (unsigned i = 0; i < data.size(); i++)
+    for (unsigned i = 0; i < in.size(); i++)
     {
 	// do the filtering
-	m_filter.x = sample2float(data[i]);
+	m_filter.x = sample2double(in[i]);
 	m_filter.y =
 	    m_filter.cx  * m_filter.x  +
 	    m_filter.cx1 * m_filter.x1 +
@@ -156,7 +158,7 @@ void Kwave::LowPassFilter::input(Kwave::SampleArray data)
 	m_filter.x1 = m_filter.x;
 	m_filter.y2 = m_filter.y1;
 	m_filter.y1 = m_filter.y;
-	m_buffer[i] = float2sample(0.95 * m_filter.y);
+	m_buffer[i] = double2sample(0.95 * m_filter.y);
     }
 }
 
@@ -202,7 +204,7 @@ void Kwave::LowPassFilter::setFrequency(const QVariant fc)
 {
 
     double new_freq = QVariant(fc).toDouble();
-    if (new_freq == m_f_cutoff) return; // nothing to do
+    if (qFuzzyCompare(new_freq, m_f_cutoff)) return; // nothing to do
 
     m_f_cutoff = new_freq;
     initFilter();
