@@ -97,7 +97,7 @@ void Kwave::LowPassPlugin::updateFilter(Kwave::SampleSource *filter,
     if (!filter) return;
 
     if (!qFuzzyCompare(m_frequency, m_last_freq) || force)
-	filter->setAttribute(SLOT(setFrequency(const QVariant)),
+	filter->setAttribute(SLOT(setFrequency(QVariant)),
 	    QVariant((m_frequency * 2.0 * M_PI) / sr));
 
     m_last_freq  = m_frequency;
