@@ -60,8 +60,8 @@ Kwave::NewSignalDialog::NewSignalDialog(QWidget *parent, sample_index_t samples,
             this, SLOT(rbTimeToggled(bool)));
 
     // connect the file format controls
-    connect(cbSampleRate, SIGNAL(editTextChanged(const QString&)),
-            this, SLOT(sampleRateChanged(const QString&)));
+    connect(cbSampleRate, SIGNAL(editTextChanged(QString)),
+            this, SLOT(sampleRateChanged(QString)));
     connect(sbChannels, SIGNAL(valueChanged(int)),
             this, SLOT(tracksChanged(int)));
     connect(sbResolution, SIGNAL(valueChanged(int)),
@@ -374,7 +374,7 @@ void Kwave::NewSignalDialog::setHMS(sample_index_t &samples)
 //***************************************************************************
 void Kwave::NewSignalDialog::invokeHelp()
 {
-    KToolInvocation::invokeHelp(_("memory-setup"));
+    KToolInvocation::invokeHelp(_("newsignal"));
 }
 
 //***************************************************************************
