@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _NEW_SIGNAL_PLUGIN_H_
-#define _NEW_SIGNAL_PLUGIN_H_
+#ifndef NEW_SIGNAL_PLUGIN_H
+#define NEW_SIGNAL_PLUGIN_H
 
 #include "config.h"
 #include <QtCore/QObject>
@@ -32,7 +32,7 @@ namespace Kwave
     public:
 
 	/** Constructor */
-	NewSignalPlugin(Kwave::PluginManager &plugin_manager);
+	explicit NewSignalPlugin(Kwave::PluginManager &plugin_manager);
 
 	/** virtual Destructor */
 	virtual ~NewSignalPlugin();
@@ -71,7 +71,7 @@ namespace Kwave
     };
 }
 
-#endif /* _NEW_SIGNAL_PLUGIN_H_ */
+#endif /* NEW_SIGNAL_PLUGIN_H */
 
 //***************************************************************************
 //***************************************************************************
