@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _NOISE_DIALOG_H_
-#define _NOISE_DIALOG_H_
+#ifndef NOISE_DIALOG_H
+#define NOISE_DIALOG_H
 
 #include "config.h"
 
@@ -92,6 +92,11 @@ namespace Kwave
 	 */
 	void listenStopped();
 
+    private slots:
+
+	/** invoke the online help */
+	void invokeHelp();
+
     protected:
 
 	/**
@@ -128,7 +133,7 @@ namespace Kwave
     };
 }
 
-#endif /* _NOISE_DIALOG_H_ */
+#endif /* NOISE_DIALOG_H */
 
 //***************************************************************************
 //***************************************************************************
