@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _NOISE_PLUGIN_H_
-#define _NOISE_PLUGIN_H_
+#ifndef NOISE_PLUGIN_H
+#define NOISE_PLUGIN_H
 
 #include "config.h"
 
@@ -33,7 +33,7 @@ namespace Kwave
     public:
 
 	/** Constructor */
-	NoisePlugin(Kwave::PluginManager &plugin_manager);
+	explicit NoisePlugin(Kwave::PluginManager &plugin_manager);
 
 	/** Destructor */
 	virtual ~NoisePlugin();
@@ -96,7 +96,7 @@ namespace Kwave
     };
 }
 
-#endif /* _NOISE_PLUGIN_H_ */
+#endif /* NOISE_PLUGIN_H */
 
 //***************************************************************************
 //***************************************************************************
