@@ -28,7 +28,6 @@
 #include <QtCore/QList>
 #include <QtCore/QStringList>
 #include <QtCore/QThread>
-#include <QtCore/QVector>
 
 #include <klocale.h> // for the i18n macro
 
@@ -133,7 +132,7 @@ void Kwave::NormalizePlugin::run(QStringList params)
     emit setProgressText(i18n("Normalizing (%1 dB) ...",
 	db.sprintf("%+0.1f", 20 * log10(gain))));
 
-    normalizer.setAttribute(SLOT(setGain(const QVariant)), QVariant(gain));
+    normalizer.setAttribute(SLOT(setGain(QVariant)), QVariant(gain));
     while (!shouldStop() && !source.eof()) {
 	source.goOn();
     }
@@ -153,8 +152,7 @@ double Kwave::NormalizePlugin::getMaxPower(Kwave::MultiTrackReader &source)
     // set up smoothing window buffer
     QVector<Kwave::NormalizePlugin::Average> average(tracks);
     for (unsigned int t = 0; t < tracks; t++) {
-	average[t].fifo.resize(SMOOTHLEN);
-	average[t].fifo.fill(0.0);
+	average[t].fifo = QVector<double>(SMOOTHLEN, double(0.0));
 	average[t].wp  = 0;
 	average[t].n   = 0;
 	average[t].sum = 0.0;
