@@ -18,13 +18,14 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _NORMALIZE_PLUGIN_H_
-#define _NORMALIZE_PLUGIN_H_
+#ifndef NORMALIZE_PLUGIN_H
+#define NORMALIZE_PLUGIN_H
 
 #include "config.h"
 
 #include <QtCore/QString>
 #include <QtCore/QStringList>
+#include <QtCore/QVector>
 
 #include "libkwave/Plugin.h"
 #include "libkwave/Sample.h"
@@ -45,7 +46,7 @@ namespace Kwave
     public:
 
 	/** Constructor */
-	NormalizePlugin(Kwave::PluginManager &plugin_manager);
+	explicit NormalizePlugin(Kwave::PluginManager &plugin_manager);
 
 	/** Destructor */
 	virtual ~NormalizePlugin();
@@ -87,7 +88,7 @@ namespace Kwave
     };
 }
 
-#endif /* _NORMALIZE_PLUGIN_H_ */
+#endif /* NORMALIZE_PLUGIN_H */
 
 //***************************************************************************
 //***************************************************************************
