@@ -18,8 +18,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _NORMALIZER_H_
-#define _NORMALIZER_H_
+#ifndef NORMALIZER_H
+#define NORMALIZER_H
 
 #include "config.h"
 
@@ -79,7 +79,7 @@ namespace Kwave
     };
 }
 
-#endif /* _NORMALIZER_H_ */
+#endif /* NORMALIZER_H */
 
 //***************************************************************************
 //***************************************************************************
