@@ -25,6 +25,7 @@
 
 #include <klocale.h>
 #include <kpushbutton.h>
+#include <ktoolinvocation.h>
 
 #include "libkwave/String.h"
 #include "libkwave/Utils.h"
@@ -77,6 +78,9 @@ Kwave::PitchShiftDialog::PitchShiftDialog(QWidget *parent)
     int w = (height() * 3) / 5;
     if (width() < w) resize(w, height());
 
+    connect(btHelp->button(QDialogButtonBox::Help), SIGNAL(clicked()),
+            this,   SLOT(invokeHelp()));
+
     // set the focus onto the "OK" button
     buttonBox->button(QDialogButtonBox::Ok)->setFocus();
 }
@@ -336,6 +340,13 @@ void Kwave::PitchShiftDialog::listenStopped()
     btListen->setChecked(false);
 }
 
+
+//***************************************************************************
+void Kwave::PitchShiftDialog::invokeHelp()
+{
+    KToolInvocation::invokeHelp(_("plugin_sect_pitch_shift"));
+}
+
 //***************************************************************************
 #include "PitchShiftDialog.moc"
 //***************************************************************************
