@@ -19,14 +19,15 @@
 #include <stdio.h>
 #include <stdlib.h>
 
+#include <QtCore/QPointer>
+#include <QtCore/QLatin1Char>
+#include <QtCore/QStringList>
 #include <QtGui/QIcon>
 #include <QtGui/QLabel>
 #include <QtGui/QPushButton>
 #include <QtGui/QTreeWidget>
 #include <QtGui/QTreeWidgetItem>
 #include <QtGui/QSlider>
-#include <QtCore/QLatin1Char>
-#include <QtCore/QStringList>
 
 #include <kapplication.h>
 #include <kcombobox.h>
@@ -79,14 +80,14 @@ Kwave::PlayBackDialog::PlayBackDialog(
 
     connect(cbMethod, SIGNAL(activated(int)),
             SLOT(methodSelected(int)));
-    connect(cbDevice, SIGNAL(editTextChanged(const QString &)),
-            SLOT(setDevice(const QString &)));
-    connect(cbDevice, SIGNAL(activated(const QString &)),
-            SLOT(setDevice(const QString &)));
-    connect(cbBitsPerSample, SIGNAL(editTextChanged(const QString &)),
-            SLOT(bitsPerSampleSelected(const QString &)));
-    connect(cbBitsPerSample, SIGNAL(activated(const QString &)),
-            SLOT(bitsPerSampleSelected(const QString &)));
+    connect(cbDevice, SIGNAL(editTextChanged(QString)),
+            SLOT(setDevice(QString)));
+    connect(cbDevice, SIGNAL(activated(QString)),
+            SLOT(setDevice(QString)));
+    connect(cbBitsPerSample, SIGNAL(editTextChanged(QString)),
+            SLOT(bitsPerSampleSelected(QString)));
+    connect(cbBitsPerSample, SIGNAL(activated(QString)),
+            SLOT(bitsPerSampleSelected(QString)));
     connect(sbChannels, SIGNAL(valueChanged(int)),
             SLOT(setChannels(int)));
     connect(slBufferSize, SIGNAL(valueChanged(int)),
@@ -95,10 +96,10 @@ Kwave::PlayBackDialog::PlayBackDialog(
             SLOT(selectPlaybackDevice()));
 
     connect(listDevices,
-            SIGNAL(currentItemChanged(QTreeWidgetItem *, QTreeWidgetItem *)),
-            SLOT(listEntrySelected(QTreeWidgetItem *, QTreeWidgetItem *)));
-    connect(listDevices, SIGNAL(itemExpanded(QTreeWidgetItem *)),
-            SLOT(listItemExpanded(QTreeWidgetItem *)));
+            SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)),
+            SLOT(listEntrySelected(QTreeWidgetItem*,QTreeWidgetItem*)));
+    connect(listDevices, SIGNAL(itemExpanded(QTreeWidgetItem*)),
+            SLOT(listItemExpanded(QTreeWidgetItem*)));
     connect(listDevices, SIGNAL(focusLost()),
             SLOT(updateListSelection()));
 
@@ -121,7 +122,7 @@ Kwave::PlayBackDialog::PlayBackDialog(
     setBitsPerSample(params.bits_per_sample);
     setChannels(params.channels);
 
-    // buffer size is independend
+    // buffer size is independent
     setBufferSize(params.bufbase);
 
     // set the focus onto the "OK" button
@@ -289,11 +290,12 @@ void Kwave::PlayBackDialog::setSupportedDevices(QStringList devices)
 	m_devices_list_map.clear();
 
 	// build a tree with all nodes in the list
-	foreach (QString dev_id, devices) {
+	foreach (const QString &dev_id, devices) {
 	    QTreeWidgetItem *parent = 0;
 
 	    QStringList list = dev_id.split(_("||"), QString::KeepEmptyParts);
-	    foreach (QString token, list) {
+	    foreach (const QString &t, list) {
+		QString token(t);
 		QTreeWidgetItem *item = 0;
 
 		// split the icon name from the token
@@ -626,22 +628,23 @@ void Kwave::PlayBackDialog::selectPlaybackDevice()
 {
     QString filter = m_file_filter;
 
-    Kwave::FileDialog dlg(
-	_("kfiledialog:///kwave_playback_device"), filter, this,
+    QPointer<Kwave::FileDialog> dlg = new(std::nothrow) Kwave::FileDialog(
+	_("kfiledialog:///kwave_playback_device"),
+	KFileDialog::Opening, filter, this,
 	true, _("file:/dev"));
-    dlg.setKeepLocation(true);
-    dlg.setOperationMode(KFileDialog::Opening);
-    dlg.setCaption(i18n("Select Playback Device"));
+    if (!dlg) return;
+    dlg->setKeepLocation(true);
+    dlg->setCaption(i18n("Select Playback Device"));
     if (!m_playback_params.device.startsWith(_("#")))
-        dlg.setUrl(KUrl(_("file:") + m_playback_params.device));
+        dlg->setUrl(KUrl(_("file:") + m_playback_params.device));
     else
-        dlg.setUrl(KUrl(_("file:/dev/*")));
-    if (dlg.exec() != QDialog::Accepted) return;
-
-    QString new_device = dlg.selectedFile();
-
-    // selected new device
-    if (cbDevice) cbDevice->setEditText(new_device);
+        dlg->setUrl(KUrl(_("file:/dev/*")));
+    if (dlg->exec() == QDialog::Accepted) {
+	QString new_device = dlg->selectedFile();
+	// selected new device
+	if (cbDevice) cbDevice->setEditText(new_device);
+    }
+    delete dlg;
 }
 
 //***************************************************************************
