@@ -40,24 +40,24 @@ QMap<QString, QString> Kwave::RecordALSA::m_device_list;
 
 //***************************************************************************
 
-/* define some endian dependend symbols that are missing in ALSA */
+/* define some endian dependent symbols that are missing in ALSA */
 #if Q_BYTE_ORDER == Q_BIG_ENDIAN
 // big endian
-#define _SND_PCM_FORMAT_S18_3 SND_PCM_FORMAT_S18_3BE
-#define _SND_PCM_FORMAT_U18_3 SND_PCM_FORMAT_U18_3BE
-#define _SND_PCM_FORMAT_U20_3 SND_PCM_FORMAT_U20_3BE
-#define _SND_PCM_FORMAT_S20_3 SND_PCM_FORMAT_S20_3BE
-#define _SND_PCM_FORMAT_U24_3 SND_PCM_FORMAT_U24_3BE
-#define _SND_PCM_FORMAT_S24_3 SND_PCM_FORMAT_S24_3BE
+#define SND_PCM_FORMAT_S18_3 SND_PCM_FORMAT_S18_3BE
+#define SND_PCM_FORMAT_U18_3 SND_PCM_FORMAT_U18_3BE
+#define SND_PCM_FORMAT_U20_3 SND_PCM_FORMAT_U20_3BE
+#define SND_PCM_FORMAT_S20_3 SND_PCM_FORMAT_S20_3BE
+#define SND_PCM_FORMAT_U24_3 SND_PCM_FORMAT_U24_3BE
+#define SND_PCM_FORMAT_S24_3 SND_PCM_FORMAT_S24_3BE
 
 #else
 // little endian
-#define _SND_PCM_FORMAT_S18_3 SND_PCM_FORMAT_S18_3LE
-#define _SND_PCM_FORMAT_U18_3 SND_PCM_FORMAT_U18_3LE
-#define _SND_PCM_FORMAT_U20_3 SND_PCM_FORMAT_U20_3LE
-#define _SND_PCM_FORMAT_S20_3 SND_PCM_FORMAT_S20_3LE
-#define _SND_PCM_FORMAT_U24_3 SND_PCM_FORMAT_U24_3LE
-#define _SND_PCM_FORMAT_S24_3 SND_PCM_FORMAT_S24_3LE
+#define SND_PCM_FORMAT_S18_3 SND_PCM_FORMAT_S18_3LE
+#define SND_PCM_FORMAT_U18_3 SND_PCM_FORMAT_U18_3LE
+#define SND_PCM_FORMAT_U20_3 SND_PCM_FORMAT_U20_3LE
+#define SND_PCM_FORMAT_S20_3 SND_PCM_FORMAT_S20_3LE
+#define SND_PCM_FORMAT_U24_3 SND_PCM_FORMAT_U24_3LE
+#define SND_PCM_FORMAT_S24_3 SND_PCM_FORMAT_S24_3LE
 
 #endif
 
@@ -85,16 +85,16 @@ static const snd_pcm_format_t _known_formats[] =
     SND_PCM_FORMAT_U16, SND_PCM_FORMAT_U16_LE, SND_PCM_FORMAT_U16_BE,
 
     /* 18 bit / 3 byte */
-    _SND_PCM_FORMAT_S18_3, SND_PCM_FORMAT_S18_3LE, SND_PCM_FORMAT_S18_3BE,
-    _SND_PCM_FORMAT_U18_3, SND_PCM_FORMAT_U18_3LE, SND_PCM_FORMAT_U18_3BE,
+    SND_PCM_FORMAT_S18_3, SND_PCM_FORMAT_S18_3LE, SND_PCM_FORMAT_S18_3BE,
+    SND_PCM_FORMAT_U18_3, SND_PCM_FORMAT_U18_3LE, SND_PCM_FORMAT_U18_3BE,
 
     /* 20 bit / 3 byte */
-    _SND_PCM_FORMAT_S20_3, SND_PCM_FORMAT_S20_3LE, SND_PCM_FORMAT_S20_3BE,
-    _SND_PCM_FORMAT_U20_3, SND_PCM_FORMAT_U20_3LE, SND_PCM_FORMAT_U20_3BE,
+    SND_PCM_FORMAT_S20_3, SND_PCM_FORMAT_S20_3LE, SND_PCM_FORMAT_S20_3BE,
+    SND_PCM_FORMAT_U20_3, SND_PCM_FORMAT_U20_3LE, SND_PCM_FORMAT_U20_3BE,
 
     /* 24 bit / 3 byte */
-    _SND_PCM_FORMAT_S24_3, SND_PCM_FORMAT_S24_3LE, SND_PCM_FORMAT_S24_3BE,
-    _SND_PCM_FORMAT_U24_3, SND_PCM_FORMAT_U24_3LE, SND_PCM_FORMAT_U24_3BE,
+    SND_PCM_FORMAT_S24_3, SND_PCM_FORMAT_S24_3LE, SND_PCM_FORMAT_S24_3BE,
+    SND_PCM_FORMAT_U24_3, SND_PCM_FORMAT_U24_3LE, SND_PCM_FORMAT_U24_3BE,
 
     /* 24 bit / 4 byte */
     SND_PCM_FORMAT_S24, SND_PCM_FORMAT_S24_LE, SND_PCM_FORMAT_S24_BE,
@@ -145,7 +145,7 @@ static const snd_pcm_format_t _known_formats[] =
 
 //***************************************************************************
 /** find out the SampleFormat of an ALSA format */
-static Kwave::SampleFormat sample_format_of(snd_pcm_format_t fmt)
+static Kwave::SampleFormat::Format sample_format_of(snd_pcm_format_t fmt)
 {
     if (snd_pcm_format_float(fmt)) {
 	if (snd_pcm_format_width(fmt) == 32)
@@ -176,21 +176,22 @@ static Kwave::byte_order_t endian_of(snd_pcm_format_t fmt)
 //***************************************************************************
 static int compression_of(snd_pcm_format_t fmt)
 {
+    int f = Kwave::Compression::NONE;
     switch (fmt) {
 	case SND_PCM_FORMAT_MU_LAW:
-	    return Kwave::Compression::G711_ULAW;
+	    f = Kwave::Compression::G711_ULAW;    break;
 	case SND_PCM_FORMAT_A_LAW:
-	    return Kwave::Compression::G711_ALAW;
+	    f = Kwave::Compression::G711_ALAW;    break;
 	case SND_PCM_FORMAT_IMA_ADPCM:
-	    return Kwave::Compression::MS_ADPCM;
+	    f = Kwave::Compression::MS_ADPCM;     break;
 	case SND_PCM_FORMAT_MPEG:
-	    return Kwave::Compression::MPEG_LAYER_I;
+	    f = Kwave::Compression::MPEG_LAYER_I; break;
 	case SND_PCM_FORMAT_GSM:
-	    return Kwave::Compression::GSM;
+	    f = Kwave::Compression::GSM;          break;
 	default:
-	    return Kwave::Compression::NONE;
+	    break;
     }
-    return Kwave::Compression::NONE;
+    return f;
 }
 
 //***************************************************************************
@@ -789,7 +790,7 @@ double Kwave::RecordALSA::sampleRate()
 
 //***************************************************************************
 int Kwave::RecordALSA::mode2format(int compression, int bits,
-                                   Kwave::SampleFormat sample_format)
+                                   Kwave::SampleFormat::Format sample_format)
 {
     // loop over all supported formats and keep only those that are
     // compatible with the given compression, bits and sample format
@@ -892,15 +893,16 @@ int Kwave::RecordALSA::bitsPerSample()
 }
 
 //***************************************************************************
-QList<Kwave::SampleFormat> Kwave::RecordALSA::detectSampleFormats()
+QList<Kwave::SampleFormat::Format> Kwave::RecordALSA::detectSampleFormats()
 {
-    QList<Kwave::SampleFormat> list;
+    QList<Kwave::SampleFormat::Format> list;
 
     // try all known sample formats
     foreach(int it, m_supported_formats)
     {
 	const snd_pcm_format_t *fmt = &(_known_formats[it]);
-	const Kwave::SampleFormat sample_format = sample_format_of(*fmt);
+	const Kwave::SampleFormat::Format sample_format =
+	    sample_format_of(*fmt);
 
 	// only accept bits/sample if compression types
 	// and bits per sample match
@@ -922,7 +924,7 @@ QList<Kwave::SampleFormat> Kwave::RecordALSA::detectSampleFormats()
 }
 
 //***************************************************************************
-int Kwave::RecordALSA::setSampleFormat(Kwave::SampleFormat new_format)
+int Kwave::RecordALSA::setSampleFormat(Kwave::SampleFormat::Format new_format)
 {
     if (m_sample_format != new_format) m_initialized = false;
     m_sample_format = new_format;
@@ -930,7 +932,7 @@ int Kwave::RecordALSA::setSampleFormat(Kwave::SampleFormat new_format)
 }
 
 //***************************************************************************
-Kwave::SampleFormat Kwave::RecordALSA::sampleFormat()
+Kwave::SampleFormat::Format Kwave::RecordALSA::sampleFormat()
 {
     return m_sample_format;
 }
