@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _RECORD_DIALOG_H_
-#define _RECORD_DIALOG_H_
+#ifndef RECORD_DIALOG_H
+#define RECORD_DIALOG_H
 
 #include "config.h"
 
@@ -117,14 +117,16 @@ namespace Kwave
 	 * sets the list of supported sample formats
 	 * @param formats list of supported sample formats, must not be empty
 	 */
-	void setSupportedSampleFormats(const QList<Kwave::SampleFormat> &formats);
+	void setSupportedSampleFormats(
+	    const QList<Kwave::SampleFormat::Format> &formats
+	);
 
 	/**
 	 * sets a new sample format
 	 * @param sample_format format of the samples, like signed/unsigned
 	 * @see SampleFormat
 	 */
-	void setSampleFormat(Kwave::SampleFormat sample_format);
+	void setSampleFormat(Kwave::SampleFormat::Format sample_format);
 
 	/**
 	 * updates the progress bar with the buffer fill state.
@@ -167,7 +169,7 @@ namespace Kwave
 	void sigBitsPerSampleChanged(unsigned int bits);
 
 	/** emitted when the sample format has changed */
-	void sigSampleFormatChanged(Kwave::SampleFormat sample_format);
+	void sigSampleFormatChanged(Kwave::SampleFormat::Format sample_format);
 
 	/** emitted when the number and/or size of buffers has changed */
 	void sigBuffersChanged();
@@ -338,7 +340,7 @@ namespace Kwave
     };
 }
 
-#endif /* _RECORD_DIALOG_H_ */
+#endif /* RECORD_DIALOG_H */
 
 //***************************************************************************
 //***************************************************************************
