@@ -112,21 +112,21 @@ QStringList *Kwave::RecordPlugin::setup(QStringList &previous_params)
     // connect some signals of the setup dialog
     connect(m_dialog, SIGNAL(sigMethodChanged(Kwave::record_method_t)),
             this,     SLOT(setMethod(Kwave::record_method_t)));
-    connect(m_dialog, SIGNAL(sigDeviceChanged(const QString &)),
-            this,     SLOT(setDevice(const QString &)));
+    connect(m_dialog, SIGNAL(sigDeviceChanged(QString)),
+            this,     SLOT(setDevice(QString)));
 
-    connect(m_dialog, SIGNAL(sigTracksChanged(unsigned int)),
-            this,     SLOT(changeTracks(unsigned int)));
+    connect(m_dialog, SIGNAL(sigTracksChanged(uint)),
+            this,     SLOT(changeTracks(uint)));
     connect(m_dialog, SIGNAL(sampleRateChanged(double)),
             this,     SLOT(changeSampleRate(double)));
     connect(m_dialog, SIGNAL(sigCompressionChanged(int)),
             this,     SLOT(changeCompression(int)));
-    connect(m_dialog, SIGNAL(sigBitsPerSampleChanged(unsigned int)),
-            this,     SLOT(changeBitsPerSample(unsigned int)));
+    connect(m_dialog, SIGNAL(sigBitsPerSampleChanged(uint)),
+            this,     SLOT(changeBitsPerSample(uint)));
     connect(m_dialog,
-	    SIGNAL(sigSampleFormatChanged(Kwave::SampleFormat)),
+	    SIGNAL(sigSampleFormatChanged(Kwave::SampleFormat::Format)),
             this,
-	    SLOT(changeSampleFormat(Kwave::SampleFormat)));
+	    SLOT(changeSampleFormat(Kwave::SampleFormat::Format)));
     connect(m_dialog, SIGNAL(sigBuffersChanged()),
             this,     SLOT(buffersChanged()));
     connect(this,     SIGNAL(sigRecordedSamples(sample_index_t)),
@@ -146,8 +146,8 @@ QStringList *Kwave::RecordPlugin::setup(QStringList &previous_params)
     m_controller.enablePrerecording(m_dialog->params().pre_record_enabled);
 
     // connect the record controller and this
-    connect(&m_controller, SIGNAL(sigReset(bool &)),
-            this,          SLOT(resetRecording(bool &)));
+    connect(&m_controller, SIGNAL(sigReset(bool&)),
+            this,          SLOT(resetRecording(bool&)));
     connect(&m_controller, SIGNAL(sigStartRecord()),
             this,          SLOT(startRecording()));
     connect(&m_controller, SIGNAL(sigStopRecord(int)),
@@ -499,8 +499,8 @@ void Kwave::RecordPlugin::changeTracks(unsigned int new_tracks)
 	}
 
 	if (new_tracks && (channels > 0)) notice(
-	    i18n("Recording with %1 channels(s) failed, "\
-		 "using %2 channels(s)", new_tracks, channels));
+	    i18n("Recording with %1 channel(s) failed, "\
+		 "using %2 channel(s)", new_tracks, channels));
     }
     m_dialog->setTracks(channels);
 
@@ -679,7 +679,8 @@ void Kwave::RecordPlugin::changeBitsPerSample(unsigned int new_bits)
 }
 
 //***************************************************************************
-void Kwave::RecordPlugin::changeSampleFormat(Kwave::SampleFormat new_format)
+void Kwave::RecordPlugin::changeSampleFormat(
+    Kwave::SampleFormat::Format new_format)
 {
     Q_ASSERT(m_dialog);
     if (!m_dialog) return;
@@ -694,9 +695,9 @@ void Kwave::RecordPlugin::changeSampleFormat(Kwave::SampleFormat new_format)
     }
 
     // check the supported sample formats
-    QList<Kwave::SampleFormat> supported_formats =
+    QList<Kwave::SampleFormat::Format> supported_formats =
 	m_device->detectSampleFormats();
-    Kwave::SampleFormat format = new_format;
+    Kwave::SampleFormat::Format format = new_format;
     if (!supported_formats.contains(format) && !supported_formats.isEmpty()) {
 	// use the device default instead
 	format = m_device->sampleFormat();
@@ -934,9 +935,13 @@ void Kwave::RecordPlugin::startRecording()
 	     Kwave::FileInfo(signalManager().metaData()).rate(), rate))
 	{
 	    // create a new and empty signal
-
 	    emitCommand(QString(_("newsignal(%1,%2,%3,%4)")).arg(
 		samples).arg(rate).arg(bits).arg(tracks));
+
+	    // the parent context might have changed, maybe we have to
+	    // re-parent this plugin instance!
+	    migrateToActiveContext();
+
 	    Kwave::SignalManager &mgr = signalManager();
 	    if (!qFuzzyCompare(mgr.rate(), rate) || (mgr.bits() != bits) ||
 	        (mgr.tracks() != tracks))
@@ -968,7 +973,7 @@ void Kwave::RecordPlugin::startRecording()
 	fileInfo.setTracks(tracks);
 	fileInfo.set(Kwave::INF_MIMETYPE, _("audio/vnd.wave"));
 	fileInfo.set(Kwave::INF_SAMPLE_FORMAT,
-	    m_dialog->params().sample_format.toInt());
+	    Kwave::SampleFormat(m_dialog->params().sample_format).toInt());
 	fileInfo.set(Kwave::INF_COMPRESSION, m_dialog->params().compression);
 
 	// add our Kwave Software tag
@@ -1133,10 +1138,11 @@ void Kwave::RecordPlugin::split(QByteArray &raw_data, QByteArray &dest,
 		quint8 *dst =
 		    reinterpret_cast<quint8 *>(dest.data());
 		src += track;
-		while (samples--) {
+		while (samples) {
 		    *dst = *src;
 		    dst++;
 		    src += tracks;
+		    samples--;
 		}
 		break;
 	    }
@@ -1147,10 +1153,11 @@ void Kwave::RecordPlugin::split(QByteArray &raw_data, QByteArray &dest,
 		quint16 *dst =
 		    reinterpret_cast<quint16 *>(dest.data());
 		src += track;
-		while (samples--) {
+		while (samples) {
 		    *dst = *src;
 		    dst++;
 		    src += tracks;
+		    samples--;
 		}
 		break;
 	    }
@@ -1161,11 +1168,12 @@ void Kwave::RecordPlugin::split(QByteArray &raw_data, QByteArray &dest,
 		quint8 *dst =
 		    reinterpret_cast<quint8 *>(dest.data());
 		src += track * 3;
-		while (samples--) {
+		while (samples) {
 		    *(dst++) = *(src++);
 		    *(dst++) = *(src++);
 		    *(dst++) = *(src++);
 		    src += (tracks - 1) * 3;
+		    samples--;
 		}
 		break;
 	    }
@@ -1176,10 +1184,11 @@ void Kwave::RecordPlugin::split(QByteArray &raw_data, QByteArray &dest,
 		quint32 *dst =
 		    reinterpret_cast<quint32 *>(dest.data());
 		src += track;
-		while (samples--) {
+		while (samples) {
 		    *dst = *src;
 		    dst++;
 		    src += tracks;
+		    samples--;
 		}
 		break;
 	    }
@@ -1190,10 +1199,11 @@ void Kwave::RecordPlugin::split(QByteArray &raw_data, QByteArray &dest,
 		quint64 *dst =
 		    reinterpret_cast<quint64 *>(dest.data());
 		src += track;
-		while (samples--) {
+		while (samples) {
 		    *dst = *src;
 		    dst++;
 		    src += tracks;
+		    samples--;
 		}
 		break;
 	    }
@@ -1205,11 +1215,12 @@ void Kwave::RecordPlugin::split(QByteArray &raw_data, QByteArray &dest,
 		    reinterpret_cast<quint8 *>(dest.data());
 		src += (track * bytes_per_sample);
 		unsigned int increment = (tracks - 1) * bytes_per_sample;
-		while (samples--) {
+		while (samples) {
 		    for (unsigned int b = 0; b < bytes_per_sample; b++) {
 			*dst = *src;
 			dst++;
 			src++;
+			samples--;
 		    }
 		    src += increment;
 		}
