@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _STATUS_WIDGET_H_
-#define _STATUS_WIDGET_H_
+#ifndef STATUS_WIDGET_H
+#define STATUS_WIDGET_H
 
 #include "config.h"
 
@@ -36,7 +36,7 @@ namespace Kwave
     public:
 
 	/** Constructor */
-	StatusWidget(QWidget *parent = 0);
+	explicit StatusWidget(QWidget *parent = 0);
 
 	/** Destructor */
 	virtual ~StatusWidget();
@@ -74,7 +74,7 @@ namespace Kwave
     };
 }
 
-#endif /* _STATUS_WIDGET_H_ */
+#endif /* STATUS_WIDGET_H */
 
 //***************************************************************************
 //***************************************************************************
