@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _SAVE_BLOCKS_DIALOG_H_
-#define _SAVE_BLOCKS_DIALOG_H_
+#ifndef SAVE_BLOCKS_DIALOG_H
+#define SAVE_BLOCKS_DIALOG_H
 
 #include "config.h"
 
@@ -104,11 +104,6 @@ namespace Kwave
 	/** collects all needed data and emits a sigSelectionChanged */
 	void emitUpdate();
 
-    protected slots:
-
-	/** calls emitUpdate() and ignores it's parameter */
-	void textChanged(const QString &);
-
     private:
 
 	/** the widget with extra settings for saving the blocks */
@@ -117,7 +112,7 @@ namespace Kwave
     };
 }
 
-#endif /* _SAVE_BLOCKS_DIALOG_H_ */
+#endif /* SAVE_BLOCKS_DIALOG_H */
 
 //***************************************************************************
 //***************************************************************************
