@@ -19,7 +19,6 @@
 
 #include <errno.h>
 
-#include <QtCore/QByteArray>
 #include <QtCore/QDir>
 #include <QtCore/QFile>
 #include <QtCore/QFileInfo>
@@ -33,13 +32,14 @@
 #include "libkwave/LabelList.h"
 #include "libkwave/MessageBox.h"
 #include "libkwave/MetaDataList.h"
+#include "libkwave/Parser.h"
 #include "libkwave/SignalManager.h"
 #include "libkwave/String.h"
 
 #include "SaveBlocksDialog.h"
 #include "SaveBlocksPlugin.h"
 
-KWAVE_PLUGIN(Kwave::SaveBlocksPlugin, "saveblocks", "2.3",
+KWAVE_PLUGIN(Kwave::SaveBlocksPlugin, "saveblocks", "2.4",
              I18N_NOOP("Save Blocks"), "Thomas Eschenbacher");
 
 //***************************************************************************
@@ -62,7 +62,6 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
     interpreteParameters(previous_params);
 
     // create the setup dialog
-    KUrl url(signalName());
     sample_index_t selection_left  = 0;
     sample_index_t selection_right = 0;
     selection(0, &selection_left, &selection_right, false);
@@ -74,28 +73,27 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
                          (selection_right + 1 >= signalLength()));
     bool enable_selection_only = selected_something && !selected_all;
 
-    Kwave::SaveBlocksDialog *dialog = new Kwave::SaveBlocksDialog(
-	_(":<kwave_save_blocks>"),
-	Kwave::CodecManager::encodingFilter(),
-	parentWidget(), true,
-	url.prettyUrl(), _("*.wav"),
-	m_pattern,
-	m_numbering_mode,
-	m_selection_only,
-	enable_selection_only
-    );
-    Q_ASSERT(dialog);
+    QPointer<Kwave::SaveBlocksDialog> dialog =
+	new(std::nothrow) Kwave::SaveBlocksDialog(
+	    _("kfiledialog:///kwave_save_blocks"),
+	    Kwave::CodecManager::encodingFilter(),
+	    parentWidget(), true,
+	    signalName(), _("*.wav"),
+	    m_pattern,
+	    m_numbering_mode,
+	    m_selection_only,
+	    enable_selection_only
+	);
     if (!dialog) return 0;
 
     // connect the signals/slots from the plugin and the dialog
-    connect(dialog, SIGNAL(sigSelectionChanged(const QString &,
-	const QString &, Kwave::SaveBlocksPlugin::numbering_mode_t, bool)),
-	this, SLOT(updateExample(const QString &, const QString &,
-	Kwave::SaveBlocksPlugin::numbering_mode_t, bool)));
-    connect(this, SIGNAL(sigNewExample(const QString &)),
-	dialog, SLOT(setNewExample(const QString &)));
+    connect(dialog, SIGNAL(sigSelectionChanged(QString,
+	QString,Kwave::SaveBlocksPlugin::numbering_mode_t,bool)),
+	this, SLOT(updateExample(QString,QString,
+	Kwave::SaveBlocksPlugin::numbering_mode_t,bool)));
+    connect(this, SIGNAL(sigNewExample(QString)),
+	dialog, SLOT(setNewExample(QString)));
 
-    dialog->setOperationMode(KFileDialog::Saving);
     dialog->setCaption(i18n("Save Blocks"));
     dialog->emitUpdate();
     if (dialog->exec() != QDialog::Accepted) return 0;
@@ -104,12 +102,28 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
     Q_ASSERT(list);
     if (list) {
 	// user has pressed "OK"
-	QString pattern, name;
+	QString pattern;
 
-	name = QLatin1String(QByteArray(
-	    dialog->selectedUrl().prettyUrl().toUtf8()).toBase64());
-	pattern = QLatin1String(QByteArray(
-	    dialog->pattern().toUtf8()).toBase64());
+	KUrl url = dialog->selectedUrl();
+	if (url.isEmpty()) {
+	    delete dialog;
+	    return 0;
+	}
+	QString name = url.path();
+	QFileInfo path(name);
+
+	// add the correct extension if necessary
+	if (!path.suffix().length()) {
+	    QString ext = dialog->selectedExtension();
+	    QStringList extensions = ext.split(_(" "));
+	    ext = extensions.first();
+	    name += ext.mid(1);
+	    path = name;
+	    url.setPath(name);
+	}
+
+	name     = Kwave::Parser::escape(name);
+	pattern  = Kwave::Parser::escape(dialog->pattern());
 	int mode = static_cast<int>(dialog->numberingMode());
 	bool selection_only = (enable_selection_only) ?
 	    dialog->selectionOnly() : m_selection_only;
@@ -293,12 +307,11 @@ int Kwave::SaveBlocksPlugin::interpreteParameters(QStringList &params)
     }
 
     // the selected URL
-    m_url = QString::fromUtf8(QByteArray::fromBase64(params[0].toAscii()));
+    m_url = Kwave::Parser::unescape(params[0]);
     if (!m_url.isValid()) return -EINVAL;
 
     // filename pattern
-    m_pattern =
-	QString::fromUtf8(QByteArray::fromBase64(params[1].toAscii()));
+    m_pattern = Kwave::Parser::unescape(params[1]);
     if (!m_pattern.length()) return -EINVAL;
 
     // numbering mode
