@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _SELECT_RANGE_DIALOG_H_
-#define _SELECT_RANGE_DIALOG_H_
+#ifndef SELECT_RANGE_DIALOG_H
+#define SELECT_RANGE_DIALOG_H
 
 #include "config.h"
 
@@ -91,10 +91,15 @@ namespace Kwave
 	    return (select_range) ? select_range->time() : 0;
 	}
 
+    private slots:
+
+	/** invoke the online help */
+	void invokeHelp();
+
     };
 }
 
-#endif /* _SELECT_RANGE_DIALOG_H_ */
+#endif /* SELECT_RANGE_DIALOG_H */
 
 //***************************************************************************
 //***************************************************************************
