@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _SELECT_RANGE_PLUGIN_H_
-#define _SELECT_RANGE_PLUGIN_H_
+#ifndef SELECT_RANGE_PLUGIN_H
+#define SELECT_RANGE_PLUGIN_H
 
 #include "config.h"
 
@@ -38,7 +38,7 @@ namespace Kwave
     public:
 
 	/** Constructor */
-	SelectRangePlugin(Kwave::PluginManager &plugin_manager);
+	explicit SelectRangePlugin(Kwave::PluginManager &plugin_manager);
 
 	/** Destructor */
 	virtual ~SelectRangePlugin();
@@ -81,7 +81,7 @@ namespace Kwave
     };
 }
 
-#endif /* _SELECT_RANGE_PLUGIN_H_ */
+#endif /* SELECT_RANGE_PLUGIN_H */
 
 //***************************************************************************
 //***************************************************************************
