@@ -78,8 +78,8 @@ Kwave::SonagramPlugin::SonagramPlugin(Kwave::PluginManager &plugin_manager)
     i18n("Sonagram");
 
     // connect the output ouf the sonagram worker thread
-    connect(this, SIGNAL(sliceAvailable(Kwave::SonagramPlugin::Slice *)),
-            this, SLOT(insertSlice(Kwave::SonagramPlugin::Slice *)),
+    connect(this, SIGNAL(sliceAvailable(Kwave::SonagramPlugin::Slice*)),
+            this, SLOT(insertSlice(Kwave::SonagramPlugin::Slice*)),
             Qt::QueuedConnection);
 
     // connect repaint timer
@@ -177,7 +177,8 @@ int Kwave::SonagramPlugin::start(QStringList &params)
     if (result) return result;
 
     // create an empty sonagram window
-    m_sonagram_window = new Kwave::SonagramWindow(signalName());
+    m_sonagram_window = new(std::nothrow)
+	Kwave::SonagramWindow(parentWidget(), signalName());
     Q_ASSERT(m_sonagram_window);
     if (!m_sonagram_window) return -ENOMEM;
 
@@ -213,15 +214,15 @@ int Kwave::SonagramPlugin::start(QStringList &params)
     Q_ASSERT(m_selection);
     if (!m_selection) return -ENOMEM;
 
-    connect(m_selection, SIGNAL(sigTrackInserted(const QUuid &)),
-            this,        SLOT( slotTrackInserted(const QUuid &)));
-    connect(m_selection, SIGNAL(sigTrackDeleted(const QUuid &)),
-            this,        SLOT( slotTrackDeleted(const QUuid &)));
+    connect(m_selection, SIGNAL(sigTrackInserted(QUuid)),
+            this,        SLOT(slotTrackInserted(QUuid)));
+    connect(m_selection, SIGNAL(sigTrackDeleted(QUuid)),
+            this,        SLOT(slotTrackDeleted(QUuid)));
     connect(
 	m_selection,
-	SIGNAL(sigInvalidated(const QUuid *, sample_index_t, sample_index_t)),
+	SIGNAL(sigInvalidated(const QUuid*,sample_index_t,sample_index_t)),
 	this,
-	SLOT( slotInvalidated(const QUuid *, sample_index_t, sample_index_t))
+	SLOT(slotInvalidated(const QUuid*,sample_index_t,sample_index_t))
     );
 
     // create a new empty image
@@ -259,8 +260,8 @@ int Kwave::SonagramPlugin::start(QStringList &params)
 
     if (m_track_changes) {
 	QObject::connect(static_cast<QObject*>(&(manager())),
-	    SIGNAL(sigSignalNameChanged(const QString &)),
-	    m_sonagram_window, SLOT(setName(const QString &)));
+	    SIGNAL(sigSignalNameChanged(QString)),
+	    m_sonagram_window, SLOT(setName(QString)));
     }
 
     // increment the usage counter and release the plugin when the
@@ -428,10 +429,10 @@ void Kwave::SonagramPlugin::calculateSlice(Kwave::SonagramPlugin::Slice *slice)
 	double ima = slice->m_output[j][1];
 	double a = ((rea * rea) + (ima * ima)) / scale;
 
-	slice->m_result[j] = static_cast<char>(qMin(a, 254.0));
+	slice->m_result[j] = static_cast<unsigned char>(qMin(a, qreal(254.0)));
     }
 
-    // free the the allocated FFT resources
+    // free the allocated FFT resources
     {
 	Kwave::GlobalLock _lock; // libfftw is not threadsafe!
 	fftw_destroy_plan(p);
@@ -454,7 +455,8 @@ void Kwave::SonagramPlugin::insertSlice(Kwave::SonagramPlugin::Slice *slice)
     if (!slice) return;
 
     QByteArray result;
-    result.setRawData(&(slice->m_result[0]), m_fft_points / 2);
+    result.setRawData(reinterpret_cast<char *>(&(slice->m_result[0])),
+                      m_fft_points / 2);
     unsigned int nr = slice->m_index;
 
     // forward the slice to the window to display it
