@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _ZERO_PLUGIN_H_
-#define _ZERO_PLUGIN_H_
+#ifndef ZERO_PLUGIN_H
+#define ZERO_PLUGIN_H
 
 #include "config.h"
 
@@ -41,7 +41,7 @@ namespace Kwave
     public:
 
 	/** Constructor */
-	ZeroPlugin(Kwave::PluginManager &plugin_manager);
+	explicit ZeroPlugin(Kwave::PluginManager &plugin_manager);
 
 	/** Destructor */
 	virtual ~ZeroPlugin();
@@ -63,7 +63,7 @@ namespace Kwave
     };
 }
 
-#endif /* _ZERO_PLUGIN_H_ */
+#endif /* ZERO_PLUGIN_H */
 
 //***************************************************************************
 //***************************************************************************
